% Matlab file Ch1_Ex1_1.m
% Generates solution to difference equation (Equation 1.30)and exact
% solution (Equation 1.42)
% Plots Figure 1.9

clc; clear all; close all

y0=1; % given initial condition for y(t)
tfinal=2; % set final simulaion time 

for T=[0.01 0.025 0.05 0.1];    
 
clear t u yA 
    
nfinal=tfinal/T; % calculate total number of discrete time steps
    
t(1:nfinal)=0;  
u(1:nfinal)=0;
yA(1:nfinal)=0; 

%%%%% begin finding recursive solution of difference equation

alpha=1-2*T;
yA(1)=y0; % set initial value of yA(n)

for n=1:nfinal
          
  u(n)=3*n*T; % calculate input at t=nT  
  t(n+1)=n*T; % calculate (n+1)st value of t
  yA(n+1)=alpha*yA(n) + T*u(n); % calculate (n+1)st value of yA
end % for n

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%% begin finding exact solution %%%%%

ti=linspace(0,tfinal,200); % set points in t-interval for calculating y(t)
yi=1.75*exp(-2*ti)+1.5*ti-0.75; % calculate exact solution y(t) at discrete points in vector ti

% for ti=[0 0.2 0.5 1 1.5 2]
%      % calculate exact solution y(t) at points ti
%     ti,yi
% end % for ti 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


if T==0.01
subplot(2,2,1)
freq=8;
plot(t(1:freq:end),yA(1:freq:end),'r.','MarkerSize',8) % plot approximate solution yA
hold on
grid on
axis([0 2 0.5 2.5])
plot(ti,yi,'b','LineWidth',1.3) % plot exact solution y(t)
text(0.3,2.2,'y_A(n), n = 0,8,16,...','FontSize',11)
plot([0.15],[2.2],'r.','MarkerSize',8)
text(0.3,1.85,'y(t), t \geq 0','FontSize',11)
plot([0.10 0.20],[1.80 1.80],'b','LineWidth',1.3)
text(1.25,0.75,'T = 0.01','FontSize',11)
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:2])

text(-0.7,2.8,'Exact and Approximate Solutions for Various Numerical Values of the Time Step T','FontSize',11)

elseif T==0.025
subplot(2,2,2)
freq=4;
plot(t(1:freq:end),yA(1:freq:end),'r.','MarkerSize',8) % plot approximate solution yA
hold on
grid on
axis([0 2 0.5 2.5])
plot(ti,yi,'b','LineWidth',1.3) % plot exact solution y(t)
text(0.3,2.2,'y_A(n), n = 0,4,8,...','FontSize',11)
plot([0.15],[2.2],'r.','MarkerSize',8)
text(0.3,1.85,'y(t), t \geq 0','FontSize',11)
plot([0.10 0.20],[1.80 1.80],'b','LineWidth',1.3)
text(1.25,0.75,'T = 0.025','FontSize',11)
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:2])
     
elseif T==0.05
subplot(2,2,3)  
freq=2;
plot(t(1:freq:end),yA(1:freq:end),'r.','MarkerSize',8) % plot approximate solution yA
hold on
grid on
axis([0 2 0.5 2.5])
plot(ti,yi,'b','LineWidth',1.3) % plot exact solution y(t)
text(0.3,2.2,'y_A(n), n = 0,2,4,...','FontSize',11)
plot([0.15],[2.2],'r.','MarkerSize',8)
text(0.3,1.85,'y(t), t \geq 0','FontSize',11)
plot([0.10 0.20],[1.80 1.80],'b','LineWidth',1.3)
text(1.25,0.75,'T = 0.05','FontSize',11) 
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:2])
xlabel('t','FontSize',12)

elseif T==0.1
subplot(2,2,4)  
freq=1;
plot(t(1:freq:end),yA(1:freq:end),'r.','MarkerSize',8) % plot approximate solution yA
hold on
grid on
axis([0 2 0.5 2.5])
plot(ti,yi,'b','LineWidth',1.3) % plot exact solution y(t)
text(0.3,2.2,'y_A(n), n = 0,1,2,...','FontSize',11)
plot([0.15],[2.2],'r.','MarkerSize',8)
text(0.3,1.85,'y(t), t \geq 0','FontSize',11)
plot([0.10 0.20],[1.80 1.80],'b','LineWidth',1.3)
text(1.25,0.75,'T = 0.1','FontSize',11) 
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:2])
xlabel('t','FontSize',12)
end % if T
    
end % for T

%%%%% begin generate numbers for Tables %%%%%

T=0.01
nfinal=tfinal/T; % calculate total number of discrete time steps
    
t(1:nfinal)=0;  
u(1:nfinal)=0;
yA(1:nfinal)=0; 

%%%%% begin finding recursive solution of difference equation

alpha=1-2*T;
yA(1)=y0; % set initial value of yA(n)

for n=1:nfinal          
  u(n)=3*n*T; % calculate input at t=nT  
  t(n+1)=n*T; % calculate (n+1)st value of t
  yA(n+1)=alpha*yA(n) + T*u(n); % calculate (n+1)st value of yA
end % for n

for n=[1 21 51 101 151 201]
    yA(n)
    ti=(n-1)*T
    yi=1.75*exp(-2*ti)+1.5*ti-0.75
    err=100*(yA(n)-yi)/yi
end % for n

T=0.1
nfinal=tfinal/T; % calculate total number of discrete time steps
    
t(1:nfinal)=0;  
u(1:nfinal)=0;
yA(1:nfinal)=0; 

%%%%% begin finding recursive solution of difference equation

alpha=1-2*T;
yA(1)=y0; % set initial value of yA(n)

for n=1:nfinal          
  u(n)=3*n*T; % calculate input at t=nT  
  t(n+1)=n*T; % calculate (n+1)st value of t
  yA(n+1)=alpha*yA(n) + T*u(n); % calculate (n+1)st value of yA
end % for n


for n=[1 3 6 11 16 21] 
    yA(n)
    ti=(n-1)*T
    yi=1.75*exp(-2*ti)+1.5*ti-0.75
    err=100*(yA(n)-yi)/yi
end % for n

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
