% File: Ch3_CaseStudy.m
% Plots Figures 3.29, 3.30, 3.31, 3.33, 3.34

clc, clear all, close all

mu=6.5; K=0.2; W=300.0; V=3 ;
g=32.2; gamma=62.4;
A=[0 1 0;0 -mu*g/W 0;K*gamma 0 -K];
B=[0;g/W;0];
C=[1 0 0 ; -gamma 0 1];
T=0.25; % Use T=0.25 for Figure 7.2 and 7.3
I=eye(3);
G=inv(I-(T/2)*A)*(I+(T/2)*A); % trapezoidal
H=T*inv(I-(T/2)*A)*B; % trapezoidal
h0=500; 
p0=gamma*h0;
alpha=(mu*g/W);

%%%%% start equilibrium conditions
fc=W-gamma*V;   
fn=(W-gamma*V)-fc;
tau1=1/K;
tau2=W/(mu*g);
Tf=5*max(tau1,tau2);
T_surface=10;  
nf=round(T_surface/T);

xA=[h0;0;p0];
for n=1:nf
    t(n)=n*T;
    xA=G*xA+H*fn;
    x1A(n)=xA(1);
    x2A(n)=xA(2);
    x3A(n)=xA(3);
end % n
del=1; 
figure(1)
subplot(3,1,1)
t=[0 t]; x1A=[h0 x1A];
plot(t(1:del:end),x1A(1:del:end),'r.','MarkerSize',10)
grid on
axis([0 T_surface 0 600])
set(gca,'XTIck',[0:10],'FontSize',11)
set(gca,'YTick',[0:200:600],'FontSize',11)
hold on
ylabel('x_1  (ft)','FontSize',12)
ti=linspace(0,T_surface,300);
c1=(g*fn)/(alpha*W);
c2=(1-exp(-alpha*ti))/alpha;
x1i=h0+c1*(ti-c2);
plot(ti,x1i,'b','LineWidth',1.3)
text(5.5,350,'x_1(n), n = 0,1,2,...','FontSize',12')
text(5.5,165,'x_1(t)','FontSize',12)
plot([5],[350],'r.','MarkerSize',10)
plot([4.8 5.2],[165 165],'b','LineWidth',1.3)
title('Discrete and Continuous State Variables for Diver at Equilibrium','FontSize',11)

subplot(3,1,2)
x2A=[0 x2A];
plot(t(1:del:end),x2A(1:del:end),'r.','MarkerSize',10)
grid on
axis([0 T_surface -1 10]) 
set(gca,'YTick',[0:5:10])
set(gca,'XTIck',[0:10],'FontSize',11)
hold on
ylabel('x_2  (ft/s)','FontSize',12)
x2i=c1*(1-exp(-alpha*ti));
plot(ti,x2i,'b','LineWidth',1.3)
text(5.5,6.5,'x_2(n), n = 0,1,2,...','FontSize',12)
text(5.5,3.2,'x_2(t)','FontSize',12)
plot([5],[6.5],'.r','MarkerSize',10)
plot([4.8 5.2],[3.2 3.2],'b','LineWidth',1.3)
 
subplot(3,1,3)
x3A=[p0 x3A];
plot(t(1:del:end),x3A(1:del:end),'r.','MarkerSize',10)
grid on
axis([0 T_surface 0 4e4]) 
set(gca,'XTIck',[0:10],'FontSize',11)
set(gca,'YTick',[0:1e4:4e4],'FontSize',11)
hold on
xlabel('t  (s)','FontSize',12)
ylabel('x_3  (lb/ft^2)','FontSize',12)
c3=(K/(alpha-K))*c2;
c4=(alpha/(K*(alpha-K)))*(1-exp(-K*ti));
x3i=gamma*(h0+c1*(ti+c3-c4));
plot(ti,x3i,'b','LineWidth',1.3)
text(5.5,2.2e4,'x_3(n), n = 0,1,2,...','FontSize',12)
text(5.5,0.9e4,'x_3(t)','FontSize',12)
plot([5],[2.2e4],'r.','MarkerSize',10)
plot([4.8 5.2],[0.9e4 0.9e4],'b','LineWidth',1.3)


%%%%% start non-equilibrium conditions %%%%%
fc=1.1*(W-gamma*V); 
fn=(W-gamma*V)-fc;
T_surface=W/(mu*g) - (mu*h0)/(fn);  % Time for diver to surface
nf=round(T_surface/T);

xA=[h0;0;p0];
for n=1:nf
    t(n)=n*T;
    xA=G*xA+H*fn;
    x1A(n)=xA(1);
    x2A(n)=xA(2);
    x3A(n)=xA(3);
end % n
del=25;

figure(2)
subplot(3,1,1)
t=[0 t]; x1A=[h0 x1A];
plot(t(1:del:end),x1A(1:del:end),'r.','MarkerSize',10)
grid on
axis([0 300 0 600])
set(gca,'XTIck',[0:50:300],'FontSize',11)
set(gca,'YTick',[0:200:600])
hold on
ylabel('x_1  (ft)','FontSize',12)
ti=linspace(0,T_surface,500);
c1=(g*fn)/(alpha*W);
c2=(1-exp(-alpha*ti))/alpha;
x1i=h0+c1*(ti-c2);
plot(ti,x1i,'b','LineWidth',1.3)
text(200,450,'x_1(n), n = 0,25,50,...','FontSize',12)
text(200,275,'x_1(t)','FontSize',12)
plot([190],[450],'.r','MarkerSize',10)
plot([185 195],[280 280],'b')
title('Discrete and Continuous State Variables for Diver''s Ascent','FontSize',11)

subplot(3,1,2)
x2A=[0 x2A];
plot(t(1:del:end),x2A(1:del:end),'.r','MarkerSize',10)
grid on
axis([0 300 -2.1 0])
set(gca,'XTIck',[0:50:300],'FontSize',11)
set(gca,'YTick',[-2:0],'FontSize',11)
hold on
ylabel('x_2  (ft/s)','FontSize',12)
x2i=c1*(1-exp(-alpha*ti));
plot(ti,x2i,'b','LineWidth',1.3)
text(50,-1,'x_2(n), n = 0,25,50,...','FontSize',12)
text(200,-1,'x_2(t)','FontSize',12)
plot([40],[-1],'.r','MarkerSize',10)
plot([185 195],[-0.95 -0.95],'b')
 
subplot(3,1,3)
x3A=[p0 x3A];
plot(t(1:del:end),x3A(1:del:end),'.r','MarkerSize',10)
grid on
axis([0 300 0 4e4])
set(gca,'XTIck',[0:50:300],'FontSize',11)
set(gca,'YTick',[0:1e4:4e4])
hold on
xlabel('t  (s)','FontSize',12)
ylabel('x_3  (lb/ft^2)','FontSize',12)
c3=(K/(alpha-K))*c2;
c4=(alpha/(K*(alpha-K)))*(1-exp(-K*ti));
x3i=gamma*(h0+c1*(ti+c3-c4));
plot(ti,x3i,'b','LineWidth',1.3)
text(200,3e4,'x_3(n), n = 0,25,50,...','FontSize',12)
text(200,1.7e4,'x_3(t)','FontSize',12)
plot([190],[3e4],'.r','MarkerSize',10)
plot([185 195],[1.75e4 1.75e4],'b','LineWidth',1.3)

%%%%% start finding max cable force for safe ascent

%1. Trial and Error incremental search
xA=[h0;0;p0];
dpmax=4;

figure(3)
grid on
for fc=115:2:125  
   fn=(W-gamma*V)-fc;
   T_surface=W/(mu*g) - (mu*h0)/(fn); % Time for diver to surface
   nf=round(T_surface/T);   
   clear t xA x1A x2A x3A y2A
   xA=[h0;0;p0];
   
      for n=1:nf
         t(n)=n*T;
         xA=G*xA+H*fn;
         x1A(n)=xA(1);
         x2A(n)=xA(2);
         x3A(n)=xA(3);
      end % for n

   y2A=C(2,1)*x1A+C(2,3)*x3A; % C(2,2)=0
   y2A=y2A/144;
   plot(t,y2A,'b','LineWidth',1.3)
   grid on
   set(gca,'XTick',[0:150:1500],'FontSize',11)
   set(gca,'YTick',[0:0.5:4.5],'FontSize',11)
   axis([-25 1500 0 4.5])
   hold on
 
end % for fact

xlabel('t  (s)','FontSize',12)
ylabel('Differential Pressure  \Deltap(t),  (psi)','FontSize',12)
title('Search for Maximum Cable Force for Safe Ascent','FontSize',11) 
plot([-25 1500],[dpmax dpmax],'k--')
text(650,4.2,'\Delta\itp_{\rmmax} \rm= 4 psi','FontSize',12)
text(50,4.25,'f_C = 125 lbs','FontSize',12) 
text(50,3.58,'f_C = 123 lbs','FontSize',12)
text(50,2.92,'f_C = 121 lbs','FontSize',12) 
text(50,2.25,'f_C = 119 lbs','FontSize',12) 
text(50,1.59,'f_C = 117 lbs','FontSize',12) 
text(50,0.9,'f_C = 115 lbs','FontSize',12) 

% 2. Analytical Solution
fc_max=(W-gamma*V)+(mu*K*dpmax*144/gamma); 


% %%%%% start diver ascent with decompression stops %%%%%
%%%%% cannot use trapezoidal H matrix because input is not constant

GE=I+T*A; % Euler G matrix
HE=T*B; % Euler H matrix
clear t x1A x2A x3A y2A
h0=500; 
p0=gamma*h0;
xA=[h0;0;p0];
P=300;
L=100;
beta=0.1;
n=0;
while xA(1) > 0  
    n=n+1;
    t(n)=n*T; 
    
   if rem(t(n),P) < L
       fc(n)=124;
       fn(n)=(W-gamma*V)-fc(n);
   else
       fc(n)=W-gamma*V;
       fn(n)=(W-gamma*V)-fc(n);
   end % if
    
    xA=GE*xA+HE*fn(n); 
    x1A(n)=xA(1);
    x2A(n)=xA(2);
    x3A(n)=xA(3);
end % while

tfinal=t(end); 

% figure(4)
% subplot(3,1,1)
% t=[0 t];
% x1A=[h0 x1A];
% plot(t(1:del:end),x1A(1:del:end),'b','LineWidth',1.3)
% grid on
% ylabel('h(t),  ft','FontSize',12)
% set(gca,'YTick',[0:100:500],'FontSize',11)
% title('Diver Ascent with Decompression Stops','FontSize',11)
% 
% subplot(3,1,2)
% x2A=[0 x2A];
% plot(t(1:del:end),x2A(1:del:end),'b','LineWidth',1.3)
% grid on
% ylabel('dh/dt,  ft/sec','FontSize',12)
% set(gca,'YTick',[-2:0.5:0],'FontSize',11)
% 
% subplot(3,1,3)
% x3A=[p0 x3A];
% plot(t(1:del:end),x3A(1:del:end),'b','LineWidth',1.3)
% grid on
% ylabel('p(t),  lb per sq ft','FontSize',12)
% set(gca,'YTick',[0:1e4:4e4],'FontSize',11)
% xlabel('t  (sec)','FontSize',12)
% 
% figure(5)   
% y2A=C(2,1)*x1A+C(2,3)*x3A;
% y2A=y2A/144;
% plot(t(1:del:end),y2A(1:del:end),'b','LineWidth',1.3)
% grid on
% xlabel('\itt  \rm(sec)','FontSize',12)
% ylabel('\Delta\itp\rm(\itt\rm),  psi','FontSize',12)
% set(gca,'FontSize',11)
% title('Differential Pressure with Decompression Stops','FontSize',11)
% 
% figure(6)   
% subplot(3,1,1)
% fc=[(1+beta)*(W-gamma*V) fc];
% plot(t,fc,'b','LineWidth',1.3)
% grid on
% axis([0 tfinal 90 140])
% ylabel('f_C(t),  lbs','FontSize',12)
% set(gca,'FontSize',11)
% text(25,130,'124','FontSize',12)
% text(175,119,'112.8','FontSize',12)
% text(350,100,'L = 100 sec,  P = 300 sec','FontSize',12)
% title('Diver Ascent with Decompression Stops','FontSize',11)
% 
% subplot(3,1,2)
% plot(t,x1A,'b','LineWidth',1.3)
% grid on
% axis([0 tfinal 0 600])
% ylabel('h(t),  ft','FontSize',12)
% set(gca,'FontSize',11)
% set(gca,'YTick',[0:200:600],'FontSize',11)
% 
% subplot(3,1,3)
% plot(t,y2A,'b','LineWidth',1.3)
% grid on
% axis([0 tfinal 0 6])
% ylabel('\Deltap(t),  psi','FontSize',12)
% set(gca,'YTick',[0:2:6],'FontSize',11)
% xlabel('t  (sec)','FontSize',12)
% set(gca,'FontSize',11)
% hold on
% plot([0 tfinal],[dpmax dpmax],'r--')
% text(50,5,'\Deltap_{max} = 4 psi','FontSize',12)
% 
% figure(7) 
% subplot(2,1,1)
% fn1=-beta*(W-gamma*V);
% plot([0 L],[fn1 fn1],'b','LineWidth',1.3)
% hold on
% grid on
% plot([L P],[0 0],'b','LineWidth',1.3)
% plot([P P+L],[fn1 fn1],'b','LineWidth',1.3)
% plot([P+L 2*P],[0 0],'b','LineWidth',1.3)
% plot([L L],[fn1 0],'k--')
% plot([P P],[0 fn1],'k--')
% plot([P+L P+L],[fn1 0],'k--')
% axis([0 600 -12 2])
% xlabel('t  (sec)','FontSize',12)
% ylabel('f_n(t)  (lbs)','FontSize',12)
% set(gca,'FontSize',11)
% title('Net Cable Force,  f_n(t) vs t','FontSize',11)
% 
% subplot(2,1,2)
% plot(t,x2A,'b','LineWidth',1.3)
% grid on
% axis([0 600 -2.5 0.5])
% hold on
% ylabel('dh/dt  (ft/sec)','FontSize',12)
% xlabel('t  (sec)','FontSize',12)
% set(gca,'FontSize',11)
% title('Diver Velocity, dh/dt vs t','FontSize',11)
% 

 
