%  CRC File: Ch3_Ex3_1.m
%  Generates numerical values in Example 3.1 and plots FIGURE 3.3

clc; clear all; close all

x0=1; % given initial condition for y(t)
tfinal=2; % set final simulaion time 

for T=[0.01 0.025 0.05 0.1] 
       
   nfinal=tfinal/T; % calculate total number of discrete time steps
    
   t(1:nfinal)=0;  
   u(1:nfinal)=0;
   xA(1:nfinal)=0; 

   clear t u xA

%%%%% begin finding recursive solution of difference equation

   alpha=1-2*T;
   xA(1)=x0; % set initial value of yA(n)

   for n=1:nfinal          
     u(n)=3*n*T; % calculate input at t=nT  
     t(n+1)=n*T; % calculate (n+1)st value of t
     xA(n+1)=alpha*xA(n) + T*u(n); % calculate (n+1)st value of xA
   end % for n

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%% begin finding exact solution %%%%%

   ti=linspace(0,tfinal,200); % set points in t-interval for calculating x(t)
   xi=1.75*exp(-2*ti)+1.5*ti-0.75; % calculate exact solution x(t) at discrete points in vector ti

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

   if T==0.01
      subplot(2,2,1)
      del=10;
      plot(t(1:del:end),xA(1:del:end),'r.','MarkerSize',10) % plot approximate solution xA
      hold on
      grid on
      axis([0 2 0 2.5])
      set(gca,'XTick',[0:0.5:2],'FontSize',11)
      set(gca,'YTick',[0:0.5:2.5],'FontSize',11)
      plot(ti,xi,'b','LineWidth',1.3) % plot exact solution x(t)
      text(-0.2,2.8,'Exact and Approximate Solutions for Different Values of the Time Step T','FontSize',11)
      legend('x_A(n), n = 0,10,20,...','x(t), t \geq 0','Location','NorthWest')
      text(1.25,0.75,'T = 0.01','FontSize',11)

   elseif T==0.025
      subplot(2,2,2)
      del=4;
      plot(t(1:del:end),xA(1:del:end),'r.','MarkerSize',10) % plot approximate solution xA
      hold on
      grid on
      axis([0 2 0 2.5])
      set(gca,'XTick',[0:0.5:2],'FontSize',11)
      set(gca,'YTick',[0:0.5:2.5],'FontSize',11)
      plot(ti,xi,'b','LineWidth',1.3) % plot exact solution x(t)
      legend('x_A(n), n = 0,4,8,...','x(t), t \geq 0','Location','NorthWest')
      text(1.25,0.75,'T = 0.025','FontSize',11)    
    
   elseif T==0.05
      subplot(2,2,3)  
      del=2;
      plot(t(1:del:end),xA(1:del:end),'r.','MarkerSize',10) % plot approximate solution xA
      hold on
      grid on
      axis([0 2 0 2.5])
      set(gca,'XTick',[0:0.5:2],'FontSize',11)
      set(gca,'YTick',[0:0.5:2.5],'FontSize',11)
      plot(ti,xi,'b','LineWidth',1.3) % plot exact solution x(t)
      xlabel('t ','FontSize',12)
      legend('x_A(n), n = 0,2,4,...','x(t), t \geq 0','Location','NorthWest')
      text(1.25,0.75,'T = 0.05','FontSize',11)  
  
   elseif T==0.1
      subplot(2,2,4)  
      del=1;
      plot(t(1:del:end),xA(1:del:end),'r.','MarkerSize',10) % plot approximate solution xA
      hold on
      grid on
      axis([0 2 0 2.5])
      set(gca,'XTick',[0:0.5:2],'FontSize',11)
      set(gca,'YTick',[0:0.5:2.5],'FontSize',11)
      plot(ti,xi,'b','LineWidth',1.3) % plot exact solution y(t)
      xlabel('t ','FontSize',12)
      legend('x_A(n), n = 0,1,2,...','x(t), t \geq 0','Location','NorthWest')
      text(1.25,0.75,'T = 0.1','FontSize',11)

   end % if T
    
end % for T


%%%%% begin generate numbers for TABLE 3.1 %%%%%

clear t u xA

T=0.01;
nfinal=tfinal/T; % calculate total number of discrete time steps
alpha=1-2*T;
xA(1)=x0; % set initial value of xA(n)

for n=1:nfinal          
    u(n)=3*n*T; % calculate input at t=nT  
    t(n+1)=n*T; % calculate (n+1)st value of t
    xA(n+1)=alpha*xA(n) + T*u(n); % calculate (n+1)st value of xA
end % for n

for n=[1 21 51 101 151 201]
    xA(n)
    ti=(n-1)*T
    xi=1.75*exp(-2*ti)+1.5*ti-0.75
    err=100*(xA(n)-xi)/xi
end % for n

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%% begin generate numbers for TABLE 3.2 %%%%%

clear t u xA

T=0.1;
nfinal=tfinal/T; % calculate total number of discrete time steps
alpha=1-2*T;
xA(1)=x0; % set initial value of xA(n)

for n=1:nfinal          
    u(n)=3*n*T; % calculate input at t=nT  
    t(n+1)=n*T; % calculate (n+1)st value of t
    xA(n+1)=alpha*xA(n) + T*u(n); % calculate (n+1)st value of xA
end % for n

for n=[1 3 6 11 16 21]
    xA(n)
    ti=(n-1)*T
    xi=1.75*exp(-2*ti)+1.5*ti-0.75
    err=100*(xA(n)-xi)/xi
end % for n

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


