% File: Ch3_Ex3_10.m
% Generates numerical values for Tables 3.7 and 3.8 and plots Figure 3.23
% - Figure 3.28

close all, clc, clear all

R12=2; R2=0.5; A1=15; A2=10;
a11=-1/(A1*R12);
a12=1/(A1*R12);
a21=1/(A2*R12);
a22=-(R12+R2)/(A2*R12*R2);
A=[a11 a12; a21 a22];
b1=1/A1;
b2=1/A2;
B=[b1 0; 0 b2];

F1=0; F2=0;


%%%%% part a) begin find continuous transition matrix phi(t)
n11=[1 -a22];
n12=a12;
n21=a21;
n22=[1 -a11];
detA=a11*a22-a12*a21;
d=[1 -(a11+a22) detA];
[R11 P K11]=residue(n11,d); 
[R12 P K12]=residue(n12,d); 
[R21 P K21]=residue(n21,d); 
[R22 P K22]=residue(n22,d); 
eig(A); % continuus poles

H10=10; H20=0;
Hinit=[H10;H20]; % initial tank levels

for T=[0.1 1 2.5]
    T;
    %%%%% part c)
    phi_1_explicit=eye(2)+T*A; % explicit Euler phi(1)
    phi_1_improved=phi_1_explicit+0.5*(T*A)^2; % improved Euler phi(1)
    p1=P(1); p2=P(2); % continuous poles
    phi_11=R11(1)*exp(p1*T)+R11(2)*exp(p2*T);  % continuous phi_11(T)
    phi_12=R12(1)*exp(p1*T)+R12(2)*exp(p2*T);  % continuous phi_12(T)
    phi_21=R21(1)*exp(p1*T)+R21(2)*exp(p2*T);  % continuous phi_21(T)
    phi_22=R22(1)*exp(p1*T)+R22(2)*exp(p2*T);  % continuous phi_22(T)
    phi=[phi_11 phi_12; phi_21 phi_22]; % continuous 2x2 phi(T)
    
    %%%%% part d)
    HA_1_explicit=phi_1_explicit*Hinit; % explict Euler HA(1)
    HA_1_improved=phi_1_improved*Hinit; % improved Euler HA(1)
    H=phi*Hinit; % continuus H(T)
         
end % for T


%%%%% begin part e)
tfinal=100;
%%%%% begin finding discrete responses H1A(n) and H2A(n)

%%% Choose either T=0.1 or T=1 or T=2.5 and comment out the other two
T=0.1;
T=1;
T=2.5;

phi_1_explicit=eye(2)+T*A; % explicit Euler phi(1)
phi_1_improved=phi_1_explicit+0.5*(T*A)^2; % improved Euler phi(1)
nfinal=round(tfinal/T);
H1A(1:nfinal)=0; % pre-allocate H1A array
H2A(1:nfinal)=0; % pre-allocate H2A array
H1A(1)=H10; H2A(1)=H20;
tn(1)=0;

%%% Choose either D=1 for explicit Euler or D=2 for improved Euler and comment out the other
%D=1; % Use explicit Euler
D=2; % Use improved Euler

for n=1:nfinal
    tn(n+1)=n*T;
    if D==1
       H1A(n+1)=phi_1_explicit(1,1)*H1A(n) + phi_1_explicit(1,2)*H2A(n);
       H2A(n+1)=phi_1_explicit(2,1)*H1A(n) + phi_1_explicit(2,2)*H2A(n);
    elseif D==2
       H1A(n+1)=phi_1_improved(1,1)*H1A(n) + phi_1_improved(1,2)*H2A(n);
       H2A(n+1)=phi_1_improved(2,1)*H1A(n) + phi_1_improved(2,2)*H2A(n);
    end  % if D==1
end % for n

%%%%% begin finding continuous responses H1(t)and H2(t)
dt=0.05;
nfinal=round(tfinal/dt);
H1(1:nfinal)=0; % pre-allocate H1 array
H2(1:nfinal)=0; % pre-allocate H2 array
for n=1:nfinal
    t(n)=(n-1)*dt;
    phi_11=R11(1)*exp(p1*t(n))+R11(2)*exp(p2*t(n));  % continuous phi_11(t)
    phi_12=R12(1)*exp(p1*t(n))+R12(2)*exp(p2*t(n));  % continuous phi_12(t)
    phi_21=R21(1)*exp(p1*t(n))+R21(2)*exp(p2*t(n));  % continuous phi_21(t)
    phi_22=R22(1)*exp(p1*t(n))+R22(2)*exp(p2*t(n));  % continuous phi_22(t)
    phi=[phi_11 phi_12; phi_21 phi_22]; % continuous 2x2 phi(T)
    H1(n)=phi_11*H10 + phi_12*H20; % H1(t)
    H2(n)=phi_21*H10 + phi_22*H20; % H2(t)
end % for n

if D==1 && T==0.1
   figure(1)
   freq=20;
   subplot(2,1,1)
   plot(tn(1:freq:end),H1A(1:freq:end),'r.','MarkerSize',10)
   hold on
   grid on
   plot(t,H1,'b','LineWidth',1.3)
   set(gca,'XTick',[0:10:100])
   set(gca,'YTick',[0:2.5:10])
   set(gca,'FontSize',11)
   xlabel('t  (min)','FontSize',11)
   ylabel('H_1  (ft)','FontSize',11)
   title('Discrete (Explicit Euler, T = 0.1 min) and Continuous Tank Levels','FontSize',11)
   text(50,8,'H_{1,A}(n), n = 0,20,40,...,1000','FontSize',11) 
   plot([45],[8],'r.','MarkerSize',10)
   text(50,5.25,'H_1(t), 0 \leq t \leq 100','FontSize',11) 
   plot([43 47],[5.25 5.25],'b','LIneWidth',1.3)
  
   subplot(2,1,2)
   plot(tn(1:freq:end),H2A(1:freq:end),'r.','MarkerSize',10)
   grid on
   hold on
   plot(t,H2,'b','LineWidth',1.3)
   set(gca,'XTick',[0:10:100])
   set(gca,'YTick',[0:0.5:2])
   set(gca,'FontSize',11)
   xlabel('t  (min)','FontSize',11)
   ylabel('H_2  (ft)','FontSize',11)
   text(50,1.7,'H_{2,A}(n), n = 0,20,40,...,1000','FontSize',11) 
   plot([45],[1.7],'r.','MarkerSize',10)
   text(50,1.2,'H_2(t), 0 \leq t \leq 100','FontSize',11) 
   plot([43 47],[1.2 1.2],'b','LIneWidth',1.3)
   
elseif D==1 && T==1
   figure(2)
   freq=2;
   subplot(2,1,1)
   plot(tn(1:freq:end),H1A(1:freq:end),'r.','MarkerSize',10)
   hold on
   grid on
   plot(t,H1,'b','LineWidth',1.3)
   set(gca,'XTick',[0:10:100])
   set(gca,'YTick',[0:2.5:10])
   set(gca,'FontSize',11)
   xlabel('t  (min)','FontSize',11)
   ylabel('H_1  (ft)','FontSize',11)
   title('Discrete (Explicit Euler, T = 1 min) and Continuous Tank Levels','FontSize',11)
   text(50,8,'H_{1,A}(n), n = 0,20,40,...,1000','FontSize',11) 
   plot([45],[8],'r.','MarkerSize',10)
   text(50,5.25,'H_1(t), 0 \leq t \leq 100','FontSize',11) 
   plot([43 47],[5.25 5.25],'b','LIneWidth',1.3)
  
   subplot(2,1,2)
   plot(tn(1:freq:end),H2A(1:freq:end),'r.','MarkerSize',10)
   grid on
   hold on
   plot(t,H2,'b','LineWidth',1.3)
   set(gca,'XTick',[0:10:100])
   set(gca,'YTick',[0:0.5:2])
   set(gca,'FontSize',11)
   xlabel('t  (min)','FontSize',11)
   ylabel('H_2  (ft)','FontSize',11) 
   text(50,1.7,'H_{2,A}(n), n = 0,20,40,...,1000','FontSize',11) 
   plot([45],[1.7],'r.','MarkerSize',10)
   text(50,1.2,'H_2(t), 0 \leq t \leq 100','FontSize',11) 
   plot([43 47],[1.2 1.2],'b','LIneWidth',1.3)
   
elseif D==1 && T==2.5
   figure(3)
   freq=1;
   subplot(2,1,1)
   plot(tn(1:freq:end),H1A(1:freq:end),'r.','MarkerSize',10)
   hold on
   grid on
   plot(t,H1,'b','LineWidth',1.3)
   set(gca,'XTick',[0:10:100])
   set(gca,'YTick',[0:2.5:10])
   set(gca,'FontSize',11)
   xlabel('t  (min)','FontSize',11)
   ylabel('H_1  (ft)','FontSize',11)
   title('Discrete (Explicit Euler, T = 2.5 min) and Continuous Tank Levels','FontSize',11)
   text(50,8,'H_{1,A}(n), n = 0,20,40,...,1000','FontSize',11) 
   plot([45],[8],'r.','MarkerSize',10)
   text(50,5.25,'H_1(t), 0 \leq t \leq 100','FontSize',11) 
   plot([43 47],[5.25 5.25],'b','LIneWidth',1.3)
  
   subplot(2,1,2)
   plot(tn(1:freq:end),H2A(1:freq:end),'r.','MarkerSize',10)
   grid on
   hold on
   plot(t,H2,'b','LineWidth',1.3)
   set(gca,'XTick',[0:10:100])
   set(gca,'YTick',[0:0.5:2])
   set(gca,'FontSize',11)
   xlabel('t  (min)','FontSize',11)
   ylabel('H_2  (ft)','FontSize',11)
   text(50,1.7,'H_{2,A}(n), n = 0,20,40,...,1000','FontSize',11) 
   plot([45],[1.7],'r.','MarkerSize',10)
   text(50,1.2,'H_2(t), 0 \leq t \leq 100','FontSize',11) 
   plot([43 47],[1.2 1.2],'b','LIneWidth',1.3)
      
end % if D==1 && T==0.1

if D==2 && T==0.1                
   figure(4)
   freq=20;
   subplot(2,1,1)
   plot(tn(1:freq:end),H1A(1:freq:end),'r.','MarkerSize',10)
   hold on
   grid on
   plot(t,H1,'b','LineWidth',1.3)
   set(gca,'XTick',[0:10:100])
   set(gca,'YTick',[0:2.5:10])
   set(gca,'FontSize',11)
   xlabel('t  (min)','FontSize',11)
   ylabel('H_1  (ft)','FontSize',11)
   title('Discrete (Improved Euler, T = 0.1 min) and Continuous Tank Levels','FontSize',11)
   text(50,8,'H_{1,A}(n), n = 0,20,40,...,1000','FontSize',11) 
   plot([45],[8],'r.','MarkerSize',10)
   text(50,5.25,'H_1(t), 0 \leq t \leq 100','FontSize',11) 
   plot([43 47],[5.25 5.25],'b','LIneWidth',1.3)
  
   subplot(2,1,2)
   plot(tn(1:freq:end),H2A(1:freq:end),'r.','MarkerSize',10)
   grid on
   hold on
   plot(t,H2,'b','LineWidth',1.3)
   set(gca,'XTick',[0:10:100])
   set(gca,'YTick',[0:0.5:2])
   set(gca,'FontSize',11)
   xlabel('t  (min)','FontSize',11)
   ylabel('H_2  (ft)','FontSize',11)
   text(50,1.7,'H_{2,A}(n), n = 0,20,40,...,1000','FontSize',11) 
   plot([45],[1.7],'r.','MarkerSize',10)
   text(50,1.2,'H_2(t), 0 \leq t \leq 100','FontSize',11) 
   plot([43 47],[1.2 1.2],'b','LIneWidth',1.3)
   
elseif D==2 && T==1
   figure(5)
   freq=2;
   subplot(2,1,1)
   plot(tn(1:freq:end),H1A(1:freq:end),'r.','MarkerSize',10)
   hold on
   grid on
   plot(t,H1,'b','LineWidth',1.3)
   set(gca,'XTick',[0:10:100])
   set(gca,'YTick',[0:2.5:10])
   set(gca,'FontSize',11)
   xlabel('t  (min)','FontSize',11)
   ylabel('H_1  (ft)','FontSize',11)
   title('Discrete (Improved Euler, T = 1 min) and Continuous Tank Levels','FontSize',11)
   text(50,8,'H_{1,A}(n), n = 0,20,40,...,1000','FontSize',11) 
   plot([45],[8],'r.','MarkerSize',10)
   text(50,5.25,'H_1(t), 0 \leq t \leq 100','FontSize',11) 
   plot([43 47],[5.25 5.25],'b','LIneWidth',1.3)
  
   subplot(2,1,2)
   plot(tn(1:freq:end),H2A(1:freq:end),'r.','MarkerSize',10)
   grid on
   hold on
   plot(t,H2,'b','LineWidth',1.3)
   set(gca,'XTick',[0:10:100])
   set(gca,'YTick',[0:0.5:2])
   set(gca,'FontSize',11)
   xlabel('t  (min)','FontSize',11)
   ylabel('H_2  (ft)','FontSize',11)
   text(50,1.7,'H_{2,A}(n), n = 0,20,40,...,1000','FontSize',11) 
   plot([45],[1.7],'r.','MarkerSize',10)
   text(50,1.2,'H_2(t), 0 \leq t \leq 100','FontSize',11) 
   plot([43 47],[1.2 1.2],'b','LIneWidth',1.3)
   
elseif D==2 && T==2.5
   figure(6)
   freq=1;
   subplot(2,1,1)
   plot(tn(1:freq:end),H1A(1:freq:end),'r.','MarkerSize',10)
   hold on
   grid on
   plot(t,H1,'b','LineWidth',1.3)
   set(gca,'XTick',[0:10:100])
   set(gca,'YTick',[0:2.5:10])
   set(gca,'FontSize',11)
   xlabel('t  (min)','FontSize',11)
   ylabel('H_1  (ft)','FontSize',11)
   title('Discrete (Improved Euler, T = 2.5 min) and Continuous Tank Levels','FontSize',11)
   text(50,8,'H_{1,A}(n), n = 0,20,40,...,1000','FontSize',11) 
   plot([45],[8],'r.','MarkerSize',10)
   text(50,5.25,'H_1(t), 0 \leq t \leq 100','FontSize',11) 
   plot([43 47],[5.25 5.25],'b','LIneWidth',1.3)
  
   subplot(2,1,2)
   plot(tn(1:freq:end),H2A(1:freq:end),'r.','MarkerSize',10)
   grid on
   hold on
   plot(t,H2,'b','LineWidth',1.3)
   set(gca,'XTick',[0:10:100])
   set(gca,'YTick',[0:0.5:2])
   set(gca,'FontSize',11)
   xlabel('t  (min)','FontSize',11)
   ylabel('H_2  (ft)','FontSize',11)
   text(50,1.7,'H_{2,A}(n), n = 0,20,40,...,1000','FontSize',11) 
   plot([45],[1.7],'r.','MarkerSize',10)
   text(50,1.2,'H_2(t), 0 \leq t \leq 100','FontSize',11) 
   plot([43 47],[1.2 1.2],'b','LIneWidth',1.3)
   
end % if D==2 && T==0.1


    






