% File: Ch3_Ex3_8.m
% Generates numerical values and plots Figure 3.16, 3.17 and 3.18

close all, clc, clear all

R12=2; R2=0.5; A1=15; A2=10;
a11=-1/(A1*R12);
a12=1/(A1*R12);
a21=1/(A2*R12);
a22=-(R12+R2)/(A2*R12*R2);
A=[a11 a12; a21 a22];
b1=1/A1;
b2=1/A2;
B=[b1 0; 0 b2];

F1=5; F2=2;

tfinal=100;
H10=0; H20=0;

u=[F1; F2];
I=eye(2);

%%%%%%%%%% begin explicit Euler %%%%%%%%%%

%%% choose value of T and freq and comment out the other
T=0.25; freq=10;
T=7.5; freq=1;

H1A(1)=H10; H2A(1)=H20;
t(1)=0;
HA=[H10; H20];
G=I+T*A;;
TBu=T*B*u;
nfinal=round(tfinal/T);
for n=1:nfinal
   t(n+1)=n*T; 
   HA=G*HA+TBu; 
   H1A(n+1)=HA(1,1);
   H2A(n+1)=HA(2,1);
end % for

H1_final=H1A(end); % last value for discrete H1
H2_final=H2A(end); % last value for discrete H2
Hss=-inv(A)*B*u; % steady-state values for H1 and H2 based on state equations
H1_ss=Hss(1); % steady-state value for H1 based on state equations
H2_ss=Hss(2); % steady-state value for H2 based on state equations

figure(1) %%%%% plot explicit Euler %%%%%
subplot(2,1,1)
plot(t(1:freq:end),H1A(1:freq:end),'r.','MarkerSize',10)
axis([0 tfinal 0 15])
hold on
grid on
plot([0 tfinal],[H1_ss H1_ss],'k--')
text(10,11.5,'(H_1)_{ss} = 13.5 ft','FontSize',11)
xlabel('t  (min)','FontSize',12)
ylabel('H_1  (ft)','FontSize',12)
if T==0.25
title('Discrete (Explicit Euler with T=0.25 min) and Continuous Responses','FontSize',10)
text(60,7.5,'H_{1,A}(n), n = 0,10,20,..','FontSize',11)
else
title('Discrete (Explicit Euler with T=7.5 min) and Continuous Responses','FontSize',10)
text(60,7.5,'H_{1,A}(n), n = 0,1,2,..','FontSize',11)
end % if T
set(gca,'XTick',[0:10:tfinal],'FontSize',11)
plot([55],[7.5],'r.','MarkerSize',10)
text(60,4,'H_1(t), t \geq 0','FontSize',11)
plot([53 57],[4 4],'b','LineWidth',1.3)

subplot(2,1,2)
plot(t(1:freq:end),H2A(1:freq:end),'r.','MarkerSize',10)
hold on
grid on
plot([0 tfinal],[H2_ss H2_ss],'k--')
text(10,2.9,'(H_2)_{ss} = 3.5 ft','FontSize',11)
xlabel('t  (min)','FontSize',12)
ylabel('H_2  (ft)','FontSize',12)
set(gca,'XTick',[0:10:tfinal],'FontSize',11)
set(gca,'YTick',[0:4],'FontSize',11)
plot([55],[1.8],'r.','MarkerSize',10)
if T==0.25
text(60,1.8,'H_{2,A}(n), n = 0,10,20,..','FontSize',11)
else
text(60,1.8,'H_{2,A}(n), n = 0,1,2,...','FontSize',11)
end % if T
text(60,0.75,'H_2(t), t \geq 0','FontSize',11)
plot([53 57],[0.75 0.75],'b','LineWidth',1.3)


%%%%%%%%%% begin implicit Euler %%%%%%%%%%
clear H1A H2A 

H1A(1)=H10; H2A(1)=H20;
%t(1)=0;
HA=[H10; H20];
G=inv(I-T*A);
for n=1:nfinal
   %t(n+1)=n*T; 
   HA=G*(HA+TBu); 
   H1A(n+1)=HA(1,1);
   H2A(n+1)=HA(2,1);
end % for

 
Hss1=[H1A(end); H2A(end)];  %  last values of H1 and H2

figure(2) %%%%% plot implicit Euler %%%%%
subplot(2,1,1)
plot(t(1:freq:end),H1A(1:freq:end),'r.','MarkerSize',10)
axis([0 tfinal 0 15])
hold on
grid on
plot([0 tfinal],[H1_ss H1_ss],'k--')
text(10,11.5,'(H_1)_{ss} = 13.5 ft','FontSize',11)
xlabel('t  (min)','FontSize',12)
if T==0.25
title('Discrete (Implicit Euler with T=0.25 min) and Continuous Responses','FontSize',10)
text(60,7.5,'H_{1,A}(n), n = 0,10,20,..','FontSize',11)
else
title('Discrete (Implicit Euler with T=7.5 min) and Continuous Responses','FontSize',10)
text(60,7.5,'H_{1,A}(n), n = 0,1,2,..','FontSize',11)
end % if T

set(gca,'XTick',[0:10:tfinal],'FontSize',11)
plot([55],[7.5],'r.','MarkerSize',10)
text(60,7.5,'H_{1,A}(n), n = 0,10,20,..','FontSize',11)
text(60,4,'H_1(t), t \geq 0','FontSize',11)
plot([53 57],[4 4],'b','LineWidth',1.3)

subplot(2,1,2)
plot(t(1:freq:end),H2A(1:freq:end),'r.','MarkerSize',10)
hold on
grid on
plot([0 tfinal],[H2_ss H2_ss],'k--')
text(10,2.9,'(H_2)_{ss} = 3.5 ft','FontSize',11)
xlabel('t  (min)','FontSize',12)
ylabel('H_2  (ft)','FontSize',12)
set(gca,'XTick',[0:10:tfinal],'FontSize',11)
set(gca,'YTick',[0:4],'FontSize',11)
plot([55],[1.8],'r.','MarkerSize',10)
if T==0.25
text(60,1.8,'H_{2,A}(n), n = 0,10,20,..','FontSize',11)
else
text(60,1.8,'H_{2,A}(n), n = 0,1,2,...','FontSize',11)
end % if T
text(60,0.75,'H_2(t), t \geq 0','FontSize',11)
plot([53 57],[0.75 0.75],'b','LineWidth',1.3)


%%%%%%%%%% begin exact H1 solution %%%%%%%%%%

H1_ss_TF=(-a22*b1*F1+a12*b2*F2)/(a11*a22-a12*a21); % steady-state H1 based on transfer functions H1/F1 and H1/F2
n=[b1*F1 -a22*b1*F1+a12*b2*F2];
d=[1 -(a11+a22) a11*a22-a12*a21 0];
[R,P,K] = residue(n,d);
c1=R(1); c2=R(2); c3=R(3);
p1=P(1); p2=P(2); p3=P(3);
eig(A); % check on results from residue function
ti=linspace(0,tfinal,250);
H1i=c1*exp(p1*ti)+c2*exp(p2*ti)+c3*exp(p3*ti);


figure(1) %%%%% begin plot exact H1 and H2 on explict Euler plots %%%%%
subplot(2,1,1) %%%%% go to explicit Euler plot for H1
plot(ti,H1i,'b','LineWidth',1.3) %%%%% plot exact H1 on explicit Euler plot

%%%%%%%%%% begin exact H2 solution %%%%%%%%%%

H2_ss_TF=(a21*b1*F1-a11*b2*F2)/(a11*a22-a12*a21); % steady-state H2 based on transfer functions H1/F1 and H1/F2
n=[b2*F2 a21*b1*F1-a11*b2*F2];
d=[1 -(a11+a22) a11*a22-a12*a21 0];
[R,P,K] = residue(n,d);
c1=R(1); c2=R(2); c3=R(3);
p1=P(1); p2=P(2); p3=P(3);
ti=linspace(0,tfinal,250);
H2i=c1*exp(p1*ti)+c2*exp(p2*ti)+c3*exp(p3*ti);

subplot(2,1,2) % go to explicit Euler plot for H2
plot(ti,H2i,'b','LineWidth',1.3) %%%%% plot exact H2 on explicit Euler plot


figure(2) %%%%% begin plot exact H1 and H2 on explict Euler plots %%%%%
subplot(2,1,1) %%%%% go to implicit Euler plot for H1 %%%%%
plot(ti,H1i,'b','LineWidth',1.3)

subplot(2,1,2) %%%%% go to implicit Euler plot for H1 %%%%%
plot(ti,H2i,'b','LineWidth',1.3) %%%%% plot exact H2 on implicit Euler plot
