% File: Ch3_step.m
% Generates values for discrete, continuous 2nd order step responses and Plots Figure 3.29

clc
clear all
close all

T=0.5; rho=0.5; wn=0.4; K=2;
wd=sqrt(1-rho*rho)*wn;

u=[1];
I=[1 0; 0 1];
A=[0 1;-wn*wn -2*rho*wn];
B=[0;K*wn*wn];
C=[1 0];
D=[0];
G=I + T*A + (1/2)*(T*A)^2;
H=(1/2)*T*T*A*B + T*B;
xA_ss=inv((I-G))*H*u;

tau=1/(rho*wn);
Tf=5*tau;
nf=round(Tf/T);

xA=[0;0];
for n=1:nf+5
    t(n)=n*T;
    xA=G*xA+H*u;
    x1A(n)=xA(1);
end % n

v=[0 28 0 2.5];
t=[0 t]; x1A=[0 x1A];
plot(t,x1A,'.r','MarkerSize',11)
grid on
axis(v)
hold on
set(gca,'XTick',[0:2:28],'FontSize',11)
set(gca,'YTick',[0:0.25:2.5],'FontSize',11)
xlabel('t  \rm(s)','FontSize',12)
ylabel('x_{\rm1}  \rm(ft)','FontSize',12)

ti=linspace(0,27.5,500);
c1=cos(wd*ti);
s1=sin(wd*ti);
z1=c1+(rho*wn/wd)*s1;
x1i=K*(1-exp(-rho*wn*ti).*z1);
plot(ti,x1i,'b','LineWidth',1.3)
text(12,1.1,'x_{1,A}(n), n = 0,1,2,3,...,55','FontSize',12)
text(12,0.80,'x_1(t), 0 \leq t \leq 27.5','FontSize',12)
text(8,1.57,'Modified Euler Integration (T = 0.5 s)','FontSize',12)
plot([11.0],[1.1],'.r','MarkerSize',11)
plot([10.6 11.4],[0.80 0.80],'-b','LineWidth',1.3)
title('Continuous and Discrete Step Responses','FontSize',11)
ti=0:2.5:27.5;
c1=cos(wd*ti);
s1=sin(wd*ti);
z1=c1+(rho*wn/wd)*s1;
x1i=K*(1-exp(-rho*wn*ti).*z1);



    
