% m-file Ch4_CaseStudy2.m

clc, close all, clear all

%% set sampling time and filter coeffcients
Ts=0.004; % sampling time
f0=60; % notch (noise) frequency (Hz)
w0=2*pi*f0;  % notch frequency (rad/sec)


%%%%% begin create ecg signal with 60 Hz sine wave noise
load Ch4_clean_ecg_10sec t s % loads 10 sec of clean ecg signal sampled every T=0.004 sec  
Amp_sine=0.25; % amplitude of sine wave noise 
ifinal=round(t(end)/Ts);
for i=1:ifinal+1
   tt=(i-1)*Ts;    
   sine_noise(i)=Amp_sine*sin(w0*tt); %sampled noise at Ts=0.004 sec intervals    
end
sine_noise=sine_noise'; % make dimensions of sine_noise compatible with s
sine_noisy_ecg=s+sine_noise;
save sine_noisy_ecg_data  t sine_noisy_ecg % saves 10 sec of sine noisy ecg signal 
figure(1)
plot(t,sine_noisy_ecg,'b')
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:5])
set(gca,'YTick',[0:0.2:1.6])
axis([0 5 0 1.6])
xlabel('t  (s)','FontSize',12)
ylabel('u(t)','FontSize',12)
title('Filter Input: ecg + noise','FontSize',11)


%%%%% begin frequency response (Q=10) %%%%%
Q=10;
delw=w0/Q;  % 3 db width (rad/sec)
b=1/(1+tan(0.5*w0*Ts/Q));
b2=1;
b1=-2*cos(w0*Ts);
b0=1;
a1=-2*b*cos(w0*Ts);
a0=2*b-1;
w_nyq=pi/Ts; % nyquist frequency
wmax=w_nyq;
w=linspace(0,wmax,1000);
z=exp(j*w*Ts);
Hz=b*(b2*z.^2 + b1*z+b0)./(z.^2 +a1*z +a0); % frequency response function
MagHz=abs(Hz);  % magnitude of H(z)
MagHz_sq=MagHz.^2; % |H(z)|^2
wHz=w/(2*pi); % frequency in Hz

figure(2)
plot(wHz,MagHz_sq,'b','LineWidth',1.3)
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:10:100])
set(gca,'YTick',[0:0.1:1])
axis([0 100 -0.05 1.05])
hold on
w1=(w0-0.5*delw)/(2*pi);
w2=(w0+0.5*delw)/(2*pi);
plot([w1 w2],[0.5 0.5],'.r','MarkerSize',12)
plot([w1 w2],[0.5 0.5],'--')
text(10,0.51,'\Delta\omega = 63 Hz - 57 Hz = 6 Hz','FontSize',12)  
text(40,0,'\omega_0 = 60 Hz','FontSize',12)
text(87.5,0.75,'3 db','FontSize',12)
plot([97 97],[0.5 0.9965],'k')
plot([96 98],[0.5 0.5],'k')
xlabel('\omega  (Hz)','FontSize',12)
ylabel('|H(e^{ j\omegaT})|^2','FontSize',12)
title('Magnitude Squared Function of Notch Filter (Q = 10)','FontSize',11)
x2=log10(wmax);
wmin=1;
x1=log10(wmin);
w=logspace(x1,x2,1000);
z=exp(j*w*Ts);
Hz=b*(b2*z.^2 + b1*z+b0)./(z.^2 +a1*z +a0); % frequency response function
MagHz_db=20*log10(abs(Hz));  % magnitude of H(z) in db
wHz=w/(2*pi); % frequency in Hz

figure(3)
semilogx(wHz,MagHz_db,'b')
grid on
set(gca,'FontSize',11)
axis([wmin w_nyq/(2*pi) -68 5])
text(45,-64,'\omega_0 = 60 Hz','FontSize',12)
xlabel('\omega  (Hz)','FontSize',12)
ylabel('|H\rm(e^{ j\omegaT}|   (db)','FontSize',12)
title('Magnitude Function of Notch Filter (Q = 10)','FontSize',11)


%%%%% begin filter response (Q=10) %%%%%
y(1)=0; y(2)=0; % initialize filter outputs
u=sine_noisy_ecg;  % store filter input in array u
for n=3:length(t)  
    y(n)=-a1*y(n-1)-a0*y(n-2)+b*(b2*u(n)+b1*u(n-1)+b0*u(n-2)); % filter output
end

figure(4)
subplot(2,1,1)
plot(t,u,'b','LineWidth',1.3)
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:5])
ylabel('u(t)','FontSize',12)
axis([0 5 0 1.6])
title('Filter Input: ecg + noise','FontSize',11)

subplot(2,1,2)
plot(t,y,'b','LineWidth',1.3)
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:5])
xlabel('t  (s)','FontSize',12)
ylabel('y(t)','FontSize',12)
axis([0 5 0 1.5])
title('Filter Output (Q = 10)','FontSize',11)


%%%%% begin frequency response (Q=50) %%%%%
Q=50;
delw=w0/Q;  % 3 db width (rad/sec)
b=1/(1+tan(0.5*w0*Ts/Q));
b2=1;
b1=-2*cos(w0*Ts);
b0=1;
a1=-2*b*cos(w0*Ts);
a0=2*b-1;
w_nyq=pi/Ts; % nyquist frequency
wmax=w_nyq;
w=linspace(0,wmax,1000);
z=exp(j*w*Ts);
Hz=b*(b2*z.^2 + b1*z+b0)./(z.^2 +a1*z +a0); % frequency response function
MagHz=abs(Hz);  % magnitude of H(z)
MagHz_sq=MagHz.^2; % |H(z)|^2
wHz=w/(2*pi); % frequency in Hz

figure(5)
plot(wHz,MagHz_sq,'b','LineWidth',1.3)
grid on
axis([0 100 -0.05 1.05])
set(gca,'FontSize',11)
set(gca,'XTick',[0:10:100])
set(gca,'YTick',[0:0.1:1])
hold on
w1=(w0-0.5*delw)/(2*pi);
w2=(w0+0.5*delw)/(2*pi);
plot([w1 w2],[0.5 0.5],'.r','MarkerSize',8)
plot([w1 w2],[0.5 0.5],':')
text(4.0,0.51,'\Delta\omega = 60.6 Hz - 59.4 Hz = 1.2 Hz','FontSize',12)  
text(39.5,0,'\omega_0 = 60 Hz','FontSize',12)
text(88,0.75,'3 db','FontSize',12)
plot([97 97],[0.5 1],'k')
plot([96 98],[0.5 0.5],'k')
xlabel('\omega  (Hz)','FontSize',12)
ylabel('|H\rm(e^{ j\omegaT})|^{2}','FontSize',12)
title('Magnitude Squared Function of Notch Filter (Q = 50)','FontSize',12)
x2=log10(wmax);
wmin=1;
x1=log10(wmin);
w=logspace(x1,x2,1000);
z=exp(j*w*Ts);
Hz=b*(b2*z.^2 + b1*z+b0)./(z.^2 +a1*z +a0); % frequency response function
MagHz_db=20*log10(abs(Hz));  % magnitude of H(z) in db
wHz=w/(2*pi); % frequency in Hz
  
figure(6)
semilogx(wHz,MagHz_db,'b')
grid on
set(gca,'FontSize',11)
set(gca,'YTick',[-50:5:5])
axis([wmin w_nyq/(2*pi) -53 5])
text(44.5,-50,'\omega_0 = 60 Hz','FontSize',12)
xlabel('\omega  (Hz)','FontSize',12)
ylabel('|H(e^{ j\omegaT})|   (db)','FontSize',12)
title('Magnitude Function of Notch Filter (Q = 50)','FontSize',11)


%%%%% begin filter response (Q=50) %%%%%
y(1)=0; y(2)=0; % initialize filter outputs
%u=noisy_ecg;  % store filter input in array u
for n=3:length(t)  
    y(n)=-a1*y(n-1)-a0*y(n-2)+b*(b2*u(n)+b1*u(n-1)+b0*u(n-2)); % filter output
end

figure(7)
subplot(2,1,1)
plot(t,u,'b','LineWidth',1.3)
axis([0 5 0 1.6])
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:5])
ylabel('u(t)','FontSize',12)
title('Filter Input: ecg + noise','FontSize',11)

subplot(2,1,2)
plot(t,y,'b','LineWidth',1.3)
axis([0 5 0 1.6])
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:5])
xlabel('t  (s)','FontSize',12)
ylabel('y(t)','FontSize',12)
title('Filter Output (Q = 50)','FontSize',11)





    
    
    
    
    
    
    
    
    
    
    
    
    

