% m-file Ch4_Ex4_33.m
% Plots Figures 4.73 - 4.75
clc; close all; clear all

tau=0.25; 
T=tau/10;
w_s=2*pi/T;
w_nyq=pi/T;

w=logspace(-1,log10(w_nyq),1000);
z=exp(j*w*T);
H=(T/tau)./(z-1+(T/tau));
magH=abs(H);
magH=20*log10(magH);
ArgH=(180/pi)*angle(H);

subplot(2,1,1)
semilogx(w,magH,'LineWidth',1.3)
grid on
hold on
semilogx([3 3],[-27.5 -1.78],'k--','LineWidth',0.7)
semilogx([0.1 3],[-1.78 -1.78],'k--','LineWidth',0.7)
axis([0.1 w_nyq -27.5 2.5])
xlabel('\omega   (rad/s)','FontSize',12)
ylabel('|H(e^{ j\omegaT})|   (db)','FontSize',12)
set(gca,'FontSize',11)
title('Bode Plot of Frequency Response Function H(e^{ j\omegaT} )','FontSize',11)
text(0.12,-8,'T = 0.025 s','FontSize',12)
text(0.12,-15,'\omega_s = 2\pi/T = 80\pi rad/s','FontSize',12)
text(0.12,-23,'\omega_N = 0.5\omega_s = 40\pi rad/s','FontSize',12)
text(3.3,-23,'\omega = 3 rad/s','FontSize',12)

subplot(2,1,2)
semilogx(w,ArgH,'Linewidth',1.3)
grid on
hold on
semilogx([3 3],[-175 -37.63],'k--','LineWidth',0.7)
semilogx([0.1 3],[-37.63 -37.63],'k--','LineWidt',0.7)
ylabel('Arg H(e^{ j\omegaT})   (deg)','FontSize',12)
xlabel('\omega   (rad/s)','FontSize',12)
set(gca,'FontSize',11)
axis([0.1 w_nyq -175 15])
text(3.3,-150,'\omega = 3 rad/s','FontSize',12)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(2)
num=T/tau;
den=[1 -1+T/tau];
SYS=tf(num,den,T);
bode(SYS,{0.1,w_nyq})
grid on
w=3; A=2;
wT=w*T;
MagH_w=0.1/sqrt(1.81-1.8*cos(wT)) 
MagH_w_db=20*log10(MagH_w)
ArgH_w=-atan(sin(wT)/(cos(wT)-0.9)) 
ArgH_w_deg=ArgH_w*(180/pi)

figure(3)
[MAG,PHASE] = bode(SYS,w);
MAG_db=20*log10(MAG);
PHASE_rad=PHASE*(pi/180);
tfinal=5;
t=linspace(0,tfinal,500);
y=0.96*(exp(-4*t)+(4/3)*sin(w*t)-cos(w*t));
plot(t,y,'b','LineWidth',1.3)
grid on
axis([0 5 -1.75 1.75]) 
hold on
kfinal=round(tfinal/T);
k=1:kfinal;
yk=A*MAG*sin(k*wT+PHASE_rad);
uk=2*sin(k*wT);
tk=k*T;
plot(tk,yk,'.r','MarkerSize',8)
plot([0 5],[0 0],'k','LineWidth',1.2)
text(2.7,-1,'y(t)','FontSize',12)
plot([2.4 2.6],[-1.05 -1.05],'b','LineWidth',1.3)
text(2.7,-1.3,'(y_k)_{ss}','FontSize',12)
plot([2.5],[-1.3],'.r','MarkerSize',8)
xlabel('t  (s)','FontSize',12)
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:5])
title('Continuous Response and Discrete Steady-State Response','FontSize',11)
n=round(4*tau/T+1);
plot([4*tau 4*tau],[-2.25 y(n)],'--k')
text(0.2,-0.9,'transient','FontSize',12)
text(0.2,-1.1,'period','FontSize',12)
text(0.08,-1.35,'(4\tau = 1 s)','FontSize',12)

figure(4)
plot(k,uk,'.b','MarkerSize',8)
grid on
hold on
plot(k,yk,'.r','MarkerSize',8)
axis([0 200 -2.2 2.2])
set(gca,'FontSize',11)
set(gca,'XTick',[0:25:200])
text(82,1.55,'u_k','FontSize',13)
text(134,0.6,'(y_k)_{ss}','FontSize',12)
xlabel('k','FontSize',12)
title('Discrete System Input and Sinusoidal Output at Steady-state','FontSize',11)

figure(5)
plot(k,uk,'.--b','MarkerSize',9)
grid on
hold on
plot(k,yk,'.--r','MarkerSize',9)
axis([90 127 1 2.3])
set(gca,'FontSize',11)
text(95.3,1.42,'u_k','FontSize',13)
title('Graphical Verification of Frequency Response Characteristics','FontSize',11)
plot([105 105],[2*sin(105*wT)  2.3],'--k')
plot([114 114],[A*MAG*sin(114*wT+PHASE_rad) 2.3],'--k')
plot([105 114],[2.15 2.15],'k')
%plot([114 130],[A*MAG*sin(114*wT+PHASE_rad) A*MAG*sin(114*wT+PHASE_rad)],'k')
text(105.23,2.2,'\Deltak=114-105=9','FontSize',11)
text(117,1.7,'Max (y_k)_{ss}','FontSize',12)
plot([114 116.5],[1.63 1.70],'k')
xlabel('k','FontSize',13)
text(105.25,1.22,'(y_k)_{ss}','FontSize',13)