% m-file Ch4_Fig4_32_and_Fig4_33.m
% Plots Figure 4.32 and Figure 4.33
clear all; close all;clc

KC=1;
KA=2; tauA=0.25;
KP=8; tauP=4;
KT=0.1; tauT=0.003;

sysC=KC;
sysA=tf(KA,[tauA 1]);
sysP=tf(KP,[tauP 1 0]);
sysT=tf(KT,[tauT 1]);

sysCA=series(sysC,sysA);
sysCAP=series(sysCA,sysP);
sys_open_loop_stable=series(sysCAP,sysT);   % stable open loop transfer function
%bode(sys_open_loop_stable)

w_phase_crossover_stable=0.9936;   % phase crossover frequency of stable system (rad/sec)
[MAG,PHASE]=bode(sys_open_loop_stable,w_phase_crossover_stable)   

KC_max=1/MAG;  % KC for marginally stable system
sys_open_loop_mstable=KC_max*sys_open_loop_stable;   % marginally stable open loop transfer function
%figure
%bode(sys_open_loop_mstable)

w_phase_crossover_mstable=w_phase_crossover_stable;   % phase crossover frequency of marginally stable system (rad/sec)
% [MAG,PHASE]=bode(sys_open_loop_mstable,w_phase_crossover_mstable)  



%%%%% Bode Plot of Marginally Stable System Open Loop Response %%%%%
wstart=0.01; 
delw=0.01;
for i=1:100
    w(i)=wstart+(i-1)*delw; 
    [MAG(i),PHASE(i)]=bode(sys_open_loop_mstable,w(i)); 
    if PHASE(i)>0
        PHASE(i)=PHASE(i)-360;
    end
    GAIN(i)=20*log10(MAG(i)); 
end
wstart=w(i); 
delw=0.1;
for i=101:190
    w(i)=wstart+(i-100)*delw; 
    [MAG(i),PHASE(i)]=bode(sys_open_loop_mstable,w(i)); 
    if PHASE(i)>0
        PHASE(i)=PHASE(i)-360;
    end
    GAIN(i)=20*log10(MAG(i));       
end
wstart=w(i); 
delw=1;
for i=191:280
    w(i)=wstart+(i-190)*delw; 
    [MAG(i),PHASE(i)]=bode(sys_open_loop_mstable,w(i)); 
    if PHASE(i)>0
        PHASE(i)=PHASE(i)-360;
    end
    GAIN(i)=20*log10(MAG(i));       
end
wstart=w(i); 
delw=10;
for i=281:370
    w(i)=wstart+(i-280)*delw; 
    [MAG(i),PHASE(i)]=bode(sys_open_loop_mstable,w(i)); 
    if PHASE(i)>0
        PHASE(i)=PHASE(i)-360;
    end
    GAIN(i)=20*log10(MAG(i));       
end
wstart=w(i);

figure(1) %%%%% Marginally stable system
subplot(2,1,1)
semilogx(w,GAIN,'b','LineWidth',1.3)
grid on
hold on
plot([min(w) max(w)],[0 0],'--k')
w_gain_crossover_mstable=w_phase_crossover_mstable;
plot([w_gain_crossover_mstable w_gain_crossover_mstable],[-200 0],'--k')
set(gca,'FontSize',11)
ylabel('Gain (db)','FontSize',12)
text(1.35,-150,'\omega_{cg} = 0.994 rad/s','FontSize',12)
title('Bode Plot of Open-Loop Transfer Function (K_C = 2.62)','FontSize',11)

subplot(2,1,2) 
semilogx(w,PHASE,'b','LineWidth',1.3)
grid on
hold on
plot([min(w) max(w)],[-180 -180],'--k')
plot([w_phase_crossover_mstable w_phase_crossover_mstable],[-400 -180],'-k')
set(gca,'FontSize',11)
set(gca,'YTick',[-400:100:0])
xlabel('\omega (rad/s)','FontSize',12)
ylabel('Phase (deg)','FontSize',12)
text(1.35,-350,'\omega_{cp} = 0.994 rad/s','FontSize',12)



%%%%% Bode Plot of Stable System Open Loop Response %%%%%
clear MAG GAIN w
sys_open_loop_stable=0.25*sys_open_loop_stable; % set KC=0.25
[M,P]=bode(sys_open_loop_stable,w_phase_crossover_stable);
GM=20*log10(M);
w_gain_crossover_stable=0.2707;   % gain crossover frequency of stable system (rad/sec)
[MAG,PHASE]=bode(sys_open_loop_stable,w_gain_crossover_stable); 
MAG_db=20*log10(MAG); % gain at crossover

wstart=0.01; 
delw=0.01;
for i=1:100
    w(i)=wstart+(i-1)*delw; 
    [MAG(i),PHASE(i)]=bode(sys_open_loop_stable,w(i)); 
    if PHASE(i)>0
        PHASE(i)=PHASE(i)-360;
    end
    GAIN(i)=20*log10(MAG(i)); 
end
wstart=w(i); 
delw=0.1;
for i=101:190
    w(i)=wstart+(i-100)*delw; 
    [MAG(i),PHASE(i)]=bode(sys_open_loop_stable,w(i)); 
    if PHASE(i)>0
        PHASE(i)=PHASE(i)-360;
    end
    GAIN(i)=20*log10(MAG(i));       
end
wstart=w(i); 
delw=1;
for i=191:280
    w(i)=wstart+(i-190)*delw; 
    [MAG(i),PHASE(i)]=bode(sys_open_loop_stable,w(i)); 
    if PHASE(i)>0
        PHASE(i)=PHASE(i)-360;
    end
    GAIN(i)=20*log10(MAG(i));       
end
wstart=w(i); 
delw=10;
for i=281:370
    w(i)=wstart+(i-280)*delw; 
    [MAG(i),PHASE(i)]=bode(sys_open_loop_stable,w(i)); 
    if PHASE(i)>0
        PHASE(i)=PHASE(i)-360;
    end
    GAIN(i)=20*log10(MAG(i));       
end
wstart=w(i);

figure(2)
subplot(2,1,1)
semilogx(w,GAIN,'b','LineWidth',1.3)
grid on
hold on
plot([min(w) max(w)],[0 0],'--k')
plot([w_gain_crossover_stable w_gain_crossover_stable],[-200 0],'--k')
ylabel('Gain (db)','FontSize',12)
text(0.4,-125,'\omega_{cg} = 0.271 rad/s','FontSize',12)
title('Bode Plot of Open-Loop Transfer Function (K_C = 0.25)','FontSize',11)
set(gca,'FontSize',11)

subplot(2,1,2) 
semilogx(w,PHASE,'b','LineWidth',1.3)
grid on
hold on
plot([min(w) max(w)],[-180 -180],'--k')
plot([w_phase_crossover_stable w_phase_crossover_stable],[-400 -180],'--k')
xlabel('\omega (rad/s)','FontSize',12)
ylabel('Phase (deg)','FontSize',12)
text(1.35,-350,'\omega_{cp} = 0.994 rad/s','FontSize',12)
set(gca,'FontSize',11)
set(gca,'YTick',[-400:100:0])

%%%%% find closed loop system poles of marginally stable system %%%%%

v1=conv([tauA 1],[tauP 1 0]) 
v2=conv(v1,[tauT 1]) 
v3=v2+[0 0 0 0 KC_max*KA*KP*KT] 
roots(v3) % closed loop poles


% %%%%% step response of marginally stable closed loop system %%%%%
% % sysCAP=KC_max*sysCAP;
% % sys_closed_loop=feedback(sysCAP,sysT)
% % figure
% % step(sys_closed_loop)


