% m-file Ch4_diver.m

clc; close all; clear all

mu=5; K = 0.2; W=300.0; V=3 ;
g=32.2; gamma=62.4;
A=[0 1 0;0 -mu*g/W 0;K*gamma 0 -K];
B=[0;g/W;0];
C=[1 0 0 ; -gamma/144 0 1/144]; % y1=h (ft), y2=delta_p (psi)
D=[0;0];

sys=ss(A,B,C,D); % create state space system object

x10=500; % initial depth (ft)
x20=0; % initial velocity (ft/sec)
x30=gamma*x10; % initial diver pressure (lb per sq ft)
x0=[x10,x20,x30]; % initial state vector

dt=0.05; tfinal=160;
t=0:dt:tfinal; % time vector
Weff=W-gamma*V; % Effective weight of diver in water
Fbar=25; tau=40;
fc=Weff+Fbar*(1-exp(-t/tau)); % cable force
fn=Weff-fc; % net force on diver

subplot(2,1,1)
plot([-10 t],[Weff fc],'b','LineWidth',1.3)
grid on
ylabel('f_c  (lb)','FontSize',12)
title('Cable Force vs Time','FontSize',11)
axis([-10 tfinal 110 140])
set(gca,'FontSize',11)
text(40,122,'F  = 25 lb, \tau = 40 s','FontSize',12)
text(40,125.9,'_','FontSize',13)
text(40,115,'Effective Weight = W - \gammaV = 112.8 lb','FontSize',12)

subplot(2,1,2)
plot([-10 t],[0 fn],'b','LineWidth',1.3)
grid on
xlabel('t  (s)','FontSize',12)
ylabel('f_n  (lb)','FontSize',12)
title('Net Force vs Time','FontSize',11)
axis([-10 tfinal -27 10])
set(gca,'FontSize',11)
set(gca,'YTick',[-30:10:10])
y=lsim(sys,fn,t,x0);
y1=y(:,1);
y2=y(:,2);

figure(2)
subplot(2,1,1)
plot(t,y1,'b','LineWidth',1.3)
grid on
hold on
plot([140 tfinal],[0 0],'b','LineWidth',1.3)
axis([0 tfinal 0 525])
set(gca,'FontSize',11)
set(gca,'YTick',[0:100:500])
ylabel('y_1(t),  ft','FontSize',12)
title('Depth of Diver vs Time','FontSize',11)

subplot(2,1,2)
plot(t,y2,'b','LineWidth',1.3)
grid on
axis([0 tfinal -1 12])
set(gca,'FontSize',11)
set(gca,'YTick',[0:2.5:10])
text(-20,13,'Differential Pressure (Internal Diver Pressure Minus Water Pressure) vs Time','FontSize',11)
xlabel('t  (s)','FontSize',12)
ylabel('y_2(t),  psi','FontSize',12)



