% m-file file 'Fig5_118and5_119.m'
% plots Figure 5.118 and Figutre 5.119

clc; close all; clear all

g=32.17;
aA=4.75e-6; nA=1.85; % arrow drag properties
aT=3e-6; nT=2.3; % target drag properties
%aA=0; aT=0; % zeros out drag forces on arrow and target

wA=2; % weight of arrow, oz
mA=(wA/16)/g; % mass of arrow, slugs
wT=16; % weight of target, oz
mT=(wT/16)/g; % mass of target, slugs

xA0=0; % initial x coordinate of arrow, ft
yA0=0; % initial y coordinate of arrow, ft

xT0=100; % x coordinate of target, ft
yT0=150; % initial y coordinate of target, ft 

theta0(1)=55.99*pi/180;
theta0(2)=55.65*pi/180;
theta0(3)=57.28*pi/180;
theta0(4)=54.59*pi/180;
v0(1)=75.21;
v0(2)=82.67;
v0(3)=75.39;
v0(4)=83.85;

for i=1:4

xAd0=v0(i)*cos(theta0(i)); % initial speed of arrow in x-direction
yAd0=v0(i)*sin(theta0(i)); % initial speed of arrow in y-direction
yTd0=0; % initial speed of target in y-direction

dx=0.25; % tolerance for locating arrow near x=xT0
target_radius=1.5; % radius of falling target

T=0.001; % integration step size

%**************************************************************************************************************************
% begin Figure 5.118
sim('arrow')
t=xAyAyT(:,1);
xA=xAyAyT(:,2);
yA=xAyAyT(:,3);
yT=xAyAyT(:,4);
theta=theta(:,2)*pi/180; % theta (rad)

LF=1.0; LT=0.4; WT=0.15;
     
     index=find(xA>xT0-dx & xA<xT0+dx);
     xA_=mean(xA(index)); % arrow x location 
     yA_=mean(yA(index)); % arrow height
     yT_=mean(yT(index)); % target height
     theta_=mean(theta(index));
     t_=mean(t(index));  % time for arrow to travel x=xT0     
     v_=mean(v(index));
     xD=xT0+LF*cos(theta_);
     yD=yA_+LF*sin(theta_);
     xE=xD+WT*sin(theta_);
     yE=yD-WT*cos(theta_); 
     xC=xD-WT*sin(theta_);
     yC=yD+WT*cos(theta_);
     xB=xD+LT*cos(theta_);
     yB=yD+LT*sin(theta_);
     xF=xT0-LF*cos(theta_);
     yF=yA_-LF*sin(theta_);     
     
     subplot(2,2,i)
     hold on
     plot([xT0 xT0],[0 yT0],'--k') % plot path of target
     grid on
     plot([xF xB xC xB xE],[yF yB yC yB yE],'r','LineWidth',1.0) % plot arrow
     xlabel('horizontal distance, x  (ft)','FontSize',12)
     ylabel('height above ground,  y (ft)','FontSize',11)
     
     thetai=linspace(0,2*pi,250); % generate points around circular target
     xi=xT0+target_radius*cos(thetai);
     yi=yT_+target_radius*sin(thetai);
     plot(xi,yi,'b') % plot target
     axis([xT0-2.5 xT0+2.5 yT_-10 yT_+10])
     axis equal 
     
     switch i
       case 1
         text(xT0-4.7,yT_+8,'v(0) = 75.21 ft/s','FontSize',11)
         text(xT0-4.7,yT_+5,'\theta(0) = 55.99\circ','FontSize',11)
         text(xT0-11,yT_-5,'t = 2.46 s','FontSize',11)
       case 2
         text(xT0-4.7,yT_+8,'v(0) = 87.67 ft/s','FontSize',11)
         text(xT0-4.7,yT_+5,'\theta(0) = 55.65\circ','FontSize',11)
         text(xT0-11,yT_-5,'t = 2.22 s','FontSize',11)
       case 3
         text(xT0-4.7,yT_-5,'v(0) = 75.39 ft/s','FontSize',11)
         text(xT0-4.7,yT_-8,'\theta(0) = 57.28\circ','FontSize',11)
         text(xT0-11,yT_+5,'t = 2.54 s','FontSize',11)
       case 4
         text(xT0-4.7,yT_+8,'v(0) = 83.85 ft/s','FontSize',11)
         text(xT0-4.7,yT_+5,'\theta(0) = 54.59\circ','FontSize',11)
         text(xT0-11,yT_-5,'t = 2.13 s','FontSize',11)
     end % switch         
     
 end % i
                        


figure(2) % begin Figure 5.119
theta0=54.59*pi/180; % initial theta (rad)
v0=83.85;
xAd0=v0*cos(theta0); % initial speed of arrow in x-direction
yAd0=v0*sin(theta0); % initial speed of arrow in y-direction
clear theta
sim('arrow')
theta=theta(:,2); % theta (deg)
v=v(:,2); % v (ft/sec)

subplot(2,1,1)
plot(t,v,'b','LineWidth',1.3)
grid on
axis([0 4.5 40 90])
set(gca,'FontSize',11)
set(gca,'XTIck',[0:0.5:4.5])
set(gca,'YTIck',[40:10:90])
ylabel('v(t),  ft/s','FontSize',11)
title('Speed of Arrow','FontSize',11)

subplot(2,1,2)
plot(t,theta,'b','LineWidth',1.3)
axis([0 4.5 -75 75])
grid on
set(gca,'FontSize',11)
set(gca,'XTIck',[0:0.5:4.5])
set(gca,'YTIck',[-75:25:75])
xlabel('t  (s)','FontSize',13)
ylabel('\theta(t),  \circF','FontSize',13)
title('Pitch Angle of Arrow','FontSize',11)