% MATLAB Script File Ch5_FourierSeries.m
% Fourier Series of periodic function f(t)
% f(t)= A, 0 <= t < T/2
%     = 0, T/2 <= t < T

close all
clc 
clear all


n=19; % number of harmonics of f(t)
k=1:2:n; % harmonics of f(t)
A=10; % amplitude of f(t)
a=2*A./(k.*pi); % Fourier Series coefficients a(k), k=1,3,5,...,n
a0=0.5*A; % ave value of f(t)
T=0.1; % period of f(t)
w0=2*pi/T; % input frequency
wh=k*w0; % wh(1):fundamental freq, wh(2):freq of 3rd harmonic, wh(3):freq of 5th harmonic, etc
wr=wh(5); % Set resonant frequency equal to freq of 9th harmonic
wn=1.01*wr; % calculate natural frequency
zeta=sqrt((1-(wr/wn)^2)/2); % calculate damping ratio

sim('resonance') % call SIMULINK model 'resonance.mdl'
t=uTFS(:,1);

% figure(1) % begin Figure 5.100
% u=uTFS(:,2);
% TFS=uTFS(:,3);
% plot(t,u,'b','LineWidth',1.75)
% grid on
% set(gca,'FontSize',11)
% hold on
% plot(t,TFS,'r','LineWidth',1.3)
% axis([0 0.21 -2 13])
% xlabel('t','FontSize',13)
% title('u(t) and its Truncated Fourier Series','FontSize',11)
% text(0.022,12.15,'truncated Fourier Series of u(t)','FontSize',12)
% plot([0.01 0.019],[12 12],'k')
% plot([2.5e-3 0.01],[10.9 12],'k')
% plot([0.13 0.14],[12 12],'k')
% plot([0.14 0.1475],[12 10.9],'k')
% text(0.07,9,'u(t)','FontSize',13)
% plot([0.085 0.1],[9 9],'k')

% figure(2)
% y=yTFS(:,2);
% TFSy=yTFS(:,3);
% 
% subplot(2,1,1)
% plot(t,y,'b','LineWidth',1.3)
% grid on
% set(gca,'FontSize',11)
% text(0.03,23,'Second-Order System Response y(t) to Input u(t)','FontSize',11) 
% 
% subplot(2,1,2)
% plot(t,TFSy,'b','LineWidth',1.3)
% grid on
% set(gca,'FontSize',11)
% xlabel('t','FontSize',13)
% text(-0.003,23.5,'Second-Order System Response to Truncated Fourier Series of u(t)','FontSize',11) 

%figure(3) % begin Figure 5.102
% w=linspace(0,1500,500); % range of freq for |G(jw)| plot
% s=j*w; %  complex freqs
% magG_w=(wn.^2)./abs(s.^2 + 2*zeta*wn*s + wn^2); % |G(jw)|
% plot(w,magG_w,'b','LineWidth',1.3)
% grid on
% set(gca,'FontSize',11)
% set(gca,'XTick',[0:250:1500])
% hold on
% s=j*wh;
% magG_wh=(wn.^2)./abs(s.^2 + 2*zeta*wn*s + wn^2); % |G(jwh)|
% plot(wh,magG_wh,'.r','MarkerSize',13)
% xlabel('\omega (rad/s)','FontSize',13)
% ylabel('|G(j\omega)|','FontSize',13)
% title('Magnitude Function of Second-Order System','FontSize',11)
% text(900,5.25,'G(s):  2^{nd} order','FontSize',13)
% text(900,4.5,'\omega_n = 571.14 rad/s','FontSize',13)
% text(900,3.75,'\zeta = 0.1','FontSize',13)
% text(900,3.0,'\omega_r = 565.49 rad/s','FontSize',13)
% text(50,0.8,'\omega_0','FontSize',12)
% text(180,0.85,'3\omega_0','FontSize',12)
% text(310,1.15,'5\omega_0','FontSize',12)
% text(435,2.0,'7\omega_0','FontSize',12)
% text(550,5.25,'9\omega_0','FontSize',12)
% text(700,1.9,'11\omega_0','FontSize',12)
% text(835,0.95,'13\omega_0','FontSize',12)
% text(1190,0.5,'19\omega_0','FontSize',12)
% text(900,2.25,'harmonic frequencies','FontSize',12)
% plot([870],[2.25],'.r','MarkerSize',13)

% figure(4)
% num=[wn^2]; % numerator of G(s)
% denom=[1 2*zeta*wn wn^2]; % denominator of G(s)
% SYS=TF(num,denom); % transfer function of G(s)
% bode(SYS,{50,1500})
% [MAG,PHASE,wh]=BODE(SYS,wh)  % Evaluate |G(jwh)| and Angle(G(jwh))
% PHASE=PHASE*(pi/180) % phase in rad

figure(5)
v=[0 T -7 7];
subplot(2,2,1)
hold on
plot(t,harmonics(:,1),'b','LineWidth',1.3)
grid on
set(gca,'FontSize',11)
axis(v)
plot(t,harmonics(:,2),'r','LineWidth',1.3)
text(0.002,-4.7,'\omega_0 = 62.8 rad/s','FontSize',12)
text(0.025,8.25,'u_1(t) and y_1(t)','FontSize',12)

subplot(2,2,2)
hold on
plot(t,harmonics(:,3),'b','LineWidth',1.3)
grid on
set(gca,'FontSize',11)
axis(v)
plot(t,harmonics(:,4),'r','LineWidth',1.3)
text(0.02,-4.7,'7\omega_0 = 439.8 rad/s','FontSize',12)
text(0.025,8.25,'u_7(t) and y_7(t)','FontSize',12)

subplot(2,2,3)
hold on
plot(t,harmonics(:,5),'b','LineWidth',1.3)
grid on
set(gca,'FontSize',11)
axis(v)
plot(t,harmonics(:,6),'r','LineWidth',1.3)
text(0.01,-5.25,'\omega_r = 9\omega_0 = 565.5 rad/s','FontSize',12)
text(0.025,8.25,'u_9(t) and y_9(t)','FontSize',12)
xlabel('t  (s)','FontSize',12)

subplot(2,2,4) 
hold on
plot(t,harmonics(:,7),'b','LineWidth',1.3)
grid on
set(gca,'FontSize',11)
axis(v)
plot(t,harmonics(:,8),'r','LineWidth',1.3)
text(0.015,-4.4,'11\omega_0 = 691.2 rad/s','FontSize',12)
text(0.02,8.25,'u_{11}(t) and y_{11}(t)','FontSize',12)
xlabel('t  (s)','FontSize',12)
