% script file 'Ch5_MonteCarlo_arrow.m'
% sets parameter values for SIMULINK file 'arrow.mdl'
% runs sim and saves data in arrow1.dat and arrow2.dat

clc, close all, clear all

g=32.17;
aA=4.75e-6; nA=1.85; % arrow drag properties
aT=3e-6; nT=2.3; % target drag properties
aA=0; aT=0; % zeros out drag forces on arrow and target

wA=2; % weight of arrow, oz
mA=(wA/16)/g; % mass of arrow, slugs
wT=16; % weight of target, oz
mT=(wT/16)/g; % mass of target, slugs

xA0=0; % initial x coordinate of arrow, ft
yA0=0; % initial y coordinate of arrow, ft

xT0=100; % x coordinate of target, ft
yT0=150; % initial y coordinate of target, ft 

v0_low=75; v0_high=85; % limits on initial speed of arrow, ft/sec
v0=v0_low+(v0_high-v0_low)*rand;  % initial speed of arrow, uniformly distributed over (v0_low, v0_high), ft/sec
v0=(v0_low+v0_high)/2; % removes variability in initial speed of arrow
mu_theta0=atan(yT0/xT0); % mean departure angle of arrow, rad
sigma_theta0_deg=1; % std dev of departure angle of arrow, deg
sigma_theta0=sigma_theta0_deg*pi/180; % std dev of departure angle of arrow, rad
theta0=mu_theta0+sigma_theta0*randn; % departure angle of arrow, distributed N(mu_theta0, sigma_theta0), rad
theta0=mu_theta0  % removes variability in departure angle
xAd0=v0*cos(theta0)  % initial speed of arrow in x-direction
yAd0=v0*sin(theta0)  % initial speed of arrow in y-direction
yTd0=0; % initial speed of target in y-direction
dx=0.25; % tolerance for locating arrow near x=xT0
target_radius=1.5; % radius of falling target
T=0.005; % integration step size

% **************************************************************************************************************************
sim('arrow')
t=xAyAyT(:,1);
xA=xAyAyT(:,2);
yA=xAyAyT(:,3);
yT=xAyAyT(:,4);
plot(xA(1:5:end),yA(1:5:end),'.k','MarkerSize',3)  % plot flight path of arrow
grid on
set(gca,'FontSize',11)
hold on
axis([-3 xA(end) -3 90])
xlabel('Horizontal Distance,  x  (ft)','FontSize',12)
ylabel('Height Above Ground,   y  (ft)','FontSize',12)
LF=1.0; LT=0.4; WT=0.15; 

for i=1:50:length(t)
    z=theta(i,2)*pi/180
    xA_end=xA(i)-LF*cos(z)
    xA_tip=xA(i)+LF*cos(z) 
    yA_end=yA(i)-LF*sin(z)
    yA_tip=yA(i)+LF*sin(z)     
    plot([xA_end xA_tip], [yA_end yA_tip],'r','LineWidth',2) % plot arrow every 0.25 sec
    plot (xT0,yT(i),'o','MarkerSize',6) % plot target every 0.25 sec
end % for

text(50,25,'Flight of arrow','FontSize',12)
text(35,26,'......','FontSize',12)
text(50,18,'Arrow location at t = 0, 0.25, 0.5 s ...','FontSize',12)
plot([37 43],[18 18],'r','LineWidth',2)
text(50,11,'Target location at t = 2, 2.25, 2.5 s ...','FontSize',12)
plot(40,11,'o','MarkerSize',6)
title('Trajectories of Arrow and Target','FontSize',11)

     figure(2)
     hold on
     index=find(xA>xT0-dx & xA<xT0+dx);
     xA_=mean(xA(index)); % arrow x location 
     yA_=mean(yA(index)); % arrow height
     yT_=mean(yT(index)); % target height
     t_=mean(t(index)); % time for arrow to travel x=xT0
     theta_=mean(theta(index,2))*pi/180;
     xD=xT0+LF*cos(theta_);
     yD=yA_+LF*sin(theta_);
     xE=xD+WT*sin(theta_);
     yE=yD-WT*cos(theta_); 
     xC=xD-WT*sin(theta_);
     yC=yD+WT*cos(theta_);
     xB=xD+LT*cos(theta_);
     yB=yD+LT*sin(theta_);
     xF=xT0-LF*cos(theta_);
     yF=yA_-LF*sin(theta_);   
     
     plot([xT0 xT0],[0 yT0],'--k') % plot path of target 
     grid on
     set(gca,'FontSize',11)
     plot([xF xB xC xB xE],[yF yB yC yB yE],'r','LineWidth',1.0) % plot arrow
     xlabel('Horizontal Distance, x  (ft)','FontSize',12)
     ylabel('Height Above Ground,  y  (ft)','FontSize',12)
     title('Close-up of Arrow Striking Target','FontSize',11)
     thetai=linspace(0,2*pi,250); % generate points around circular target
     xi=xT0+target_radius*cos(thetai);
     yi=yT_+target_radius*sin(thetai);
     plot(xi,yi,'b') % plot target
     %axis([xT0-2.5 xT0+2.5 yT_-15 yT_+15])
     axis([95 105 55 80])
     axis equal     
     text(88,75.7,'Path of falling target','FontSize',13)                       
     str1=sprintf('t = %.2f s',t_);
     text(xT0-13.5,yT_-5,str1,'FontSize',13)
     str2=sprintf('arrow height = %.2f ft',yA_);
     text(xT0-13.5,yT_-7,str2,'FontSize',13)
     str3=sprintf('target height = %.2f ft',yT_);
     text(xT0-13.5,yT_-9,str3,'FontSize',13)    
                                                  
*******************************************************************************************************************************
%%%% begin obtain data for histogram
nruns=1000;
% nruns=50000; for Figure 5.115
k=1;  % initializes index in Monte carlo simulation loop
loop_passes=1;
num_hits=0;
mu_theta0=atan(yT0/xT0); % mean departure angle of arrow, rad
sigma_theta0_deg=1; % std dev of departure angle of arrow, deg
sigma_theta0=sigma_theta0_deg*pi/180; % std dev of firing angle of arrow, rad

while k<= nruns & loop_passes<=1.1*nruns     
   
v0=v0_low+(v0_high-v0_low)*rand; % initial speed of arrow, uniformly distributed over (v0_low, v0_high), ft/sec
% v0=(v0_low+v0_high)/2; % removes variability in initial arrow speed

theta0=mu_theta0+sigma_theta0*randn; % firing angle of arrow, distributed N(mu_theta0, sigma_theta0), rad
% theta0=mu_theta0; % removes variability in departure angle

xAd0=v0*cos(theta0); % initial speed of arrow in x-direction
yAd0=v0*sin(theta0); % initial speed of arrow in y-direction
    
sim('arrow')
t=xAyAyT(:,1);
xA=xAyAyT(:,2);
yA=xAyAyT(:,3);
yT=xAyAyT(:,4);

index=find(xA>xT0-dx & xA<xT0+dx);

  if isempty(index)~=1
    
    xAA=mean(xA(index)); % arrow position close to xT0
    yAA=mean(yA(index)); % arrow height
    yTT=mean(yT(index)); % target height
    
    separation(k)=yAA-yTT; % separation between arrow and target
  
    if yAA>yTT-target_radius & yAA<yTT+target_radius % check for hit
      num_hits=num_hits+1; % increment number of hits
    end % if
    k=k+1; % increment number of runs

  end % if isempty(index) 
  loop_passes=loop_passes+1;
      
end % while

num_hits,nruns
Pr_Hit=num_hits/nruns
% save arrowdata nruns num_hits Pr_Hit separation  % saves results of Monte
                                                   % Carlo trials



 

