% MATLAB script file 'Ch5_MonteCarlo_damping_ratio.m'
% computes the empirical pdf and cdf for zeta and plots Figure 5.109 and
% Figure 5.110

close all; clc; clear all
num=100000;
Ml=0.9; Mu=1.1; % lower and upper limits, slugs
Bl=1.75; Bu=2.25; % lower and upper limits, (lb-sec)/ft
Kl=3.8; Ku=4.2; % lower and upper limits, lb/ft

% for i=1:num
%     Mi=Ml+(Mu-Ml)*rand;
%     Bi=Bl+(Bu-Bl)*rand;
%     Ki=Kl+(Ku-Kl)*rand;
%     zetai(i)=Bi/(2*sqrt(Mi*Ki));
% end % for

load Ch5_MonteCarlo_damping_ratio_data
dx=0.005; % interval width for empirical pdf
centers=0.4:dx:0.6; 
edges=0.4-dx/2:dx:0.6+dx/2; 
N=histc(zetai,edges);

subplot(1,2,1)
hist(zetai,centers)
grid on
set(gca,'FontSize',11)
axis([0.4-dx 0.6+dx 0 1.075*max(N)])
set(gca,'XTick',[0.4:0.05:0.6])
xlabel('Damping Ratio, u','FontSize',12)
ylabel('Frequency of Occurrence, n_i','FontSize',12)
text(0.36,4600,'Histogram of Damping Ratio Values','FontSize',11)
text(0.41,1.04*max(N),'100,000 trials','FontSize',11)
N=N(1:end-1);

Ni=[0 N 0]; 
Pri=Ni/(num*dx); 
xi=0.4-dx:dx:0.6+dx;

subplot(1,2,2)
plot(xi,Pri,'.r','MarkerSize',10)
grid on
hold on
plot(xi,Pri,'b','LineWidth',1.3)
set(gca,'FontSize',11)
axis([0.4-dx 0.6+dx 0 1.075*max(Pri)])
set(gca,'XTick',[0.4:0.05:0.6])
xlabel('Damping Ratio, u','FontSize',12)
ylabel('Approximation of  f_{\zeta}(u)','FontSize',12)
text(0.38,9.2,'Monte Carlo Damping Ratio pdf','FontSize',11)
text(0.442,3.75,'M_l=0.9, M_u=1.1','FontSize',11)
text(0.435,2.75,'B_l=1.75, B_u=2.25','FontSize',11)
text(0.445,1.75,'K_l=3.8, K_u=4.2','FontSize',11)
text(0.475,0.9,'\itf_{\rmi}','FontSize',11)
plot([0.46],[0.9],'.r','MarkerSize',10)
text(0.475, 0.4,'empirical pdf','FontSize',11)
plot([0.445 0.465],[0.4 0.4],'b','LineWidth',1.3)

Pr=sum(Pri(11:21))*dx;  % empirical prob that zeta fall between 0.45 and 0.5


figure(2)
load Ch5_MonteCarlo_damping_ratio_data
cdf_zeta(1)=0;
for i=1:length(xi)
    cdf_zeta(i+1)=cdf_zeta(i)+Pri(i)*dx;
end

xi=[0 xi 0.66];
cdf_zeta(end+1)=1;
plot(xi,cdf_zeta,'b','LineWidth',1.3) % plot empirical cdf for zeta
grid on
set(gca,'FontSize',11)
hold on
plot(xi,cdf_zeta,'.r','MarkerSize',10)
axis([0.35 0.65 -0.02 1.02])
set(gca,'YTick',[0:0.1:1])
xlabel('Damping Ratio, u','FontSize',12)
ylabel('Empirical Cumulative  Distribution Function','FontSize',12)
title('Generation of Random \zeta_i iValues','FontSize',11)
text(0.5255,0.655,'\wedge')
text(0.525,0.6,'F_{\zeta}(u)','FontSize',13)

R=rand; % generate a random number betwen 0 and 1
% R=0.4; for text Figure 5.110
for i=1:length(xi)
    if cdf_zeta(i)<=R & cdf_zeta(i+1)>R
        m=(cdf_zeta(i+1)-cdf_zeta(i))/(xi(i+1)-xi(i));
        z=xi(i)+(R-cdf_zeta(i))/m;
    end % if
end % for

plot([0 z],[R R],'--k')
plot([z z],[-0.02 R],'--k')
text(0.35+(z-0.35)/2, R+0.05,'R_i','FontSize',13)
text(z+0.005,0.025,'\zeta_i','FontSize',13)






