% m-file "Ch5_call_cascaded_tanks.m"
% calls Simulink model "cascaded_tanks.mdl"
% Two tanks in series
% tank 1 input flow from pulse input and/or outflow from tank 2
% computes liquid volume balances for different scenarios
% Plots Figures 5.129 - 5.132

clc, close all, clear all

%%%%% Part 1) %%%%%

%%% tank 1  baseline %%%
c1=2; % discharge constant for tank 1
A1=4; % area of tank 1
L1=20; % height of tank 1
fact1=0; % factor for determining initial tank 1 level
H1_init=fact1*L1; % initial level in tank 1

%%% tank 2 baseline %%%
c2=2; % discharge constant for tank 2
A2=4; % area of tank 2
L2=10; % height of tank 2
fact2=0; % factor for determining initial tank 2 level
H2_init=fact2*L2; % initial level in tank 2

%%% remaining baseline values %%%
pulse_time_on=0;  % pulse input time on for flow into tank 1 
pulse_time_off=20; % pulse input time off for flow into tank 1
A=15; % amplitude of external flow into tank 1
K1=1; % K1=0 (tank 1 step input flow f11 is off), K1=1 (tank 1 step input flow f11 is on)
K2=0; % K2=0 (tank 2 f02 output is not input to tank 1), K2=1 (tank 2 output f02 is input to tank 1)
tfinal=70; % simulation final time

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% A1 = 4;
% A2 = 4;
% L1 = 20;
% L2 = 10;
% c1 = 2;
% c2 = 2;
% H1_init = 0;
% H2_init = 0;
% t0 = 0;
% t1 = 20;
% A = 15;
% K1 = 1;
% K2 = 0;
%%%%%%%%%%%%%%%%%%%%%%%%%%


f01_max=c1*sqrt(L1);
f02_max=c2*sqrt(L2);

sim('cascaded_tanks') % tanks in series with only pulse flow input to first tank

t=t_H1(:,1);
H1=t_H1(:,2);
f1=t_f1(:,2);
H2=t_H2(:,2);

figure(1)
plot(t,H1,'b','LineWidth',1.3)
grid on
hold on
plot(t,H2,'r','LineWidth',1.3)
set(gca,'FontSize',11)
set(gca,'XTick',[0:5:70])
set(gca,'YTick',[0:2:20])
axis([0 tfinal 0 1.05*max(max(H1),max(H2))])
xlabel('t (min)','FontSize',12)
ylabel('H_{1}(t),  H_{2}(t),  (ft)','FontSize',12)
title('Tank 1 and Tank 2 Levels vs Time','FontSize',11)
text(22.5,18.3,'H_1(t)','FontSize',12)  % when K2=0
% text(25.0,18.3,'H_1(t)','FontSize',12) % when K2=1
text(15,11.0,'H_2(t)','FontSize',12)

f01=t_f01(:,2);
f02=t_f02(:,2);

figure(2)
plot(t,H1,'b','LineWidth',1.3)
grid on
hold on
set(gca,'FontSize',11)
set(gca,'XTick',[0:5:50])
set(gca,'YTick',[0:2:20])
plot(t,f1,'r','LineWidth',1.3)
plot(t,f01,'k','LineWidth',1.3)
max_f1=max(f1);
max_f01=max(f01);
max_f=max(max_f1,max_f01);
max_f_L1=max(max_f,L1);
axis([0 tfinal 0 1.05*max_f_L1])
xlabel('t (min)','FontSize',12)
ylabel('H_1(t),  (ft)    and    f_1(t),  f_{0,1}(t),  (ft^3/min)','FontSize',12)
title('Tank 1 Level, Flow In and Flow Out vs Time')
text(22.5,18.3,'H_1(t)','FontSize',12)
text(10,16.3,'f_1(t)','FontSize',12)
text(10,10.3,'f_{0,1}(t)','FontSize',12)


figure(3)
plot(t,H2,'b','LineWidth',1.3)
hold on
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:5:50])
set(gca,'YTick',[0:11])
plot(t,f01,'r','LineWidth',1.3)
plot(t,f02,'k','LineWidth',1.3)
% max_f02=max(f02);
% max_f=max(max_f01,max_f02);
% max_f_L2=max(max_f,L2);
% axis([0 tfinal 0 1.05*max_f_L2])
axis([0 tfinal 0 11])
xlabel('t (min)','FontSize',12)
ylabel('H_2(t),  (ft)    and    f_{0,1}(t),  f_{0,2}(t),  (ft^3/min)','FontSize',12)
title('Tank 2 Level, Tank 1 and Tank 2 Outflows vs Time','FontSize',11)
text(15,7.0,'f_{0,2}(t)','FontSize',12)
text(23,8.2,'f_{0,1}(t)','FontSize',12)
text(33,8.2,'H_2(t)','FontSize',12)

% V1_init=A1*H1_init;
% fprintf('(a) Initial volume in Tank 1 = %.1f cu ft\n',V1_init)
% V2_init=A2*H2_init;
% fprintf('(b) Initial volume in Tank 2 = %.1f cu ft\n',V2_init)
% tank1_external_input_flow=V1_in(end); % volume into tank 1 from external source (cu ft)
% fprintf('(c) Total volume into Tank 1 from external source = %.1f cu ft\n\n',tank1_external_input_flow)
% fprintf('(a) + (b) + (c) = %.1f cu ft\n\n',V1_init+V2_init+tank1_external_input_flow)
% 
% tank1_vol=V1(end); % volume in tank 1 at time tfinal, cu ft
% fprintf('(d) Final volume in Tank 1 = %.1f cu ft\n',tank1_vol)
% tank2_vol=V2(end); % volume in tank 2 at time tfinal, cu ft
% fprintf('(e) Final volume in Tank 2 = %.1f cu ft\n',tank2_vol)
% 
% tank2_vol_out=V2_out(end); % tank 2 volume output not returned to tank 1, cu ft
% fprintf('(f) Total volume from Tank 2 not returned to Tank 1 = %.1f\n',tank2_vol_out)
% tank1_spillover=V1_spill(end); % volume overflowing tank 1, cu ft
% fprintf('(g) Total volume spilling over from Tank 1 = %.1f\n',tank1_spillover)
% tank2_spillover=V2_spill(end); % volume overflowing tank 2, cu ft
% fprintf('(h) Total volume spilling over from Tank 2 = %.1f\n\n',tank2_spillover)
% fprintf('(d) + (e) + (f) + (g) +(h) = %.1f cu ft\n\n',tank1_vol+tank2_vol+tank2_vol_out+tank1_spillover+tank2_spillover)
% 
% %% Case I 
% % baseline conditions
% 
% %% Case II
% % A=25; % amplitude of external flow into tank 1
% 


