% MATLAB script file 'Ch5_eject.m'
% sets parameters for SIMULINK model file 'ejection_seat.mdl'
% plots Figure 5.24 and Figure 5.126

clc
close all
clear all

thetaE=15*(pi/180);
vE=40;
m=8;
A=10;
CD=1;
y1=4;
g=32.2;

x_init=-y1*tan(thetaE);
y_init=y1;
vy_init=vE*cos(thetaE);

h=0;
vA=500;
vx_init=vA-vE*sin(thetaE);
v_init=sqrt(vx_init^2 + vy_init^2);
theta_init=atan(vy_init/vx_init);
sim('ejection_seat')
xplane=[0 -36 -48 -60 -60];
yplane=[0 0 12 12 0];
plot(xplane,yplane,'b','LineWidth',1.5)
hold on
set(gca,'FontSize',11)
set(gca,'YTick',[0:2:20])
plot(x,y,'k--','LineWidth',1.3)
plot(x_init,y_init,'.k','MarkerSize',15)
axis([-61 1 -1 20])
title('Pilot and Seat Ejection Trajectory Relative to Plane','FontSize',11)
xlabel('x  (ft)','FontSize',13)
ylabel('y  (ft)','FontSize',13)
text(-59.25,3.5,'Vertical Stabilizer','FontSize',13)
text(-42,8,'Plane profile','FontSize',13)
text(-30,16.5,'Pilot and seat trajectory','FontSize',13)
text(-18,4,'Starting point','FontSize',13)

% statements below are for generating Figure 5.126 
% In order to simulate 2 sec, the stop value of -60 in 'ejection_seat.mdl' should be changed to -400 before running
% Note: theta in SIMULINK model is sent to a scope and an array named 'theta' returned to WorkSpace

figure(2)  % begin plot Figure 5.26
t=theta(:,1);
th=theta(:,2)*180/pi;
subplot (2,1,1)
plot(t,y,'b','LineWidth',1.3)
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.25:2])
set(gca,'YTick',[0:5:20])
axis([0 2 0 22])
ylabel('y  (ft)','FontSize',13)
title('Pilot and Seat Height Above Plane vs Time','FontSize',11)

subplot(2,1,2)
plot(t,th,'b','LineWidth',1.3)
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.25:2])
axis([0 2 -10 7])
xlabel('t  (s)','FontSize',13)
ylabel('\theta  (deg)','FontSize',13)
title('Pilot and Seat Angle of Trajectory vs Time','FontSize',11)
