% m-file "Ch5_plot_arrow_histogram.m"
% plots histograms in Figure5.115

clc, close all, clear all

%%%%% begin plot histogram of arrowdata1.mat and arrowdata2.mat
load arrowdata1
edges=-24.75:0.5:24.75;
N=histc(separation,edges);
bincenters=-24.5:0.5:24.5;
subplot(2,1,1)
hist(separation,bincenters)
grid on
set(gca,'FontSize',11)
axis([-25 25 0 1.05*max(N)])
ylabel('Freq of Occurrence','FontSize',12)
title('Histogram of Vertical Separation Between Arrow and Target','FontSize',12)
text(-23.5,1000,'\theta(0) \sim N(56.31\circ, 1\circ)','FontSize',12)
text(-23.5,1500,'v(0) \sim U(75 fps, 85 fps)','FontSize',12)
text(-21.7,500,'50,000 runs','FontSize',12)
str4=sprintf('Pr(Hit) = %.4f',Pr_Hit);
text(10,1500,str4,'FontSize',12)
text(10,1000,'arrowdata1.mat','FontSize',12)

load arrowdata2
edges=-24.75:0.5:24.75;
N=histc(separation,edges);
bincenters=-24.5:0.5:24.5;

subplot(2,1,2)
hist(separation,bincenters)
grid on
set(gca,'FontSize',11)
axis([-25 25 0 1.05*max(N)])
ylabel('Freq of Occurrence','FontSize',12)
xlabel('\Delta = y_A - y_T  (ft)  ','FontSize',12)
title('Histogram of Vertical Separation Between Arrow and Target','FontSize',12)
text(-23.5,1000,'\theta(0) \sim N(56.31\circ, 1\circ)','FontSize',12)
text(-23.5,1500,'\itv\rm(0) \sim U(75 fps, 85 fps)','FontSize',12)
text(-21.7,500,'50,000 runs','FontSize',12)
str4=sprintf('Pr(Hit) = %.4f',Pr_Hit);
text(10,1500,str4,'FontSize',12)
text(10,1000,'arrowdata2.mat','FontSize',12)

%%%%% begin plot graph of Pr(Hit) vs number of trials for 1000 trials from
%%%%% arrowdata1.mat in Figure 5.116
target_radius=1.5;
k=0;
nhits=0;

for i=1:1000 % 1000 trials
    if abs(separation(i))<target_radius
       nhits=nhits+1;
   end
   if mod(i,100)==0 % 1000 trials of arrowdata1.mat
       k=k+1;
       n(k)=100*k; % 1000 trials
       PrHit(k)=nhits/i;
   end
end % for

figure(2) 
plot(n,PrHit,'.r','MarkerSize',12)
grid on
set(gca,'FontSize',11)
hold on
plot(n,PrHit,'--b','LineWidt',1.3)
axis([0 1000 0.205 0.24]) % scale for 1000 trials of arrowdata1.mat
set(gca,'XTick',[0:100:1000])
xlabel('Number of Trials','FontSize',12)
ylabel('Estimated Probability of a Hit','FontSize',12)
text(-15,0.242,'Effect of Number of Trials on Estimated Probability of Hitting Target','FontSize',11)
text(600,0.211,'arrowdata1.mat','FontSize',13)  % text for 1000 trials of arrowdata1.mat
 

%%%%% begin plot graph of Pr(Hit) vs number of trials for 50000 trials from
%%%%% arrowdata1.mat in Figure 5.117
k=0;
nhits=0;
for i=1:length(separation) % 50000 trials   
    if abs(separation(i))<target_radius
       nhits=nhits+1;
   end
    if mod(i,1000)==0 % 50000 trials of arrowdata1.mat
       k=k+1;
       n(k)=1000*k; % 50000 trials
       PrHit(k)=nhits/i;
   end
end % for

figure(3)
plot(n,PrHit,'.r','MarkerSize',12)
grid on
set(gca,'FontSize',11)
hold on
plot(n,PrHit,'--b','LineWidth',1.1)
axis([0 length(separation) 0.205 0.217]) % scale for 50000 trials of
                                           % arrowdata1.mat
xlabel('Number of Trials','FontSize',12)
ylabel('Estimated Probability of a Hit','FontSize',12)
title('Effect of Number of Trials on Estimated Probability of Hitting Target','FontSize',11)
text(3.0e4,0.2058,'arrowdata1.mat','FontSize',13)  % text for 1000 trials of arrowdata1.mat
%set(gca,'YTick',[0.2081:0.0020:0.2241])