% MATLAB script file 'Ch5_safe_eject.m'
% Sets parameters for SIMULINK model file 'ejection_seat.mdl'
% Calculates minimum plane speed vA as a function of altitude h
% for a safe ejection
% This program will take several minutes to run depending on
% RK-2 integration step size set in 'ejection_set.mdl'
% Watch the h display as SIMULINK model executes
% Execution stops after h reaches 50,000 ft for the second time
% Set STOP condition back t0 -60

clc; close all; clear all

thetaE=15*(pi/180); % ejection angle (rad)
vE=40; % ejection speed (ft/sec)
m=8; % mass of pilot and seat (slugs)
A=10; % surface area (sq ft)
CD=1; % drag coeffficient
y1=4; % y value at ejection
g=32.2; % gravitational constant
rear_stab=12; % height of vertical stabilizer at rear end of plane
clearance=5; % safety clearance for safe ejection (ft)

x_init=-y1*tan(thetaE); % x value at ejection (ft) - passed to x integrator
y_init=y1; % y value at ejection (ft) - passed to y integrator
vy_init=vE*cos(thetaE); % ydot value at ejection (ft/sec)

vA=100; % constant horizontal speed of plane (ft/sec)
vx_init=vA-vE*sin(thetaE); % xdot initial value at ejection (ft/sec)
v_init=sqrt(vx_init^2 + vy_init^2); % initial velocity at ejection
theta_init=atan(vy_init/vx_init); % initial angle theta at ejection (rad)

for i=1:11
    h=(i-1)*5000; % set altitude (ft)
    hh(i)=h; % save altitude in array hh for plotting
    sim('ejection_seat') % call SIMULINK model
      while y(end) <= rear_stab+clearance % check if pilot/seat clear stabilizer by clearance amount
        vA=vA+10; % increment plane speed
        vx_init=vA-vE*sin(thetaE); % calculate new xdot initial value
        v_init=sqrt(vx_init^2 + vy_init^2); % calculate new initial velocity at ejection
        theta_init=atan(vy_init/vx_init);  % calculate new initial angle theta at ejection       
        sim('ejection_seat') % call SIMULINK model 
      end % while
    vAmin(i)=vA; % save minimum safe speed (ft/sec) in array vAmin for plotting
end % for

for i=1:11         
  vA=1650; % constant horizontal speed of plane (ft/sec)
  vx_init=vA-vE*sin(thetaE); % xdot initial value at ejection (ft/sec)
  v_init=sqrt(vx_init^2 + vy_init^2); % initial velocity at ejection
  theta_init=atan(vy_init/vx_init); % initial angle theta at ejection (rad)
  h=(i-1)*5000;  % set altitude (ft)
  hh(i)=h; % save altitude in array hh for plotting
  sim('ejection_seat') % call SIMULINK model
    while y(end) <= rear_stab+clearance % check if pilot/seat clear stabilizer by clearance amount
      vA=vA-10; % increment plane speed
      vx_init=vA-vE*sin(thetaE); % calculate new xdot initial value
      v_init=sqrt(vx_init^2 + vy_init^2); % calculate new initial velocity at ejection
      theta_init=atan(vy_init/vx_init);  % calculate new initial angle theta at ejection       
      sim('ejection_seat') % call SIMULINK model 
   end % while
  vAmax(i)=vA; % save maximum safe speed (ft/sec) in array vAmax for plotting
end % for

plot(hh,vAmin,'.r','MarkerSize',12)
grid on
axis([0 50000 0 1800])
set(gca,'FontSize',11)
set(gca,'XTick',[0:5000:50000])
set(gca,'YTick',[0:200:1800])
hold on
plot(hh,vAmin,'--b','LineWidth',1.3)
plot(hh,vAmax,'.r','MarkerSize',12)
plot(hh,vAmax,'--b','LineWidth',1.3)
xlabel('Altitude   h  (ft)','FontSize',12)
ylabel('Aircraft Speed  v_A   (ft/s)','FontSize',12)
title('Safe Conditions for Pilot Ejection','FontSize',11)
text(2e4,550,'Region of Safe Ejection','FontSize',13)


 

