% m-file Ch6_CaseStudy.m
% plots Figures 6.71 - 6.74

% Chapter 6 - Case Study: Spread of an Epidemic
% Part 1 - Investigating the effect of inoculations

clc; clear all; close all

T=0.1;
tfinal=200; % weeks
ifinal=round(tfinal/T);
t0=8; % Beginning of quarantine and inoculations (weeks)
I0=2500; % Constant immigration until t>T0 (people/week)
imm=I0;
alpha=0.90; % (fraction of immigrants who are susceptible)
a23=0.10; 
a24=0.003;
c=2.25e-8; % Baseline value of c for contagious effect study
x10=1e7; % Initial number of susceptibles (people)
xA(1,1)=x10; 
xA(1,2:5)=0; % Other initial states are all zero
sick(1)=0; % Initial cumulative sick
tot(1)=sum(xA(1,1:5)); % Initialize sum of people in states x1 - x5

 for k=4:4 
   INC=(k-1)*5000; % Constant number of innoculations (people/week)

for i=1:ifinal
   t(i)=(i-1)*T;
   
  if t(i)<t0
    a25=0; a53=0; a54=0; imm=I0; inoc=0;
  else 
    a25=0.05; a53=a23; a54=a24; imm=0; inoc=INC;
  end % if 
     
   k1=deriv_epidemic(xA(i,1:5),imm,inoc,alpha,a23,a24,a25,a53,a54,c);   
   k2=deriv_epidemic(xA(i,1:5)+0.5*k1*T,imm,inoc,alpha,a23,a24,a25,a53,a54,c);
   k3=deriv_epidemic(xA(i,1:5)+0.5*k2*T,imm,inoc,alpha,a23,a24,a25,a53,a54,c); 
   k4=deriv_epidemic(xA(i,1:5)+k3*T,imm,inoc,alpha,a23,a24,a25,a53,a54,c);
   xA(i+1,1:5)=xA(i,1:5)+(T/6)*(k1+2*k2+2*k3+k4);  % Update state
   tot(i+1)=sum(xA(i+1,1:5));  
        
   %%%%% RK-4 for cumulative sick %%%%%
   const=(1-alpha)*imm;
   k1=const+c*xA(i,1)*xA(i,2);
   k2=const+c*(xA(i,1)+0.5*k1*T)*(xA(i,2)+0.5*k1*T);
   k3=const+c*(xA(i,1)+0.5*k2*T)*(xA(i,2)+0.5*k2*T);
   k4=const+c*(xA(i,1)+k3*T)*(xA(i,2)+k3*T);
   sick(i+1)=sick(i)+(T/6)*(k1+2*k2+2*k3+k4); % Update cumulative sick number   
     
end % for i
t(i+1)=ifinal*T;

del=round((ifinal+1)/20);
figure(k)

subplot(2,1,1)
hold on
plot(t(1:del:end),xA(1:del:end,1),'.--b','MarkerSize',10)
plot(t(1:del:end),xA(1:del:end,3),'.--r','MarkerSize',10)
plot(t(1:del:end),sick(1:del:end),'.--k','MarkerSize',10)
axis([0 200 0 10.5e6])
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:20:200])
set(gca,'YTick',[0:2e6:10e6])

switch k
  case 1
  text(30,11.2e6,'Simulation Results (N_0 = 0 inoculations per week)','FontSize',11)
  text(28,8.8e6,'x_1','FontSize',13)
  text(120,2.6e6,'x_3','FontSize',13)
  text(88,3.5e6,'s','FontSize',13)
    
  case 2
  text(30,11.2e6,'Simulation Results (N_0 = 5,000 inoculations per week)','FontSize',11)
  text(28,8.7e6,'x_1','FontSize',13)
  text(180,7e6,'x_3','FontSize',13)
  text(167,3e6,'s','FontSize',13)
  plot([172 180],[3.5e6 4.85e6],'k')
  
  case 3
  text(30,11.2e6,'Simulation Results (N_0 = 10,000 inoculations per week)','FontSize',11)
  text(30,8.5e6,'x_1','FontSize',13)
  text(105,4.40e6,'x_3','FontSize',13)
  text(159,3.1e6,'s','FontSize',13)
  
  case 4
  text(30,11.2e6,'Simulation Results (N_0 = 15,000 inoculations per week)','FontSize',11)
  text(30,8.5e6,'x_1','FontSize',13)
  text(75,3.2e6,'x_3','FontSize',13)
  text(159,1.968e6,'s','FontSize',13)
end % 
ylabel('People','FontSize',12)

subplot(2,1,2)
hold on
plot(t(1:del:end),xA(1:del:end,2),'.--b','MarkerSize',10)
plot(t(1:del:end),xA(1:del:end,4),'.--r','MarkerSize',10)
plot(t(1:del:end),xA(1:del:end,5),'.--k','MarkerSize',10)
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:20:200])
set(gca,'YTick',[0:1e5:6e5])

switch k
  case 1
  text(30,6.5e5,'Simulation Results (N_0 = 0 inoculations per week)','FontSize',11)
  text(58.5,2.7e5,'x_2','FontSize',13)
  text(175,2.35e5,'x_4','FontSize',13)
  text(105,3.4e5,'x_5','FontSize',13)
  
  case 2
  text(30,6.3e5,'Simulation Results (N_0 = 5,000 inoculations per week)','FontSize',11)
  text(58.5,2.4e5,'x_2','FontSize',13)
  text(175,2.20e5,'x_4','FontSize',13)
  text(106,2.85e5,'x_5','FontSize',13)
  
  case 3
  text(30,4.2e5,'Simulation Results (N_0 = 10,000 inoculations per week)','FontSize',11)
  text(60,2e5,'x_2','FontSize',13)
  text(175,1.65e5,'x_4','FontSize',13)
  text(106,2.15e5,'x_5','FontSize',13)   
  
  case 4
  text(30,3.2e5,'Simulation Results (N_0 = 15,000 inoculations per week)','FontSize',11)
  text(67,2e5,'x_2','FontSize',13)
  text(175,1.30e5,'x_4','FontSize',13)
  text(103,1.62e5,'x_5','FontSize',13)
end % 
xlabel('t  (weeks)','FontSize',12)
ylabel('People','FontSize',12)

end % for k

%%%%%%%%%%%%%%%%%%%% begin sensitivity analysis  %%%%%%%%%%%%%%%%%%%%
% Chapter 6 - Case Study: Spread of an Epidemic
% Part 2 - Sensitivity of cumulative sick and Number of deaths to contagious parameter c

%clc; clear all; close all

% T=0.1;
% tfinal=200; % weeks
% ifinal=round(tfinal/T);
% t0=8; % Beginning of quarantine and inoculations (weeks)
% I0=2500; % Constant immigration until t>t0 (people/week)
% imm=I0;
% alpha=0.90; % (fraction of immigrants who are susceptible)
% a23=0.10; 
% a24=0.003;
c0=2.25e-8; % Baseline value of c for contagious effect study

x1_initial=1e7; % Initial number of susceptibles (people)
xA(1,1)=x1_initial; 
xA(1,2:5)=0; % Other initial states are all zero
sick(1)=0; % Initial cumulative sick
tot(1)=sum(xA(1,1:5)); % Initialize sum of people in states x1 - x6

j=1; % index of data pt
for c=linspace(0.75*c0,1.25*c0,15) % 15 equally spaced values of parameter 
                                   % c from 75% of c0 to 125% of c0
INC=0;

for i=1:ifinal
   t(i)=(i-1)*T;
   
  if t(i)<t0
    a25=0; a53=0; a54=0; imm=I0; inoc=0;
  else 
    a25=0.05; a53=a23; a54=a24; imm=0; inoc=INC;
  end % if 
     
   k1=deriv_epidemic(xA(i,1:5),imm,inoc,alpha,a23,a24,a25,a53,a54,c);   
   k2=deriv_epidemic(xA(i,1:5)+0.5*k1*T,imm,inoc,alpha,a23,a24,a25,a53,a54,c);
   k3=deriv_epidemic(xA(i,1:5)+0.5*k2*T,imm,inoc,alpha,a23,a24,a25,a53,a54,c); 
   k4=deriv_epidemic(xA(i,1:5)+k3*T,imm,inoc,alpha,a23,a24,a25,a53,a54,c);
   xA(i+1,1:5)=xA(i,1:5)+(T/6)*(k1+2*k2+2*k3+k4);  % Update state
   tot(i+1)=sum(xA(i+1,1:5)); % Calculate total individuals in states 1 - 5 
        
   %%%%% RK-4 for cumulative sick %%%%%
   const=(1-alpha)*imm;
   k1=const+c*xA(i,1)*xA(i,2);
   k2=const+c*(xA(i,1)+0.5*k1*T)*(xA(i,2)+0.5*k1*T);
   k3=const+c*(xA(i,1)+0.5*k2*T)*(xA(i,2)+0.5*k2*T);
   k4=const+c*(xA(i,1)+k3*T)*(xA(i,2)+k3*T);
   sick(i+1)=sick(i)+(T/6)*(k1+2*k2+2*k3+k4); % Update cumulative sick number
         
end % for i
t(i+1)=ifinal*T;

cc(j)=c; getsick(j)=sick(end); died(j)=xA(end,4); % save values of c, number sick,
                                                  % number died for jth data pt
j=j+1; % increment data pt index

end % for c

figure
plot(cc(8),getsick(8),'*r') % plot baseline data pt for number sick vs c=c0
hold on
plot(cc([1:7 9:15]),getsick([1:7 9:15]),'.b:','MarkerSize',13) % plot other data pts for number sick vs c
xlabel('\itc  \rm(people ^{-1}- week ^{-1})','FontSize',11)
ylabel('\its\rm(200),   people','FontSize',11)
text(1.8e-8,8.63e6,'Sensitivity of Cumulative Sick After 200 Weeks to','FontSize',11)
text(1.63e-8,8.22e6,'Variation in Parameter Measuring Contagiousness of Disease','FontSize',11)
text(2.4e-8,3.25e6,'baseline pt','FontSize',11)
plot(2.35e-8,3.25e6,'*r')
text(2.4e-8,2.5e6,'cumulative sick','FontSize',11)
plot(2.35e-8,2.5e6,'.b','MarkerSize',14)


figure
plot(cc(8),died(8),'*r') % plot baseline data pt for number died vs c=c0
hold on
plot(cc([1:7 9:15]),died([1:7 9:15]),'.b:','MarkerSize',13) % plot other data pts for number died vs c
xlabel('\itc  \rm(people ^{-1}- week ^{-1})','FontSize',11)
ylabel('\itx\rm_{4}(200),   people','FontSize',11)
text(1.75e-8,2.69e5,'Sensitivity of Cumulative Deaths After 200 Weeks to','FontSize',11)
text(1.63e-8,2.57e5,'Variation in Parameter Measuring Contagiousness of Disease','FontSize',11)
text(2.4e-8,1.25e5,'baseline pt','FontSize',11)
plot(2.35e-8,1.25e5,'*r')
text(2.4e-8,1.0e5,'cumulative deaths','FontSize',11)
plot(2.35e-8,1.0e5,'.b','MarkerSize',14)
