% m-file Ch6_CaseStudy_Sensitivity.m
% plots Figure 6.75 and Figure 6.76

% Chapter 6 - Case Study: Spread of an Epidemic
% Part 2 - Sensitivity of cumulative sick and Number of deaths to contagious parameter c

clc; clear all; close all

T=0.1;
tfinal=200; % weeks
ifinal=round(tfinal/T);
t0=8; % Beginning of quarantine and inoculations (weeks)
I0=2500; % Constant immigration until t>t0 (people/week)
imm=I0;
alpha=0.90; % (fraction of immigrants who are susceptible)
a23=0.10; 
a24=0.003;
c0=2.25e-8; % Baseline value of c for contagious effect study

x1_initial=1e7; % Initial number of susceptibles (people)
xA(1,1)=x1_initial; 
xA(1,2:5)=0; % Other initial states are all zero
sick(1)=0; % Initial cumulative sick
tot(1)=sum(xA(1,1:5)); % Initialize sum of people in states x1 - x6

j=1; % index of data pt
for c=linspace(0.75*c0,1.25*c0,15) % 15 equally spaced values of parameter 
                                   % c from 75% of c0 to 125% of c0
INC=0;

for i=1:ifinal
   t(i)=(i-1)*T;
   
  if t(i)<t0
    a25=0; a53=0; a54=0; imm=I0; inoc=0;
  else 
    a25=0.05; a53=a23; a54=a24; imm=0; inoc=INC;
  end % if 
     
   k1=deriv_epidemic(xA(i,1:5),imm,inoc,alpha,a23,a24,a25,a53,a54,c);   
   k2=deriv_epidemic(xA(i,1:5)+0.5*k1*T,imm,inoc,alpha,a23,a24,a25,a53,a54,c);
   k3=deriv_epidemic(xA(i,1:5)+0.5*k2*T,imm,inoc,alpha,a23,a24,a25,a53,a54,c); 
   k4=deriv_epidemic(xA(i,1:5)+k3*T,imm,inoc,alpha,a23,a24,a25,a53,a54,c);
   xA(i+1,1:5)=xA(i,1:5)+(T/6)*(k1+2*k2+2*k3+k4);  % Update state
   tot(i+1)=sum(xA(i+1,1:5)); % Calculate total individuals in states 1 - 5 
        
   %%%%% RK-4 for cumulative sick %%%%%
   const=(1-alpha)*imm;
   k1=const+c*xA(i,1)*xA(i,2);
   k2=const+c*(xA(i,1)+0.5*k1*T)*(xA(i,2)+0.5*k1*T);
   k3=const+c*(xA(i,1)+0.5*k2*T)*(xA(i,2)+0.5*k2*T);
   k4=const+c*(xA(i,1)+k3*T)*(xA(i,2)+k3*T);
   sick(i+1)=sick(i)+(T/6)*(k1+2*k2+2*k3+k4); % Update cumulative sick number
         
end % for i
t(i+1)=ifinal*T;

cc(j)=c; getsick(j)=sick(end); died(j)=xA(end,4); % save values of c, number sick,
                                                  % number died for jth data pt
j=j+1; % increment data pt index

end % for c

figure(1) % plot Figure 6.75
plot(cc(8),getsick(8),'*r','MarkerSize',8) % plot baseline data pt for number sick vs c=c0
hold on
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[1.6e-8:0.2e-8:3e-8])
set(gca,'YTick',[0:1e6:8e6])
plot(cc([1:7 9:15]),getsick([1:7 9:15]),'.b--','MarkerSize',12) % plot other data pts for number sick vs c
xlabel('c  (people^{-1} per week)','FontSize',13)
ylabel('s_A(200),  people','FontSize',13)
text(2.3e-8,3.25e6,'baseline','FontSize',13)
plot(2.25e-8,3.2e6,'*r','MarkerSize',8)
text(2.3e-8,2.2e6,'cumulative sick','FontSize',13)
plot(2.25e-8,2.2e6,'b.','MarkerSize',12)
title({'Sensitivity of Cumulative Sick After 200 Weeks to Variation in ';'        Parameter measuring Contagiousness of Disease'}) 

figure(2) % plot Figure 6.76
plot(cc(8),died(8),'*r','MarkerSize',8) % plot baseline data pt for number died vs c=c0
hold on
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[1.6e-8:0.2e-8:3e-8])
set(gca,'YTick',[0:0.25e5:2.5e5])
plot(cc([1:7 9:15]),died([1:7 9:15]),'.b--','MarkerSize',12) % plot other data pts for number died vs c
xlabel('c  (people^{-1} per week)','FontSize',13)
ylabel('x_4(200),  people','FontSize',13)
text(2.3e-8,1.075e5,'baseline','FontSize',13)
plot(2.25e-8,1.075e5,'*r','MarkerSize',8)
text(2.3e-8,0.819e5,'cumulative deaths','FontSize',13)
plot(2.25e-8,0.819e5,'b.','MarkerSize',12)
title({'Sensitivity of Cumulative Deaths After 200 Weeks to Variation in ';'        Parameter measuring Contagiousness of Disease'})






