% m-file Ch6_12.m
% plots Figure 6.67 and Figure 6.68

clc, clear all, close all

global g R m J gamma r alpha thetaL T ISTATE

g=32.17; % gravitational constant
R=3; % pendulum length (ft)
dens_iron=7.87*62.43; % density of iron (lb per cu ft)
r=2.5; % radius of bob (in)
r=r/12; % radius of bob (ft)
V=(4/3)*pi*r^3; % volume of bob (cu ft)
W=dens_iron*V; % weight of iron bob
m=W/g; % mass of iron bob (slug)
gamma=150; % sp wt of water (lb per cu ft); 
FB=gamma*V; % buoyant force (lb)
J=m*R^2; % imertia of bob
alpha=0.3; % drag coefficent (lbs per ft/sec)
L=2.25; % vertical distance from center of rotation to liquid (ft)
thetaL=acos(L/R);  % rad, |theta|<thetaL means bob is submersed in liquid 
thetad0=0;  % initial angular speed (deg/sec)
x20=thetad0*pi/180;  % initial angular speed (rad/sec)
theta_init=[ ];
theta_min=[ ];

th1=45;
th2=60;
del_th=0.5;
for theta0=th1:del_th:th2; % initial angular displacement (deg)
   
x10=theta0*pi/180; % initial angular displacement (rad)
x1(1)=x10;
x2(1)=x20;
[ph1(1) ph2(1)]=DFUNCT(x10,x20);
ph1_old=ph1(1); 
ph2_old=ph2(1); 
ISTATE=CNTRL(ph1(1),ph2(1));

T=0.1; % integration step (sec)
tfinal=5;
i=1;
t(1)=0;
ti=0;

while ti<tfinal 
  flag=0;   % reset flag indicating the start of new interval
  [x1(i+1) x2(i+1)]=RK4(T,x1(i),x2(i),ISTATE); % compute state at ti+T
  [ph1_new ph2_new]=DFUNCT(x1(i+1),x2(i+1));  % compute ph1 and ph2 at ti+T
  
  % i,ti,ph1_old,ph1_new,ph2_old,ph2_new 
  if ph1_old*ph1_new <0 | ph2_old*ph2_new <0 % check if either ph1 or ph2 changed sign from ti to ti+T
  
    x11=x1(i);
    x22=x2(i);
    if ph1_old*ph1_new <0 % check if ph1 changed sign 
       a=INTRP(ti,ph1_old,ph1_new,x11,x22,1);  % find point in interval ti+aT where ph1=0      
    elseif ph2_old*ph2_new <0 % check if ph2 changed sign 
       a=INTRP(ti,ph2_old,ph2_new,x11,x22,2); % find point in interval ti+aT where ph2=0
    end % if    
      
    [x1(i+1) x2(i+1)]=RK4(a*T,x1(i),x2(i),ISTATE);  % compute state at ti+aT
    [ph1(i+1) ph2(i+1)]=DFUNCT(x1(i+1),x2(i+1)); % compute ph1 and ph2 at ti+aT   
   
    %%%%% change ISTATE at ti+aT
    if ISTATE== 1    
      ISTATE=2; % from 1 to 2
    else 
      ISTATE=1; % from 2 to 1                    
    end % if       
    [x1(i+2) x2(i+2)]=RK4(T-a*T,x1(i+1),x2(i+1),ISTATE); % compute state at ti+T and store in x1 and x2 arrays  
    [ph1(i+2) ph2(i+2)]=DFUNCT(x1(i+2),x2(i+2)); % compute ph1 and ph2 at ti+T and store in ph1 and ph2 arrays              
    flag=1;  % set flag indicating interpolation step was executed    
    
  end % if   
  
    if flag ==0 % check if no interpolation occurred
      t(i+1)=ti+T; % store ti+T in t array   
      ph1(i+1)=ph1_new; % store ph1 at ti+T in array ph1
      ph2(i+1)=ph2_new; % store ph2 at ti+T in array ph2
      ISTATE=CNTRL(ph1_new,ph2_new); % compute ISTATE at ti+T
      IST(i+1)=ISTATE; % save ISTATE at ti+T in array IST
      ph1_old=ph1_new; % save ph1 value
      ph2_old=ph2_new; % save ph2 value       
      i=i+1; % increment array index i by 1
    end % if  
    
    if flag==1
       t(i+1)=ti+a*T; % store point ti+aT in t array  
       t(i+2)=ti+T; % store point ti+T in next location of t array
       ph1_old=ph1(i+2); % store ph1 array value at ti+T in ph1_old
       ph2_old=ph2(i+2); % store ph2 array value at ti+T in ph2_old  
       ISTATE=CNTRL(ph1_old,ph2_old); % compute ISTATE at ti+T
       IST(i+2)=ISTATE; % save ISTATE at ti+T in array IST
       i=i+2; % increment array index i by 2
    end % if            
    
    ti=ti+T; % Compute ti for next iteration of while loop
    
end % while

x1=(180/pi)*x1; % convert theta from rad to degrees
thetaL_deg=thetaL*180/pi;  % convert thetaL from rad to degrees

theta_init=[theta_init theta0];
theta_min=[theta_min min(x1)];

end % for

plot(theta_init,theta_min,'.:')
hold on
plot([th1 th2],[-thetaL_deg -thetaL_deg])
xlabel('\theta(0),  (deg)','FontSize',11)
ylabel('\theta_{min}  (deg)','FontSize',11)
text(46,-40.75,'\theta_{L} = -41.4 deg','FontSize',11)
title('Minimum Angular Displacement vs Initial Angular Displacement','FontSize',11)
text(53,-33,'\itR \rm= 3 ft','FontSize',11)
text(53,-34.5,'\itL \rm= 2.25 ft','FontSize',11)
text(53,-36,'\itr \rm= 2.5 in','FontSize',11)
text(53,-37.5,'\gamma_{bob} = 491.3 lb per cu ft','FontSize',11)
text(53,-39,'\alpha = 0.3 lb per ft/sec','FontSize',11)
text(53,-40.5,'\gamma = 150 lb per cu ft','FontSize',11)
text(47.5,-45,'\itd\theta \rm(0) /dt\rm = 0 deg/sec','FontSize',11)

%%%%% prepare for plot of pendulum angle with theta(0) = 52 deg
T=0.001; % reduce integration step size to generate "exact" soln
x10=52*pi/180; % start pendulum at 52 deg
sim('pendulum')
ttt=t_theta(:,1);
theta_exact=t_theta(:,2);
figure
plot(ttt,theta_exact,'b')
axis([0 5 -50 60])
hold on
plot([0 5],[-41.4 -41.4],':k')
text(2.5,-36.5,'\theta = -\theta_{L} = -41.4 deg','FontSize',11)
title('Angular Displacement of Pendulum for \theta(0) = 52 deg','FontSize',11)
text(0.25,50,'Exact solution approximated by Simulink RK-4, \itT \rm= 0.001 sec','FontSize',11)
ylabel('\theta(\itt\rm),  \rmdeg','FontSize',11)
xlabel('\itt  \rm(sec)','FontSize',11)