% m-file Ch6_Ex6_3.m
% RK-4 integration of 2nd order system
% generates values for Table 6.3
% plots Figure 6.6

clc; clear all; close all

c1=0.06; c2=0.015;
M=5; tau=4;

% RK-4
T=1;
tfinal=300;
i_final=round(tfinal/T);
xA=[0;0];
xAx(1,1)=xA(1); xAx(2,1)=xA(2);
k1=[0;0];k2=k1;k3=k1;k4=k1;

for i=1:i_final
    ti=(i-1)*T;
    tt(i)=ti;
    
   u=M*exp(-ti/tau);
   k1=statederiv_f(ti,xA,u);
   u=M*exp(-(ti+0.5*T)/tau);
   k2=statederiv_f(ti+0.5*T,xA+0.5*k1*T,u);
   k3=statederiv_f(ti+0.5*T,xA+0.5*k2*T,u);
   u=M*exp(-(ti+T)/tau);
   k4=statederiv_f(ti+T,xA+k3*T,u);
   
   xA=xA+(T/6)*(k1+2*k2+2*k3+k4);
   xAx(1,i+1)=xA(1);
   xAx(2,i+1)=xA(2);
end % for i

% Exact Solution
ti=linspace(0,tfinal,500);
z3=c1-c2; z1=(1/tau)-c1; z2=(1/tau)-c2;
A=(c1*M)/(z3*z1*z2);
e1=exp(-c1*ti); e2=exp(-c2*ti); e3=exp(-ti/tau);
x1i=A*(z1*e2-z2*e1+z3*e3);

incr=4;
v=1:incr:i_final;

subplot(2,1,1)
plot(tt(v),xAx(1,v),'.r','MarkerSize',9)
grid on
set(gca,'FontSize',11)
hold on
plot(ti,x1i,'b','LineWidth',1.3)
text (200,10.7,'x_{1,A}(i),i = 0,4,8,...','FontSize',13)
plot(190,10.7,'.r','MarkerSize',9)
text(200,5.7,'x_1(t)','FontSize',13)
plot([185 195],[5.7 5.7],'b','LineWidth',1.3)
xlabel('t  (min)','FontSize',13)
ylabel('x_1 =  m_2   (mg)','FontSize',13)
title ('RK- 4 Integration (T = 1 min)','FontSize',11)

subplot(2,1,2)
plot(tt(v),xAx(2,v),'.r','MarkerSize',9)
axis([0 300 -0.2 0.8])
set(gca,'YTick',[-0.2:0.2:0.8])
grid on
set(gca,'FontSize',11)
text(100,0.44,'x_{2,A}(i), i = 0,4,8,...','FontSize',13)
hold on
plot(90,0.44,'.r','MarkerSize',9)
xlabel('t  (min)','FontSize',13)
ylabel('x_2 =  dm_2/dt   (mg/min)','FontSize',13)


