% m-file Ch6_Ex6_6
% cals Simulink model boat_xt_yt.mdl
% plots Figures 6.13,6.14 and 6.15

clc; close all; clear all

% Part B) Plot x vst, y vs t, theta vs t %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
opts1=simset('Solver','ode45','RelTol',1.0E-9,'MaxStep',20);
[t1,xs1,theta1]=sim('boat_xt_yt',[],opts1); % xs1=[x y] with ode45
opts2=simset('Solver','ode4','FixedStep',0.01);
[t2,xs2,theta2]=sim('boat_xt_yt',[],opts2); % xs1=[x(t) y(t)] with ode4 (exact soln)

figure(1) % begin plot Figure 6.13
subplot(3,1,1)
plot(t1,xs1(:,1),'.r','MarkerSize',9) % plot x vs t data pts
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:50:350])
set(gca,'YTick',[0:250:1000])
ylabel('x  (ft)','FontSize',13)
hold on
plot(t2,xs2(:,1),'b','LineWidth',1.3) % plot x(t) vs t
axis([0 350 0 1100])
title('Results of Boat Crossing Simulation','FontSize',11)
text(50,850,'ode45','FontSize',13)
plot(40,850,'.r','MarkerSize',9)
text(50,600,'x(t)','FontSize',13)
plot([35 45],[570 570],'b','LineWidth',1.3)

subplot(3,1,2)
plot(t1,xs1(:,2),'.r','MarkerSize',9) % plot y vs t data pts
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:50:350])
set(gca,'YTick',[0:1250:5000])
ylabel('y  (ft)','FontSize',11)
hold on
plot(t2,xs2(:,2),'b','LineWidth',1.3) % plot y(t) vs t
text(50,4150,'ode45','FontSize',13)
plot([40],[4150],'.r','MarkerSize',9)
text(50,2850,'y(t)','FontSize',11)
plot([35 45],[2820 2820],'b','LineWidth',1.3)

subplot(3,1,3)
plot(t1,theta1,'.r','MarkerSize',9) % plot theta vs t data pts
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:50:350])
axis([0 350 77 92])
xlabel('t  (s)','FontSize',13)
ylabel('\theta  (deg)','FontSize',13)
hold on
plot(t2,theta2,'b','LineWidth',1.3) % plot theta(t) vs t
text(50,88,'ode45','FontSize',13)
plot(40,88,'.r','MarkerSize',9)
text(50,84,'\theta(t)','FontSize',13)
plot([35 45],[83.6 83.6],'b','LineWidth',1.3)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Part C) Plot theta(x) vs x in Figure 6.14 %%%%%%%%%%%%%%%%%%%%%%%%
figure(2)  % begin plot Figure 6.14
plot(xs1(:,1),theta1,'.r','MarkerSize',9) % plot theta vs x data pts
axis([0 1050 78 90])
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:100:1000])
xlabel('x  (ft)','FontSize',13)
ylabel ('\theta   (deg)','FontSize',13)
title('Steering Angle \theta(x) (deg) vs. Horizontal Distance x (ft)','FontSize',11)
hold on
plot(xs2(:,1),theta2,'b','LineWidth',1.3) % plot theta(x) vs x
text(200,86.2,'\theta_A(i) using ode45','FontSize',13)
plot(150,86.25,'.r','MarkerSize',9)
text(200,84.28,'\theta (x)','FontSize',13)
plot([120 180],[84.28 84.28],'b','LineWidth',1.3)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Part E) R-K-Fehlberg soln

L=1000;
H=5000;
conv=528/360;
vr=5; vr=vr*conv;
vb=15; vb=vb*conv;
tol_1=1e-7;
tol_2=1e-5;
Tmax=25;
Tmin=0.1;
clear x
x(1)=0;
yA(1)=0;
T(1)=1; 
lte(1)=0;
i=1;
  
  while x(i) < L-0.1
      
    k1=deriv_boat(x(i),yA(i));
    k2=deriv_boat(x(i)+0.25*T(i),yA(i)+0.25*T(i)*k1);
    k3=deriv_boat(x(i)+(3/8)*T(i),yA(i)+(3/32)*T(i)*k1+(9/32)*T(i)*k2);
    k4=deriv_boat(x(i)+(12/13)*T(i),yA(i)+(1932/2197)*T(i)*k1-(7200/2197)*T(i)*k2+(7296/2197)*T(i)*k3);
    k5=deriv_boat(x(i)+T(i),yA(i)+(439/216)*T(i)*k1-8*T(i)*k2+(3680/513)*T(i)*k3-(845/4104)*T(i)*k4);
    k6=deriv_boat(x(i)+0.5*T(i),yA(i)-(8/27)*T(i)*k1+2*T(i)*k2-(3544/2565)*T(i)*k3+(1859/4104)*T(i)*k4-(11/40)*T(i)*k5);
    
    yA(i+1)=yA(i)+T(i)*((16/135)*k1+(6656/12825)*k3+(28561/56430)*k4-(9/50)*k5+(2/55)*k6);
    lte(i+1)=T(i)*((1/360)*k1-(128/4275)*k3-(2197/75240)*k4+(1/50)*k5+(2/55)*k6); 
     
   if abs(lte(i+1))<tol_1
       T(i+1)=min(2*T(i),Tmax);
   elseif abs(lte(i+1)) > tol_2 
           T(i+1)=max(Tmin,T(i)/2);
   else T(i+1)=T(i);
   end % if
   
    x(i+1)=x(i)+T(i);
    i=i+1;
      
end % while
 
% Part F Plot Analytical and RK-Fehlberg solutions in Figure 5.16 %%%%%%%%%%%%
figure(3) % begin plot Figure 6.15
plot(x,yA,'.r','MarkerSize',9) % Plot R-K-Fehlberg data pts
axis([0 1050 0 5400])
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:100:1000])
set(gca,'YTick',[0:500:5000])
xlabel('x  (ft)','FontSize',13)
ylabel('y  (ft)','FontSize',13)
hold on
k=vr/vb;
D0=sqrt(L^2 + H^2);
x_final=999.9;
c=(L^(k-1))*(H+D0);
cc=(L^(k-1))*(H-D0);
xx=0:x_final;
z=L-xx;
y=H-(z/2).*(c*z.^(-k)-(1/c)*z.^k);
plot(xx,y,'b','LineWidth',1.3) % plot analytical soln y(x) vs x
title('Path of Boat','FontSize',11)
text(150,3585,'RK-Fehlberg: y_A(i), i = 0,1,2,3,...','FontSize',13)
plot(100,3620,'.r','MarkerSize',9)
text(150,3125,'Exact: y(x)','FontSize',13)
plot([80 120],[3120 3120],'b','LineWidth',1.3)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
