% m-file Ch6_Ex6_9.m
% plots Figure 6.24 and Figure 6.25

clc; close all; clear all;

R=25;
L=0.02;
C=0.2;
v0=12;
x10=0;
x20=v0/L;

r=roots([L*C R*C 1]);
r1=r(1);
r2=r(2);
tau1=-1/r1;
tau2=-1/r2;
tfinal=5*max(tau1,tau2);

options=simset('Solver','ode2','FixedStep',0.0015);
[tA,xA,y]=sim('stiff_circuit',tfinal,options);
options=simset('Solver','ode2','FixedStep',0.0016);
[tB,xB,y]=sim('stiff_circuit',tfinal,options);
options=simset('Solver','ode23s');
[tC,xC,y]=sim('stiff_circuit',tfinal,options);
options=simset('Solver','ode2','FixedStep',0.002);
[tD,xD,y]=sim('stiff_circuit',0.04,options);

figure(1)
% begin plot Figure 6.24
subplot(2,2,1)
v=[1:40 40:500:length(tA)];
plot(tA(v),xA(v,1),'.r')
axis([-1 26 -0.05 0.55])
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:5:25])
set(gca,'YTick',[0:0.1:0.5])
hold on
D=v0/(L*(r1-r2));
ti=linspace(0,tfinal,500);
yi=D*(exp(r1*ti)-exp(r2*ti));
plot(ti,yi,'b','LineWidth',1.3)
title('RK-2 (T = 0.0015 s)','FontSize',11)
text(4,0.45,'x_{1,A}, i= 0,1,..,40,540,...','FontSize',11)
plot(3.0,0.45,'.r')
text(6,0.35,'i(t), t \geq 0','FontSize',11)
plot([3 5],[0.34 0.34],'b','LineWidth',1.3)

subplot(2,2,2)
del=1;
plot(tC(1:del:end),xC(1:del:end,1),'.r')
axis([-1 26 -0.05 0.55])
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:5:25])
set(gca,'YTick',[0:0.1:0.5])
hold on
plot(ti,yi,'b','LineWidth',1.3)
title('Stiff Integrator ode23s','FontSize',11)
text(3,0.45,'x_{1,A}(i), i = 0,1,2,...,72','FontSize',12)
plot(2,0.45,'.r')
text(6,0.35,'i(t), t \geq 0','FontSize',12)
plot([3 5],[0.34 0.34],'b','LineWidth',1.3)

subplot(2,2,3)
del=500;
plot(tB(1:del:end),xB(1:del:end,1),'.r')
axis([-1 26 -12e-14 1e-14])
grid on
hold on
set(gca,'FontSize',11)
set(gca,'XTick',[0:5:25])
set(gca,'YTick',[-10e-14:2e-14:0])
xlabel('t  (s)','FontSize',12)
% axis([-1 25 min(xB(:,1)) max(xB(:,1))])
title('               RK-2 (T = 0.0016 s)','FontSize',11)
text(1,-10.5e-14,'x_{1,A}(i), i = 0,500,1000,...','FontSize',12)
plot(0,-10.5e-14,'.r')

subplot(2,2,4)
plot(tD,xD,'.r')
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.01:0.04])
xlabel('t  (s)','FontSize',12)
axis([-0.002 0.042 1.05*min(xD(:,1)) 500])
title('RK-2 (T = 0.002 s)','FontSize',11)
text(0.007,-7e3,'x_{1,A}(i), i = 0,1,2,...','FontSize',12)

for i=1:length(tC)-1
    tcDiff(i)=tC(i+1)-tC(i);
end

figure(2) % begin plot Figure 6.25
plot(tcDiff,'.b','MarkerSize',10)
grid on
set(gca,'FontSize',11)
hold on
axis([0 80 -0.05 0.55])
xlabel('Step Number','FontSize',13)
ylabel('Step Size','FontSize',13)
title('Stiff Integrator ''ode23s'' Step Sizes','FontSize',13)
text(23,0.025,'t = 0.0368 s','FontSize',13) 
text(24,0.12,'t = 0.1529 s','FontSize',13) 
text(22.45,0.44,'t = 0.6528 s','FontSize',13)
plot([23 23],[0.465 0.5],'k')
text(55,0.44,'t = 24.6490 s','FontSize',13) 
plot([71 71],[0.465 0.5],'k')
text(59.5,0.35,'t = 25 s','FontSize',13) 