% m-file Ch6_Fig6_21.m
% generates step response x(t), approximate step response xhat(t), and xA(i)
% plots Figure 6.21

clc; clear all; close all;

B=1; K=10;
tau=B/K; % system time constant
tauF=tau/100; % fast time constant
tfinal=5*tau;
xA(1)=0; x(1)=0;
i=1;
T=0.1*tauF; % integration step size
t(1)=0;
while t(i)<tfinal
    
   F_hat(i)=K*(1-exp(-t(i)/tauF)); % approximate step input
   
   %%%%% Begin RK-4 %%%%%
   k1=(1/tau)*(-xA(i)+(1/K)*F_hat(i)); % compute state derivative function at beginning of interval
   F_hat_mid=K*(1-exp((-t(i)+0.5*T)/tauF)); % compute input at mid-point of interval
   k2=(1/tau)*(-xA(i)+0.5*k1*T+(1/K)*F_hat_mid); % compute derivative at mid-point of interval
   k3=(1/tau)*(-xA(i)+0.5*k2*T+(1/K)*F_hat_mid); % compute derivative second time at mid-point of interval
   F_hat_end=K*(1-exp((-t(i)+T)/tauF)); % compute input at end of interval
   k4=(1/tau)*(-xA(i)+k3*T+(1/K)*F_hat_end); % compute derivative at end of interval
   xA(i+1)=xA(i)+(T/6)*(k1+2*k2+2*k3+k4); % compute state update
   %%%%% End RK-4 %%%%%
   
   i=i+1; 
   t(i)=(i-1)*T;
   x(i)=1-exp(-t(i)/tau); % compute analytical step response 
   x_hat(i)=1-(1/(tau-tauF))*(tau*exp(-t(i)/tau) - tauF*exp(-t(i)/tauF));
         
 end % while
 
 t=t(1:end-1); % remove last component of t
 F_hat_normalized=F_hat/K; % compute input F_hat divided by K
 x=x(1:end-1); % remove last component of x 
 x_hat=x_hat(1:end-1); % remove last component of x_hat
 xA=xA(1:end-1); % remove last comnponent of XA
 
 subplot(2,2,1) 
 plot([0 0 0.005],[0 1 1],'b','LineWidth',1.3)
 grid on
 hold on
 plot(t,F_hat_normalized,'r','LineWidth',1.3)
 grid on
 axis([-0.0005 0.005 0 1.25])
 set(gca,'YTick',[0:0.2:1])
 set(gca,'XTick',[0:0.001:0.005])
 text(1e-3,1.10,'Ideal Unit Step')
 xlabel('t  (s)')
 text(1.5e-3,0.65,'Approximate Unit')
 text(1.5e-3,0.5,'Step Input')
 text(1.5e-3,0.25,'1 F(t)')
 text(1.5e-3,0.22,'_')
 text(1.47e-3,0.08,'K')
 text(-0.9e-3,1.4,'Unit Step Response and Simulated (RK-4) Response to Approximate Step Input')
 text(1.81e-3,0.36,'\wedge')
 
 subplot(2,2,3) 
 plot([0 0 0.5],[0 1 1],'b','LineWidth',1.3) % plot exact unit step
 grid on
 hold on
 plot(t,x,'r','LineWidth',1.3) % plot analytical step response
 axis([-0.05 0.5 0 1.25])
 set(gca,'YTick',[0:0.2:1])
 xlabel('t  (s)')
 set(gca,'XTick',[0:0.1:0.5])
 text(0.065,1.10,'Ideal Unit Step')
 text(0.065,0.3,'Unit Step Response, x(t)')
    
 subplot(2,2,2)
 plot(t(1:150:end),xA(1:150:end),'.b--')
 grid on
 axis([-0.05 0.5 0 1.1])
 set(gca,'XTick',[0:0.1:0.5])
 set(gca,'YTick',[0:0.2:1])
 text(0.13,0.52,'RK-4 Response to')
 text(0.13,0.30,'Input  1 \itF\rm(\itt\rm)')
 %text(0.20,0.73,'\rm(\itT\rm = 0.0001 sec)')
 text(-0.025,1.0,'T = 0.0001 s')
 text(0.24,0.28,'_')
 text(0.237,0.13,'K')
 xlabel('t  (s)')
 %text(-0.025,1.1,'\tau = 0.1 sec, \tau_{F} \rm= 0.001 sec')
 text(0.2731,0.40,'\wedge')
 
 
clear t xA 
xA(1)=0; x(1)=0;
i=1;
T=7.5*tauF; % integration step size
t(1)=0;
while t(i)<tfinal    
     
   %%%%% Begin RK-4 %%%%%
   k1=(1/tau)*(-xA(i)+(1/K)*F_hat(i)); % compute state derivative function at beginning of interval
   F_hat_mid=K*(1-exp((-t(i)+0.5*T)/tauF)); % compute input at mid-point of interval
   k2=(1/tau)*(-xA(i)+0.5*k1*T+(1/K)*F_hat_mid); % compute derivative at mid-point of interval
   k3=(1/tau)*(-xA(i)+0.5*k2*T+(1/K)*F_hat_mid); % compute derivative second time at mid-point of interval
   F_hat_end=K*(1-exp((-t(i)+T)/tauF)); % compute input at end of interval
   k4=(1/tau)*(-xA(i)+k3*T+(1/K)*F_hat_end); % compute derivative at end of interval
   xA(i+1)=xA(i)+(T/6)*(k1+2*k2+2*k3+k4); % compute state update
   %%%%% End RK-4 %%%%%
   
   i=i+1; 
   t(i)=(i-1)*T;
   x(i)=1-exp(-t(i)/tau); % compute analytical step response 
   x_hat(i)=1-(1/(tau-tauF))*(tau*exp(-t(i)/tau) - tauF*exp(-t(i)/tauF));
         
 end % while
 
 t=t(1:end-1); % remove last component of t
 xA=xA(1:end-1); % remove last comnponent of XA
 
 subplot(2,2,4)
 plot(t(1:2:end),xA(1:2:end),'.--b')
 grid on
 axis([-0.05 0.5 -25 7])
 set(gca,'XTick',[0:0.1:0.5])
 set(gca,'YTick',[-20:4:0])
 text(0.13,-10,'RK-4 Response to')
 text(0.2731,-14,'\wedge')
 text(0.13,-17,'Input  1 F(t)')
 %text(0.20,-6.0,'\rm(\itT\rm = 0.0075 sec)')
 text(0.05,4,'\itT\rm = 0.0075 s')
 text(0.24,-17.5,'_')
 text(0.237,-21.5,'K')
 xlabel('t  (s)')
 

 
