% m-file Ch6_coffee.m
% calls Simulink model coffee.mdl
% plots Figure 6.50 and Figure 6.51

clc, clear all, close all

D=6; % diameter of reservoir, (in)
A=pi*(0.5*D/12)^2; % cross sectional area of pot, (sq ft)
H=5; % height of water in reservoir, (in)
vol_water_res_cu_ft=A*(H/12); % volume of water in reservoir, (cu ft)
vol_water_res_oz=vol_water_res_cu_ft*7.4805*128; % volume of water in reservoir, (oz)
number_8_oz_cups=vol_water_res_oz/8  % number of 8-oz cups of coffee 
Ht=62.4*vol_water_res_cu_ft  % amount of water in reservoir, (lbs)
L=2.5; % height of coffee in bed, (in)
dz=(1/3)*(L/12); % height of coffee per section, (ft)
HL=2.723; % holdup of liquid per unit height of bed, (lb water per ft of coffee)
%beta0=1.5/60;  % amplitude component of w, lbs of water per sec
%beta1=0;
%beta2=pi/10; % frequency component of w, rad/sec
B0=3; % total amt of fresh ground coffee per volume of bed, (lb of coffee per cu ft of bed)
cs=0.2; % saturated concentration of coffee, (lb coffee per lb of water)
a=3000; % mass transfer area per unit volume of bed, (sq ft per cu ft)
Km=0.00003; % mass transfer coefficient
cf=A*dz*a*Km;
HLdz=HL*dz;
B0Adz=B0*A*dz;
tfinal=600; % sim time (sec)
t1=60; % input parameter for flow w in Look-up Table, (sec)
wbar=0.05; % output parameter for flow w in Look-up Table, (lb/sec)
sim('coffee')
t=c1(:,1);
c1=c1(:,2);
c2=c2(:,2);
c3=c3(:,2);
cR=cR(:,2);

figure(1) % plot Figure 6.50
plot(t,c1,'b','LineWidth',1.3)
axis([0 tfinal 0 0.028])
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:100:tfinal])
text(20,0.0072,'c_1(t)','FontSize',13)
hold on
plot(t,c2,'r','LineWidth',1.3)
text(56.5,0.0144,'c_2(t)','FontSize',13)
plot(t,c3,'g','LineWidth',1.3)
text(60,0.0205,'c_3(t)','FontSize',13)
plot(t,cR,'k','LineWidth',1.3)
text(150,0.0105,'c_R(t)','FontSize',13)
xlabel('t  (s)','FontSize',13)
ylabel('Concentration,  lb coffee per lb of water','FontSize',13)
title('Concentration of Coffee vs Time for Lumped Parameter Model','FontSize',11)

amt_coffee_initial=B0*A*(L/12)*16; % initial amount of fresh coffee, (oz)

amt_coffee_final_sec1=E0_1(end,2)*B0*A*dz*16; % final amount of coffee remaining in section 1, (oz)
amt_coffee_final_sec2=E0_2(end,2)*B0*A*dz*16; % final amount of coffee remaining in section 2, (oz)
amt_coffee_final_sec3=E0_3(end,2)*B0*A*dz*16; % final amount of coffee remaining in section 3, (oz)
amt_coffee_final_res=cR(end)*Ht*16; % final amount of coffee in resrvoir, (oz)
amt_coffee_final=amt_coffee_final_sec1+amt_coffee_final_sec2+amt_coffee_final_sec3+amt_coffee_final_res; % final amount of coffee (oz)

KTE1=KTE_1(:,2)*16; % coffee extracted from section 1, (oz)
KTE2=KTE_2(:,2)*16; % coffee extracted from section 2, (oz)
KTE3=KTE_3(:,2)*16; % coffee extracted from section 3, (oz)

figure(2)  % plot Figure 6.51
subplot(2,2,1)
amt_coffee_initial_sec1=amt_coffee_initial/3; % initial amount of fresh coffee in section 1, (oz)
plot([0 tfinal],[amt_coffee_initial_sec1 amt_coffee_initial_sec1],'k--','LineWidth',1.2)
grid on
axis([0 600 0 0.8])
set(gca,'FontSize',11)
set(gca,'XTick',[0:150:600])
set(gca,'YTick',[0:0.2:0.8])
hold on
plot(t,KTE1,'b','LineWidth',1.3)
ylabel('K_{TE_1}(t),  oz','FontSize',12)
text(29,0.725,'Initial amount of coffee','FontSize',11)
text(-30,0.920,'Section 1 Coffee Extraction','FontSize',11)

subplot(2,2,2)
amt_coffee_initial_sec2=amt_coffee_initial/3; % initial amount of fresh coffee in section 2, (oz)
plot([0 tfinal],[amt_coffee_initial_sec2 amt_coffee_initial_sec2],'k--','LineWidth',1.2)
hold on
grid on
axis([0 600 0 0.8])
set(gca,'FontSize',11)
set(gca,'XTick',[0:150:600])
set(gca,'YTick',[0:0.2:0.8])
plot(t,KTE2,'b','LineWidth',1.3)
ylabel('K_{TE_2}(t),  oz','FontSize',12)
text(29,0.725,'Initial amount of coffee','FontSize',11)
text(-30,0.920,'Section 2 Coffee Extraction','FontSize',11)

subplot(2,2,3)
amt_coffee_initial_sec3=amt_coffee_initial/3; % initial amount of fresh coffee in section 1, (oz)
plot([0 tfinal],[amt_coffee_initial_sec3 amt_coffee_initial_sec3],'k--','LineWidth',1.2)
hold on
grid on
axis([0 600 0 0.8])
set(gca,'FontSize',11)
set(gca,'XTick',[0:150:600])
set(gca,'YTick',[0:0.2:0.8])
plot(t,KTE3,'b','LineWidth',1.3)
ylabel('K_{TE_3}(t),  oz','FontSize',12)
text(29,0.725,'Initial amount of coffee','FontSize',11)
text(-30,0.920,'Section 3 Coffee Extraction','FontSize',11)
xlabel('t  (s)','FontSize',12)

subplot(2,2,4)
plot([0 tfinal],[amt_coffee_initial amt_coffee_initial],'k--','LineWidth',1.2)
hold on
axis([0 tfinal 0 2.5])
KTE=KTE1+KTE2+KTE3; % total coffee extracted from sections 1,2,3, (oz)
plot(t,KTE,'b','LineWidth',1.3)
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:150:600])
set(gca,'YTick',[0:0.5:2.5])
ylabel('K_{TE}(t),  oz','FontSize',12)
xlabel('t  (s)','FontSize',12)
text(30,2.20,'Initial amount of coffee','FontSize',11)
text(-100,2.85,'Sections 1,2,3 Coffee Extraction','FontSize',11)





