% m-file Ch6_discont.m
% calls Simulink model pendulum.mdl
% plots Figures 6.59 - 6.62

clc, clear all, close all

global g R m J gamma r alpha thetaL T ISTATE

g=32.17; % gravitational constant
R=3; % pendulum length (ft)
dens_iron=7.87*62.43; % density of iron (lb per cu ft)
r=2.5; % radius of bob (in)
r=r/12; % radius of bob (ft)
V=(4/3)*pi*r^3; % volume of bob (cu ft)
W=dens_iron*V; % weight of iron bob
m=W/g; % mass of iron bob (slug)

gamma=62.4; % sp wt of water (lb per cu ft);
FB=gamma*V; % buoyant force (lb)
J=m*R^2; % imertia of bob
alpha=0.15; % drag coefficent (lbs per ft/sec)
L=2.25; % vertical distance from center of rotation to liquid (ft)
thetaL=acos(L/R);  % rad, |theta|<thetaL means bob is submersed in liquid 
theta0=75; % initial angular displacement (deg)
x10=theta0*pi/180; % initial angular displacement (rad)
thetad0=0;  % initial angular speed (deg/sec)
x20=thetad0*pi/180;  % initial angular speed (rad/sec)

x1(1)=x10;
x2(1)=x20;
[ph1(1) ph2(1)]=DFUNCT(x10,x20);
ph1_old=ph1(1); 
ph2_old=ph2(1); 
ISTATE=CNTRL(ph1(1),ph2(1));
IST(1)=ISTATE;
[theta_d(1) theta_dd(1)]=f(x10,x20,ISTATE);
x1_disc=[ ];
x2_disc=[ ];
t_disc=[ ];

T=0.025; % integration step (sec)

tfinal=15;
% Change to tfinal=5.9 to generate Figure 6.63
%tfinal=5.9;
i=1;
t(1)=0;
ti=0;

while ti<tfinal 
  flag=0;   % reset flag indicating the start of new interval
  [x1(i+1) x2(i+1)]=RK4(T,x1(i),x2(i),ISTATE); % compute state at ti+T
  [ph1_new ph2_new]=DFUNCT(x1(i+1),x2(i+1));  % compute ph1 and ph2 at ti+T
  
  % i,ti,ph1_old,ph1_new,ph2_old,ph2_new 
  if ph1_old*ph1_new <0 | ph2_old*ph2_new <0 % check if either ph1 or ph2 changed sign from ti to ti+T
  
    x11=x1(i);
    x22=x2(i);
    if ph1_old*ph1_new <0 % check if ph1 changed sign 
       a=INTRP(ti,ph1_old,ph1_new,x11,x22,1);  % find point in interval ti+aT where ph1=0      
    elseif ph2_old*ph2_new <0 % check if ph2 changed sign 
       a=INTRP(ti,ph2_old,ph2_new,x11,x22,2); % find point in interval ti+aT where ph2=0
    end % if    
      
    [x1(i+1) x2(i+1)]=RK4(a*T,x1(i),x2(i),ISTATE);  % compute state at ti+aT
    t_disc=[t_disc ti+a*T];
    x1_disc=[x1_disc (180/pi)*x1(i+1)]; 
    x2_disc=[x2_disc (180/pi)*x2(i+1)]; 
    [ph1(i+1) ph2(i+1)]=DFUNCT(x1(i+1),x2(i+1)); % compute ph1 and ph2 at ti+aT   
   
    %%%%% change ISTATE at ti+aT
    if ISTATE== 1    
      ISTATE=2; % from 1 to 2
    else 
      ISTATE=1; % from 2 to 1                    
    end % if       
    IST(i+1)=ISTATE; % store ISTATE at ti+aT in array IST
    [theta_d(i+1) theta_dd(i+1)]=f(x1(i+1),x2(i+1),ISTATE); % compute theta_dot and theta_double_dot at ti+aT and store in arrays
    [x1(i+2) x2(i+2)]=RK4(T-a*T,x1(i+1),x2(i+1),ISTATE); % compute state at ti+T and store in x1 and x2 arrays  
    [ph1(i+2) ph2(i+2)]=DFUNCT(x1(i+2),x2(i+2)); % compute ph1 and ph2 at ti+T and store in ph1 and ph2 arrays              
    [theta_d(i+2) theta_dd(i+2)]=f(x1(i+2),x2(i+2),ISTATE); % compute theta_dot and theta_double_dot at ti+T and store in arrays
    flag=1;  % set flag indicating interpolation step was executed    
    
  end % if   
  
    if flag ==0 % check if no interpolation occurred
      t(i+1)=ti+T; % store ti+T in t array   
      ph1(i+1)=ph1_new; % store ph1 at ti+T in array ph1
      ph2(i+1)=ph2_new; % store ph2 at ti+T in array ph2
      ISTATE=CNTRL(ph1_new,ph2_new); % compute ISTATE at ti+T
      IST(i+1)=ISTATE; % save ISTATE at ti+T in array IST
      [theta_d(i+1) theta_dd(i+1)]=f(x1(i+1),x2(i+1),ISTATE); % save theta_dot and theta_double_dot at ti+T in arrays 
      ph1_old=ph1_new; % save ph1 value
      ph2_old=ph2_new; % save ph2 value       
      i=i+1; % increment array index i by 1
    end % if  
    
    if flag==1
       t(i+1)=ti+a*T; % store point ti+aT in t array  
       t(i+2)=ti+T; % store point ti+T in next location of t array
       ph1_old=ph1(i+2); % store ph1 array value at ti+T in ph1_old
       ph2_old=ph2(i+2); % store ph2 array value at ti+T in ph2_old  
       ISTATE=CNTRL(ph1_old,ph2_old); % compute ISTATE at ti+T
       IST(i+2)=ISTATE; % save ISTATE at ti+T in array IST
       i=i+2; % increment array index i by 2
    end % if            
    
    ti=ti+T; % Compute ti for next iteration of while loop
    
end % while

figure(1) % plot Figure 6.61
subplot(2,2,1)
hold on
x1=(180/pi)*x1; % convert theta from rad to degrees
thetaL_deg=thetaL*180/pi;  % convert thetaL from rad to degrees
plot(t,x1,'b','LineWidth',1.3)
axis([0 tfinal -90 90])
grid on
set(gca,'FontSize',11)
set(gca,'YTick',[-90:45:90])
plot([0 tfinal],[thetaL_deg thetaL_deg],'k--','LineWidth',1.2)
plot([0 tfinal],[-thetaL_deg -thetaL_deg],'k--','LineWidth',1.2)
text(3.0,70,'\theta = \theta_L = 41.4 deg','FontSize',13) % valid when tfinal = 15 sec
text(2.0,-72,'\theta = -\theta_L = -41.4 deg','FontSize',13) % valid when tfinal = 15 sec
ylabel('\theta(t),  deg','FontSize',12)

subplot(2,2,3)
plot(t,IST,'b','LineWidth',1.2)
axis([0 tfinal 0.75 2.25])
grid on
set(gca,'FontSize',11)
set(gca,'YTICK',[1 2])
xlabel('t  (s)','FontSize',12)
ylabel('ISTATE','FontSize',12)

subplot(2,2,2)
x2=(180/pi)*x2;
plot(t,x2,'b','LineWidth',1.3)
axis([0 tfinal -275 250])
grid on
set(gca,'FontSize',11)
set(gca,'YTICK',[-200:100:200])
ylabel('d\theta/dt,  deg/s','FontSize',12)

subplot(2,2,4)
theta_dd=(180/pi)*theta_dd;
plot(t,theta_dd,'b','LineWidth',1.3)
axis([0 tfinal -650 650])
grid on
set(gca,'FontSize',11)
set(gca,'YTick',[-500:250:500])
xlabel('t  (s)','FontSize',12)
ylabel('d^{2}\theta/dt^{\rm2},  deg/s^{2}','FontSize',12)

figure(2) % plot Figure 6.63 valid only for tfinal = 5.9 sec
[AX,H1,H2]=plotyy(t,x1,t,theta_dd);
grid on
% set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:6])
set(AX(1),'YColor','black','YTick',[-100:25:100],'FontSize',12)
set(AX(2),'YColor','black','YTick',[-1000:250:1000],'FontSize',12)
% set(get(AX(1),'Ylabel'),'String','\theta  (deg)') 
% set(get(AX(2),'Ylabel'),'String','d^2\theta/dt^2  (deg/sec^2)')

hold on
plot([0 tfinal],[-thetaL_deg -thetaL_deg],'k--','LineWidth',1.2)
plot([0 tfinal],[thetaL_deg thetaL_deg],'k--','LineWidth',1.2)
% next 4 lines based on 4 crossings from liquid to air
plot(t_disc(2),x1_disc(2),'r.','MarkerSize',14)
plot(t_disc(4),x1_disc(4),'r.','MarkerSize',14)
plot(t_disc(6),x1_disc(6),'r.','MarkerSize',14)
plot(t_disc(8),x1_disc(8),'r.','MarkerSize',14)
plot(t_disc(1),x1_disc(1),'r*',t_disc(3),x1_disc(3),'r*',t_disc(5),x1_disc(5),'r*',t_disc(7),x1_disc(7),'r*')
text(0.6,70,'\theta (deg)','FontSize',13)
plot([0.15 0.5],[70 70],'k')
text(0.3,-80,'d^2\theta/dt^2 (deg/s^2)','FontSize',13)
plot([0.1,0.3],[-59,-72],'k')
text(-0.15,110,'Angular Displacement (left axis) and Angular Acceleration (right axis)','FontSize',11)
xlabel('t  (s)','FontSize',13)
% ylabel('\theta(t),  (deg)','FontSize',13)
text(3,85,'air to liquid transition','FontSize',13)
plot(2.8,85,'*r')
text(3,70,'liquid to air transition','FontSize',13)
plot(2.8,70,'r.','MarkerSize',14)
% 
figure(3) % plot Figure 6.60
plot(x1,x2,'b','LineWidth',1.3)
hold on
grid on
set(gca,'FontSize',11)
plot(x1_disc,x2_disc,'r.','MarkerSize',13)
plot([-thetaL_deg -thetaL_deg],[-250 260],'k--','LineWidth',1.2)
plot([thetaL_deg thetaL_deg],[-250 260],'k--','LineWidth',1.2)
axis([-98 95 -250 250])
xlabel('\theta  (deg)','FontSize',13)
ylabel('d\theta/dt  (deg/s)','FontSize',13)
text(-90,210,'\theta = -\theta_L = -41.4 deg','FontSize',13)
text(30,210,'\theta = \theta_L = 41.4 deg','FontSize',13)
text(45,-200,'1st transition','FontSize',13)
title('Phase Portrait','FontSize',11)

% figure(4) % plot Figure 6.65
subplot(2,1,1)
hold on
plot(t,ph1,'b.')
grid on
set(gca,'FontSize',11)
axis([0 tfinal -2.5 1])
set(gca,'XTick',[0:15])
set(gca,'YTick',[-0.5:0.25:0.5])
%%%%% Uncomment next 4 lines for Figure 6.66
%  axis([-0.5 6.5 -0.5 0.5])
%  text(0.75,0.20,'\phi_1 = 0','FontSize',13)
%  text(2.9,0.20,'\phi_1 = 0','FontSize',13)
%  text(5,0.20,'\phi_1 = 0','FontSize',13) 
xlabel('t  (s)','FontSize',13)
ylabel('\phi_1','FontSize',14)
title('Discontinuity Functions','FontSize',11)
 
subplot(2,1,2)
hold on
plot(t,ph2,'b.')
grid on
set(gca,'FontSize',11)
axis([0 tfinal -2.5 1])
set(gca,'XTick',[0:15])
set(gca,'YTick',[-0.5:0.25:0.5])
%%%%% Uncomment next 5 lines for Figure 6.66
%  axis([-0.5 6.5 -0.5 0.5])
%  text(-0.3,0.20,'\phi_2 = 0','FontSize',13)
%  text(1.8,0.20,'\phi_2 = 0','FontSize',13)
%  text(3.9,0.20,'\phi_2 = 0','FontSize',13)
%  text(5.6,0.20,'\phi_2 = 0','FontSize',13) 
xlabel('t  (s)','FontSize',13)
ylabel('\phi_2','FontSize',14)
 
figure(5) % plot Figure 6.64
tfinal=5;
sim('pendulum')
plot(t,x1,'b','LineWidth',1.3)
axis([0 tfinal -100 100])
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:5])
set(gca,'YTick',[-100:25:100])
hold on
tt=t_theta(:,1);
theta=t_theta(:,2);
plot(tt,theta,'r','LineWidth',1.3)
xlabel('t  (s)','FontSize',13)
ylabel('\theta(t),  deg','FontSize',13)

T=0.001; % reduce integration step size to generate "exact" soln
sim('pendulum')
ttt=t_theta(:,1);
theta_exact=t_theta(:,2);
plot(ttt,theta_exact,'k','LineWidth',1.3)
hold on
plot([0 tfinal],[-thetaL_deg -thetaL_deg],'k--','LineWidth',1.2)
plot([0 tfinal],[thetaL_deg thetaL_deg],'k--','LineWidth',1.2)
text(1.55,-31,'\theta = -\theta_L = -41.4 deg','FontSize',13)
text(2.5,52,'\theta = \theta_L = 41.4 deg','FontSize',13)
title('Comparison of Discontinuity Method, Simulink and "Exact" Solutions','FontSize',11)
text(1.35,92,'Discontinuity method (T = 0.1 s)','FontSize',12)
plot([0.135 1.25],[70 87],'k')
text(1.35,80,'Simulink (T = 0.1 s)','FontSize',12)
plot([0.213 1.25],[62 77],'k')
text(1.35,68,'"Exact" (Simulink, T = 0.001 s)','FontSize',12)
plot([0.28 1.25],[53 67],'k')

text(1.3,-70,'\theta(0) = 75 deg, d\theta(0)/dt = 0 deg/s','FontSize',13)
text(1.3,-90,'\alpha = 0.15 lb per ft/s, \gamma = 62.4 lb per cu ft','FontSize',13)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Repeat for new initial conditions and parameters
clear all

global g R m J gamma r alpha thetaL T ISTATE

g=32.17; % gravitational constant
R=3; % pendulum length (ft)
dens_iron=7.87*62.43; % density of iron (lb per cu ft)
r=2.5; % radius of bob (in)
r=r/12; % radius of bob (ft)
V=(4/3)*pi*r^3; % volume of bob (cu ft)
W=dens_iron*V; % weight of iron bob
m=W/g; % mass of iron bob (slug)

gamma=150; % sp wt of water (lb per cu ft);
FB=gamma*V; % buoyant force (lb)
J=m*R^2; % imertia of bob
alpha=0.3; % drag coefficent (lbs per ft/sec)
L=2.25; % vertical distance from center of rotation to liquid (ft)
thetaL=acos(L/R);  % rad, |theta|<thetaL means bob is submersed in liquid 
theta0=75; % initial angular displacement (deg)
x10=theta0*pi/180; % initial angular displacement (rad)
thetad0=0;  % initial angular speed (deg/sec)
x20=thetad0*pi/180;  % initial angular speed (rad/sec)

x1(1)=x10;
x2(1)=x20;
[ph1(1) ph2(1)]=DFUNCT(x10,x20);
ph1_old=ph1(1); 
ph2_old=ph2(1); 
ISTATE=CNTRL(ph1(1),ph2(1));
IST(1)=ISTATE;
[theta_d(1) theta_dd(1)]=f(x10,x20,ISTATE);
x1_disc=[ ];
x2_disc=[ ];
t_disc=[ ];

T=0.1; % integration step (sec)

tfinal=15;
i=1;
t(1)=0;
ti=0;

while ti<tfinal 
  flag=0;   % reset flag indicating the start of new interval
  [x1(i+1) x2(i+1)]=RK4(T,x1(i),x2(i),ISTATE); % compute state at ti+T
  [ph1_new ph2_new]=DFUNCT(x1(i+1),x2(i+1));  % compute ph1 and ph2 at ti+T
  
  % i,ti,ph1_old,ph1_new,ph2_old,ph2_new 
  if ph1_old*ph1_new <0 | ph2_old*ph2_new <0 % check if either ph1 or ph2 changed sign from ti to ti+T
  
    x11=x1(i);
    x22=x2(i);
    if ph1_old*ph1_new <0 % check if ph1 changed sign 
       a=INTRP(ti,ph1_old,ph1_new,x11,x22,1);  % find point in interval ti+aT where ph1=0      
    elseif ph2_old*ph2_new <0 % check if ph2 changed sign 
       a=INTRP(ti,ph2_old,ph2_new,x11,x22,2); % find point in interval ti+aT where ph2=0
    end % if    
      
    [x1(i+1) x2(i+1)]=RK4(a*T,x1(i),x2(i),ISTATE);  % compute state at ti+aT
    t_disc=[t_disc ti+a*T];
    x1_disc=[x1_disc (180/pi)*x1(i+1)]; 
    x2_disc=[x2_disc (180/pi)*x2(i+1)]; 
    [ph1(i+1) ph2(i+1)]=DFUNCT(x1(i+1),x2(i+1)); % compute ph1 and ph2 at ti+aT   
   
    %%%%% change ISTATE at ti+aT
    if ISTATE== 1    
      ISTATE=2; % from 1 to 2
    else 
      ISTATE=1; % from 2 to 1                    
    end % if       
    IST(i+1)=ISTATE; % store ISTATE at ti+aT in array IST
    [theta_d(i+1) theta_dd(i+1)]=f(x1(i+1),x2(i+1),ISTATE); % compute theta_dot and theta_double_dot at ti+aT and store in arrays
    [x1(i+2) x2(i+2)]=RK4(T-a*T,x1(i+1),x2(i+1),ISTATE); % compute state at ti+T and store in x1 and x2 arrays  
    [ph1(i+2) ph2(i+2)]=DFUNCT(x1(i+2),x2(i+2)); % compute ph1 and ph2 at ti+T and store in ph1 and ph2 arrays              
    [theta_d(i+2) theta_dd(i+2)]=f(x1(i+2),x2(i+2),ISTATE); % compute theta_dot and theta_double_dot at ti+T and store in arrays
    flag=1;  % set flag indicating interpolation step was executed    
    
  end % if   
  
    if flag ==0 % check if no interpolation occurred
      t(i+1)=ti+T; % store ti+T in t array   
      ph1(i+1)=ph1_new; % store ph1 at ti+T in array ph1
      ph2(i+1)=ph2_new; % store ph2 at ti+T in array ph2
      ISTATE=CNTRL(ph1_new,ph2_new); % compute ISTATE at ti+T
      IST(i+1)=ISTATE; % save ISTATE at ti+T in array IST
      [theta_d(i+1) theta_dd(i+1)]=f(x1(i+1),x2(i+1),ISTATE); % save theta_dot and theta_double_dot at ti+T in arrays 
      ph1_old=ph1_new; % save ph1 value
      ph2_old=ph2_new; % save ph2 value       
      i=i+1; % increment array index i by 1
    end % if  
    
    if flag==1
       t(i+1)=ti+a*T; % store point ti+aT in t array  
       t(i+2)=ti+T; % store point ti+T in next location of t array
       ph1_old=ph1(i+2); % store ph1 array value at ti+T in ph1_old
       ph2_old=ph2(i+2); % store ph2 array value at ti+T in ph2_old  
       ISTATE=CNTRL(ph1_old,ph2_old); % compute ISTATE at ti+T
       IST(i+2)=ISTATE; % save ISTATE at ti+T in array IST
       i=i+2; % increment array index i by 2
    end % if            
    
    ti=ti+T; % Compute ti for next iteration of while loop
    
end % while
% 
% figure(6) % plot Figure 6.67
% subplot(2,2,1)
% hold on
% x1=(180/pi)*x1; % convert theta from rad to degrees
% thetaL_deg=thetaL*180/pi;  % convert thetaL from rad to degrees
% plot(t,x1)
% axis([0 tfinal -90 90])
% plot([0 tfinal],[thetaL_deg thetaL_deg],'r:')
% plot([0 tfinal],[-thetaL_deg -thetaL_deg],'r:')
% text(4.5,58,'\theta = \theta_{\itL} \rm= 41.4 deg','FontSize',11) % valid when tfinal = 15 sec
% text(4.5,-60,'\theta = -\theta_{\itL} \rm= -41.4 deg','FontSize',11) % valid when tfinal = 15 sec
% xlabel('\itt  \rm(sec)','FontSize',11)
% ylabel('\theta(\itt\rm),  deg','FontSize',11)
% 
% subplot(2,2,3)
% plot(t,IST)
% h=gca;
% set(h,'YTICK',[1 2])
% axis([0 tfinal 0.75 2.25])
% xlabel('\itt  \rm(sec)','FontSize',11)
% ylabel('ISTATE','FontSize',11)
% 
% subplot(2,2,2)
% x2=(180/pi)*x2;
% plot(t,x2)
% axis([0 tfinal -275 250])
% xlabel('\itt  \rm(sec)','FontSize',11)
% ylabel('d\theta/dt,  \rmdeg/sec','FontSize',11)
% 
% subplot(2,2,4)
% theta_dd=(180/pi)*theta_dd;
% plot(t,theta_dd)
% axis([0 tfinal -650 650])
% xlabel('\itt  \rm(sec)','FontSize',11)
% ylabel('d^{2}\theta/dt^{\rm2},  \rmdeg/sec^{2}','FontSize',11)
% 
% figure % valid only for tfinal = 5.9 sec
% plotyy(t,x1,t,theta_dd)
% hold on
% plot([0 tfinal],[-thetaL_deg -thetaL_deg],':')
% plot([0 tfinal],[thetaL_deg thetaL_deg],':')
% % next 2 lines based on 2 crossings from liquid to air
% plot(t_disc(2),x1_disc(2),'r.','MarkerSize',14)
% plot(t_disc(4),x1_disc(4),'r.','MarkerSize',14)
% %plot(t_disc(6),x1_disc(6),'r.','MarkerSize',14)
% %plot(t_disc(8),x1_disc(8),'r.','MarkerSize',14)
% plot(t_disc(1),x1_disc(1),'r*',t_disc(3),x1_disc(3),'r*',t_disc(5),x1_disc(5),'r*')
% text(0.6,70,'\theta (deg)','FontSize',11)
% plot([0.15 0.5],[70 70],'k')
% text(0.3,-80,'d^{2}\theta/dt^{\rm2} \rm(deg/sec^{2})','FontSize',11)
% plot([0.1,0.3],[-59,-72],'k')
% title('Angular Displacement and Angular Acceleration vs Time','FontSize',11)
% xlabel('\itt  \rm(sec)','FontSize',11)
% ylabel('\theta\rm(\itt\rm),  (deg)','FontSize',11)
% text(3,85,'air to liquid transition','FontSize',11)
% plot(2.8,85,'r*')
% text(3,70,'liquid to air transition','FontSize',11)
% plot(2.8,70,'r.','MarkerSize',14)
% 
% figure
% plot(x1,x2)
% hold on
% plot(x1_disc,x2_disc,'.r','MarkerSize',14)
% plot([-thetaL_deg -thetaL_deg],[-250 260],':k')
% plot([thetaL_deg thetaL_deg],[-250 260],':k')
% axis([-98 95 -250 250])
% xlabel('\theta  (deg)','FontSize',11)
% ylabel('d\theta/dt  \rm(deg/sec)','FontSize',11)
% text(-96,200,'\theta = -\theta_{\itL} \rm= -41.4 deg','FontSize',11)
% text(43,200,'\theta = \theta_{\itL} \rm= 41.4 deg','FontSize',11)
% text(45,-200,'1st transition','FontSize',11)
% title('Phase Portrait','FontSize',11)
% 
% figure
% subplot(2,1,1)
% hold on
% plot(t,ph1,'.')
% plot([0 tfinal],[0 0])
% axis([0 tfinal -2.5 1])
% xlabel('\itt  \rm(sec)','FontSize',11)
% ylabel('\phi_{1}')
% title('Discontinuity Functions','FontSize',11)
% 
% subplot(2,1,2)
% hold on
% plot(t,ph2,'.')
% plot([0 tfinal],[0 0])
% axis([0 tfinal -2.5 1])
% xlabel('\itt  \rm(sec)','FontSize',11)
% ylabel('\phi_{2}','FontSize',11)
% 
% figure
% sim('pendulum')
% plot(t,x1,'b')
% axis([0 5 -80 95])
% hold on
% tt=t_theta(:,1);
% theta=t_theta(:,2);
% plot(tt,theta,'r')
% xlabel('\itt  \rm(sec)','FontSize',11)
% ylabel('\theta(\itt\rm),  deg','FontSize',11)
% 
% T=0.001; % reduce integration step size to generate "exact" soln
% sim('pendulum')
% ttt=t_theta(:,1);
% theta_exact=t_theta(:,2);
% plot(ttt,theta_exact,'k')
% hold on
% %plot([0 5],[-thetaL_deg -thetaL_deg],':k')
% %plot([0 5],[thetaL_deg thetaL_deg],':k')
% title('Comparison of Discontinuity Method, Simulink and "Exact" Solutions','FontSize',11)
% text(0.5,77,'Discontinuity method (\itT \rm= 0.1 sec)','FontSize',11)
% text(0.5,62,'"Exact" (Simulink, \itT \rm= 0.001 sec)','FontSize',11)
% text(3.3,40,'Simulink (\itT \rm= 0.1 sec)','FontSize',11)
% plot([3 3.25],[40 40],'k')
% plot([3 3],[-25.9 40],'k')
% 
% text(1.7,-53,'\theta(0) = 75 deg, d\theta\rm(0)/dt \rm= -90 deg/sec','FontSize',11)
% text(1.7,-68,'\alpha = 0.3 lb per ft/sec, \gamma = 150 lb per cu ft','FontSize',11)
%   
% 
