function a=INTRP(ti,ph_old,ph_new,x11,x22,k)
% Interpolates to estimate pt ti+aT where one of the discontinuity
% functions is zero.  Uses linear interpolation to find intermediate pt
% ti+bT followed by quadratic interpolation based on given two pts and 
% intermediate pt.

% Inputs: ti - starting pt of interval to be interpolated
%         ph_old,ph_new - starting and ending value of discontinuity
%                         function which changed sign over interval
%         x11,x22 - state vector at start of interval
%         k - index indicating which discontinuity function changed sign

% Outputs: a - decimal number between 0 and 1 indicating where
%              discontinuity function is estimated to be zero

global T ISTATE

b=ph_old/(ph_old-ph_new); % zero crossing at ti+bT based on linear interpolation of (ti,ph_old) and (ti+T,ph_new)
t0=ti+b*T;
t1=ti;
t2=ti+T;
y1=ph_old;
y2=ph_new;
[x11 x22]=RK4(b*T,x11,x22,ISTATE); % compute state at ti+bT
[ph11 ph22]=DFUNCT(x11,x22);  % compute ph1 and ph2 at ti+bT
if k==1
  y0=ph11;
else 
  y0=ph22;
end % if
t=[t1 t0 t2];
y=[y1 y0 y2];
p=polyfit(t,y,2); % fit quadratic thru (ti,ph_old), (ti+T,ph_new) and (ti+bT,y0)
r=roots(p); % roots of quadratic
if r(1)>=ti & r(1)<=ti+T % find root in interval (ti,ti+T)
  t_root=r(1);
else
  t_root =r(2);
end % if
a=(t_root-ti)/T; %  normalizes "a" to between 0 and 1



