% m-file Ch7_Fig7_36.m
% plots Figure 7.36
% calls Simulink model globe.mdl
% Finds and plots two lines corresponding to objective fcn contour F0
% between 0 and B=50 or one line for F0 greater than B=50 and less then Max F0
% corresponding to c=c_min=0 and F1=F1_max=10
% Program takes several minutes to execute
% If unsuccessful, try lowering delF1 and/or increasing eps

clear all, clc, close all

F1_min=0; F1_max=10;
c_min=0; c_max=2; delc=(c_max-c_min)/2;
% delc=c_max-c_min;
R=5;
T_max=300;
T_design=150; % center of fill time design interval (min)
del=10; % width of design interval centered at T_design (min) 
TL=T_design-del/2; % lower end of design interval (min)
TH=T_design+del/2; % upper end of design interval (min)
A=100; B=50;
delF1=0.005; 
eps=0.5; % fill time tolerance
iter_max=round(F1_max/delF1);  

F0=20;         
Tfill_low=TL*(1-sqrt(F0/A)); 
Tfill_high=TH+(T_max-TH)*sqrt(F0/B);     
i=0;

for c=c_min:delc:c_max    
  i=i+1; 
  ci(i)=c;
  F1=c*sqrt(R); % minimum req'd flow in to fill globe  
  F1_low(i)=0;
  F1_high(i)=0;
  iter=0;      
    
        while F1_high(i)==0 & iter < iter_max  
      
           F1=F1+delF1;     
           sim('globe')     
           t=H(:,1);
           tfill=t(end);  
            
           if abs(tfill-Tfill_high)<eps  
              F1_low(i)=F1;              
           end
   
           if abs(tfill-Tfill_low)<eps  
             F1_high(i)=F1;              
           end
 
         iter=iter+1;

        end % while F1_high(i)==0 & iter < iter_max  
        
        plot(ci,F1_low,'.--b','MarkerSize',13,'LineWidth',1.3)
        grid on
        axis([c_min c_max F1_min F1_max])
        hold on
        plot(ci,F1_high,'.--b','MarkerSize',13,'LineWidth',1.3)           
                 
    end % for c=c_min:delc:c_max 
    
clear all

F1_min=0; F1_max=10;
c_min=0; c_max=2; delc=(c_max-c_min)/2;
% delc=c_max-c_min;
R=5;
T_max=300;
T_design=150; % center of fill time design interval (min)
del=10; % width of design interval centered at T_design (min) 
TL=T_design-del/2; % lower end of design interval (min)
TH=T_design+del/2; % upper end of design interval (min)
A=100; B=50;
delF1=0.0025;  
eps=0.5; % fill time tolerance
iter_max=round(F1_max/delF1); 
F0=60; 
Tfill_low=TL*(1-sqrt(F0/A));     
i=0;

for c=c_min:delc:c_max    
  i=i+1; 
  ci(i)=c;
  F1=c*sqrt(R); % minimum req'd flow in to fill globe 
  F1_high(i)=0;
  iter=0;
  
  while F1_high(i)==0 & iter < iter_max  
      
    F1=F1+delF1;     
    sim('globe')     
    t=H(:,1);
    tfill=t(end);  
                                          
     if abs(tfill-Tfill_low)<eps  
        F1_high(i)=F1;              
     end
     
     iter=iter+1;  
     
  end % while F1_high(i)==0 & iter < iter_max              

plot(ci,F1_high,'.--b','MarkerSize',13,'LineWidth',1.3)           
                 
end % for c=c_min:delc:c_max  

clear all

F1_min=0; F1_max=10;
c_min=0; c_max=2; delc=(c_max-c_min)/2;
% delc=c_max-c_min;
R=5;
T_max=300;
T_design=150; % center of fill time design interval (min)
del=10; % width of design interval centered at T_design (min) 
TL=T_design-del/2; % lower end of design interval (min)
TH=T_design+del/2; % upper end of design interval (min)
A=100; B=50;
delF1=0.0025;  
eps=0.5; % fill time tolerance
iter_max=round(F1_max/delF1);
F0=0;         
Tfill_low=TL*(1-sqrt(F0/A)); 
Tfill_high=TH+(T_max-TH)*sqrt(F0/B);     
i=0;

for c=c_min:delc:c_max    
  i=i+1; 
  ci(i)=c;
  F1=c*sqrt(R); % minimum req'd flow in to fill globe  
  F1_low(i)=0;
  F1_high(i)=0;
  iter=0;
          
        while F1_high(i)==0 & iter < iter_max  
      
           F1=F1+delF1;     
           sim('globe')     
           t=H(:,1);
           tfill=t(end);  
            
           if abs(tfill-Tfill_high)<eps  
              F1_low(i)=F1;              
           end
   
           if abs(tfill-Tfill_low)<eps  
             F1_high(i)=F1;              
           end
 
         iter=iter+1;

        end % while F1_high(i)==0 & iter < iter_max  
        
        plot(ci,F1_low,'.--b','MarkerSize',13,'LineWidth',1.3)
        axis([c_min c_max F1_min F1_max])
        hold on
        plot(ci,F1_high,'.--b','MarkerSize',13,'LineWidth',1.3)           
                 
    end % for c=c_min:delc:c_max 

F1_R=sqrt(R)*ci;
cc(1)=0; cc(2)=c_max; cc(3)=c_max; cc(4)=0;
FF(1)=0; FF(2)=F1_R(end); FF(3)=0; FF(4)=0;

plot(cc,FF,'k','LineWidth',1.5)

 for x=0:0.2:2
     y=2.236*x;
     plot([x x],[0 y],'k','LineWidth',1.1)     
 end
 
 for y=1:3
     x=y/2.236;
     plot([x 2],[y y],'k','LineWidth',1.1)
 end

text(0.75,1.4,'Infeasible Region: H(\infty) < R = 5 ft','FontSize',13) 
xlabel('c  (ft^3/min per ft^{1/2})','FontSize',13)
ylabel('F_1  (ft^3/min)','FontSize',13)  
text(0.6,10.45,'F_0 = 0, 20, 60 Contours','FontSize',11)
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.2:2])
set(gca,'YTick',[0:10])
text(0.2,8.7,'60','FontSize',12)
text(0.2,4.25,'20','FontSize',12)
text(0.2,2.7,'0','FontSize',12)
text(0.2,1.0,'20','FontSize',12)


 