% m-file Ch7_Fig7_32.m
% draws objective function for globe tank fill example 
% along with fill times for F0=20 and F0=60
% plots Figure 7.32

clc, close all, clear all

T_design=150; % center of fill time design interval (min)
del=10; % width of design interval centered at T_design (min) 
TL=T_design-del/2; % lower end of design interval (min)
TH=T_design+del/2; % upper end of design interval (min)
A=100; B=50;
T_max=300; % maximum fill time for running simulation

t1i=linspace(0,TL,400);
F1i=A*((t1i/TL)-1).^2;
t3i=linspace(TH,T_max,400);
F3i=B*((t3i-TH)/(T_max-TH)).^2;
t2i=[TL TH];
F2i=[0 0];
t4i=[T_max T_max+100];
F4i=[B B];
ti=[t1i t2i t3i t4i];
Fi=[F1i F2i F3i F4i];
plot(ti,Fi,'b','LineWidth',1.3)
grid on
axis([-5 T_max+50 -5 A+5])
hold on

F0=20;
Tfill_low=TL*(1-sqrt(F0/A)); 
Tfill_high=TH+(T_max-TH)*sqrt(F0/B);
plot([0 Tfill_high],[20 20],'--k')
plot([Tfill_low Tfill_low],[-5 20],'--k')
plot([Tfill_high Tfill_high],[-5 20],'--k')

F0=60;
Tfill=TL*(1-sqrt(F0/A)); 
plot([0 Tfill],[60 60],'--k')
plot([Tfill Tfill],[-5 60],'--k')
set(gca,'XTick',[0 32.68 80.15 150 200 246.71 300 350])
set(gca,'FontSize',11)

xlabel('t_{fill}','FontSize',13)
ylabel('F(t_{fill})','FontSize',13)
text(100,110,'Objective Function  F(t_{fill})','FontSize',12)
plot(0,A,'.r','MarkerSize',13)
plot(300,B,'.r','MarkerSize',13)
text(10,100,'A = 100','FontSize',12)
text(290,55,'B = 50','FontSize',12)
plot([T_design T_design],[-5 80],'--k')
text(118,82.0,'T_{des} = 150 min','FontSize',12)
plot([TL TL],[-5 60],'--k')
text(65,62,'T_L = 145 min','FontSize',12)
plot([TH TH],[-5 60],'--k')
text(160,62,'T_H = 155 min','FontSize',12)
text(251.5,2.9,'T_{max} = 300 min','FontSize',12)
text(160,45,'\Delta = T_H - T_L = 10 min','FontSize',12)
 

