% m-file Ch7_Fish_Sharks.m
% calls Simulink model Fish_Sharks.mdl
% plots Figure 7.3 and Figure 7.4

clear all; close all; clc

a=50; b=1; c=5; e=2; lam=10;
Fe=(a*lam)/(b*lam+c*e); 
Se=(a*e)/(b*lam+c*e); 

F0=1.25*Fe; S0=0.25*Se;
sim('Fish_Sharks') 
t=F(:,1);
F=F(:,2);
S=S(:,2);

% figure(1) % plot Figure 7.3
% 
% subplot(2,1,1)
% plot(t,F,'b','LineWidth',1.3)
% grid on
% axis([0 2 20 50])
% set(gca,'FontSize',11)
% set(gca,'XTick',[0:0.25:2])
% set(gca,'YTick',[20:5:50])
% xlabel('t','FontSize',13)
% ylabel('F(t)','FontSize',13)
% title('F(t) vs. t')
% 
% subplot(2,1,2)
% plot(t,S,'b','LineWidth',1.3)
% grid on
% axis([0 2 0 6])
% set(gca,'FontSize',11)
% set(gca,'XTick',[0:0.25:2])
% set(gca,'YTick',[0:6])
% xlabel('t','FontSize',13)
% ylabel('S(t)','FontSize',13)
% title('S(t) vs. t')

figure(2) % plot Figure 7.4
plot(F,S,'b','LineWidth',1.3)
grid on
hold on
axis([20 45 0 6])
set(gca,'XTick',[20:5:45])
set(gca,'YTick',[0:6])
set(gca,'FontSize',11)
xlabel('Fish','FontSize',13)
ylabel('Sharks','FontSize',13)
title('S(t) vs. F(t)')
text(21,5.1,'(F_e, S_e)','FontSize',13)
text(23.5,1.1,'(1.25F_e, 0.25S_e)','FontSize',13)
plot(Fe,Se,'r.','MarkerSize',13)
text(33,5.15,'equilibrium pt','FontSize',13)
plot(32,5.1,'r.','MarkerSize',13)

% 
% fact=0.75;
% x0=[fact*Fe;fact*Se] 
% F0=fact*Fe;
% S0=fact*Se;
% [x,u,y,dx]=trim('Fish_Sharks',x0)


figure(3) % plot Figure 7.5
% find state trajectories near equil pt %%%%%
hold on
for i=1:100 
    F0=5+45*rand;
    S0=1+9*rand;
    plot([F0],[S0],'.r','MarkerSize',9)
    [t,x,y]=sim('Fish_Sharks');
    F=x(:,1);
    S=x(:,2);
    plot(F,S,'b','LineWidth',1.3)
    axis([0 55 0 11])
end
set(gca,'FontSize',11)
set(gca,'XTick',[0:5:55])
set(gca,'YTick',[0:11])
% 
plot([Fe Fe],[0 12],'--k','LineWidth',1.2)
plot([0 55],[Se Se],'--k','LineWidth',1.2)
xlabel('F','FontSize',13)
ylabel('S','FontSize',13)
text(5,11.4,'State Trajectories Near Equilibrium Point F_e = 25, S_e = 5','FontSize',11)
    

