% m-file Ch7_InvertPend.m
% calls Simulink models InvertPend_1.mdl and InvertPend_2.mdl
% plots Figure 7.63 and Figure 7.64

clear all; close all; clc

M=3; m=0.1;l=0.75;g=9.8;
x10=0; x20=0; x30=pi; x40=0; u0=0; % Operating pt: x1=x, x2=xdot, x3=theta, x4=thetadot
y10=x10; y20=x30; % Outputs at operating pt

a11=0; a13=0; a14=0; a12=1;
a21=0; a22=0;
z1=M+m*(sin(x30)^2);
z2=m*l*(x40^2)*cos(x30)- m*g*(1-2*(sin(x30)^2));
z3=m*l*(x40^2)*sin(x30)-0.5*m*g*sin(2*x30)+u0;
N1=z1*z2-z3*m*sin(2*x30);
D1=z1^2;
a23=N1/D1;
a24=(2*m*l*x40*sin(x30))/z1;
a31=0; a32=0; a33=0; a34=1;
a41=0; a42=0;
a44=-m*l*x40*sin(2*x30)/(l*z1);
z4=-m*l*(x40^2)*(1-2*sin(x30)^2)+(m+M)*g*cos(x30)+u0*sin(x30);
z5=0.5*l*(x40^2)*sin(2*x30)-(m+M)*g*sin(x30)+u0*cos(x30);
N2=l*z1*z4+z5*l*m*sin(2*x30);
D2=(l*z1)^2;
a43=N2/D2;
b11=0; b31=0;
b21=1/z1;
b41=-cos(x30)/(l*z1);
c11=1; c12=0; c13=0; c14=0;
c21=0; c22=0; c24=0; c23=1;
d11=0; d21=0;

A1=[a11 a12 a13 a14; a21 a22 a23 a24; a31 a32 a33 a34; a41 a42 a43 a44]  
B1=[b11; b21; b31; b41];
C1=[c11 c12 c13 c14; c21 c22 c23 c24]; 
D1=[d11; d21]; 

[sizes,X0,states]=InvertPend_1([ ],[ ],[ ],0); 

x_operpt=[x10;x30;x20;x40]; % Simulink states are x, theta, xdot, thetadot
x_operpt=[0 pi 0 0]'; % Simulink states are x, theta, xdot, thetadot
[A2,B2,C2,D2]=linmod('InvertPend_1',x_operpt,u0)
%eig(A1), eig(A2)

%%%%% compute a43 using numerical approximation of partial derivative %%%%%
del=0.01;
sin1=sin(pi+del);
sin1sq=sin1^2;
sin2=sin(pi-del);
sin2sq=sin2^2;
k1=(m+M)*g/(l*2*del);
k2=sin1/(M+m*sin1sq);
k3=sin2/(M+m*sin2sq);
partial_f43=k1*(k2-k3);


%%%%% begin with input u=2.5
uu=2.5;
sim('InvertPend_2')
t=theta_lin_nonlin(:,1);
theta_nonlin=theta_lin_nonlin(:,2);
theta_lin=theta_lin_nonlin(:,3);

figure(1)
subplot(3,1,1)
plot(t,theta_nonlin,'b','LineWidth',1.3)
grid on
axis([0 5 2.95 3.35])
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:5])
set(gca,'YTick',[3:0.1:3.3])
ylabel('\theta_{NL}(t),  rad','FontSize',13)
title('Nonlinear and Linearized Pendulum Angle in rad,  u(t) = 2 N, 1 \leq t \leq 2','FontSize',11)

subplot(3,1,2)
plot(t,theta_lin,'b','LineWidth',1.3)
grid on
axis([0 5 2.95 3.35])
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:5])
set(gca,'YTick',[3:0.1:3.3])
ylabel('\theta_L(t),  rad','FontSize',13)

subplot(3,1,3)
plot(t,theta_nonlin,'b','LineWidth',1.3)
grid on
hold on
plot(t,theta_lin,'r','LineWidth',1.3)
grid on
axis([0 5 2.95 3.35])
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:5])
set(gca,'YTick',[3:0.1:3.3])
xlabel('t  (s)','FontSize',13)
text(3.15,3.05,'nonlinear','FontSize',13)
plot([3.97 4.21],[3.04 3.04],'b','LineWidth',1.1)
text(4.32,3.22,'linear','FontSize',13)
plot([3.9623 4.23],[3.21 3.21],'r','LineWidth',1.1)


%%%% change input to u=25
uu=25;
sim('InvertPend_2')
t=theta_lin_nonlin(:,1);
theta_nonlin=theta_lin_nonlin(:,2);
theta_lin=theta_lin_nonlin(:,3);

figure(2)
subplot(3,1,1)
plot(t,theta_nonlin,'b','LineWidth',1.3)
grid on
axis([0 5 1.25 5.0])
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:5])
set(gca,'YTick',[2:5])
ylabel('\theta_{NL}(t),  rad','FontSize',13)
title('Nonlinear and Linearized Pendulum Angle in rad,  u(t) = 25 N, 1 \leq t \leq 2','FontSize',11)

subplot(3,1,2)
plot(t,theta_lin,'r','LineWidth',1.3)
grid on
axis([0 5 1.25 5.0])
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:5])
set(gca,'YTick',[2:5])
ylabel('\theta_L(t),  rad','FontSize',13)

subplot(3,1,3)
plot(t,theta_nonlin,'b','LineWidth',1.3)
hold on
plot(t,theta_lin,'r','LineWidth',1.3)
grid on
axis([0 5 1.25 5.0])
set(gca,'FontSize',11)
set(gca,'XTick',[0:0.5:5])
set(gca,'YTick',[2:5])
xlabel('t  (s)','FontSize',13)
text(1.26,3.2,'nonlinear','FontSize',13)
plot([2.1 2.307],[3.13 3.13],'b','LineWidth',1.1)
text(2.55,3.915,'linear','FontSize',13)
plot([3.07 3.34],[3.8 3.8],'r','LineWidth',1.1)