% m-file Ch7_Toolbox_opt_search.m
% plots Figure 7.18 and Figure 7.19
% calls Simulink model target_projectile.mdl

clc, close all, clear all

L=5000; % ft
m=2000/32.2; % slugs
mu=0.1; % lb per ft/sec
vT_mph=15; % mph
vT_fps=vT_mph*(5280/3600); % ft/sec
vP_initial=45; % projectile initial speed (mph)
vP_initial=vP_initial*(5280/3600); % projectile initial speed (ft/sec)
theta=45 ;% projectile firing angle (deg)
theta=theta*(pi/180); % projectile firing angle (rad)
T=0.05; % step size (sec)

%%%%%%%%%% optimization for vT=15 mph %%%%%%%%%%
angle_init=15; % starting angle (deg)
angle_init=angle_init*pi/180; % starting angle (rad)
[opt_angle_rad,FVAL]=fminunc(@obj_fcn_D,angle_init,[ ],L,m,mu,vT_fps,vP_initial)   % optimum angle (rad) and min D
opt_angle_deg=opt_angle_rad*180/pi % optimum angle (deg)

%%%%% simulate and plot optimum projectile firing
theta=opt_angle_rad; % optimum fifring angle (rad)
%[sizes,x0,states]=target_projectile([],[],[],0)
vT=vT_fps;
sim('target_projectile')
xT=target_xy(:,1);
yT=target_xy(:,2);
figure(1) % plot Figure 7.18 
plot(xT,yT,'b','LineWidth',1.3)
grid on
xlabel('x  (ft)','FontSize',12)
ylabel('y  (ft)','FontSize',12)
hold on
xP=projectile_xy(:,1);
yP=projectile_xy(:,2);
delT=2.5; % time separation between consecutive projectile plotted locations (sec)
del=round(delT/T); 
plot(xP(1:del:end),yP(1:del:end),'.r','MarkerSize',9)

text(225,4000,'Target trajectory','FontSize',13)
plot([150 200],[4000 4000],'b','LineWidth',1.3)
text(225,3500,'Projectile trajectory','FontSize',13)
plot(175,3500,'.r','MarkerSize',9)
min_xT=min(xT); max_xT=max(xT);
min_yT=min(yT); max_yT=max(yT);
min_xP=min(xP); max_xP=max(xP);
min_yP=min(yP); max_yP=max(yP);
min_x=min(min_xT,min_xP);
max_x=max(max_xT,max_xP);
min_y=min(min_yT,min_yP);
max_y=max(max_yT,max_yP);
axis([min_x max_x+100 min_y-100 max_y+200])
text(1100,2000,'v_T  = 15 mph','FontSize',13)
text(1100,1500,'\theta_{opt} = 69.63 deg','FontSize',13)
title('Simulated Firing at Optimum Firing Angle','FontSize',11)


%%%%%%%%%% optimization for vT=75 mph %%%%%%%%%%
% vT_mph=75; % mph
% % vT_mph=75; % mph
% vT_fps=vT_mph*(5280/3600); % ft/sec
% vP_initial=45; % projectile initial speed (mph)
% vP_initial=vP_initial*(5280/3600); % projectile initial speed (ft/sec)
% theta=45 ;% projectile firing angle (deg)
% theta=theta*(pi/180); % projectile firing angle (rad)
% 
% angle_init=45; % starting angle (deg)
% angle_init=angle_init*pi/180; % starting angle (rad)
% [opt_angle_rad,FVAL]=fminunc(@obj_fcn_D,angle_init,[ ],L,m,mu,vT_fps,vP_initial)   % optimum angle (rad) and min D
% opt_angle_deg=opt_angle_rad*180/pi % optimum angle (deg)
% 
% %%%%% simulate and plot optimum projectile firing
% theta=opt_angle_rad; % optimum fifring angle (rad)
% %[sizes,x0,states]=target_projectile([],[],[],0)
% vT=vT_fps;
% sim('target_projectile')
% xT=target_xy(:,1);
% yT=target_xy(:,2);
% figure 
% plot(xT,yT)
% xlabel('\itx  \rm(ft)','FontSize',11)
% ylabel('\ity  \rm(ft)','FontSize',11)
% hold on
% xP=projectile_xy(:,1);
% yP=projectile_xy(:,2);
% delT=2.5; % time separation between consecutive projectile plotted locations (sec)
% del=round(delT/T); 
% plot(xP(1:del:end),yP(1:del:end),'.r')
% set(gca,'YTick',[-1000:500:5000])

text(725,3500,'Target trajectory','FontSize',11)
plot([550 650],[3500 3500],'b')
text(725,3000,'Projectile trajectory','FontSize',11)
plot(600,3000,'.r')

min_xT=min(xT); max_xT=max(xT);
min_yT=min(yT); max_yT=max(yT);
min_xP=min(xP); max_xP=max(xP);
min_yP=min(yP); max_yP=max(yP);
min_x=min(min_xT,min_xP);
max_x=max(max_xT,max_xP);
min_y=min(min_yT,min_yP);
max_y=max(max_yT,max_yP);
axis([min_x max_x+200 min_y-100 max_y+200])
text(2500,1500,'\itv_{T}  \rm= 75 mph','FontSize',11)
text(2500,900,'\theta_{opt} \rm= -11.85 deg','FontSize',11)
title('Simulated Firing at Optimum Firing Angle','FontSize',11)
    