% m-file Ch7_globe_contour.m
% Finds and plots two lines corresponding to objective fcn contour F0
% between 0 and B=50 or one line for F0 greater than B=50 and less then Max F0
% corresponding to c=c_min=0 and F1=F1_max=10
% Program takes several minutes to execute
% If unsuccessful, try lowering delF1 and/or increasing eps
% plots Figure 7.36
% see also "Ch7_Fig7_36.m"

clear all, clc

F1_min=0; F1_max=10;
c_min=0; c_max=2;
R=5;
T_max=300;
T_design=150; % center of fill time design interval (min)
del=10; % width of design interval centered at T_design (min) 
TL=T_design-del/2; % lower end of design interval (min)
TH=T_design+del/2; % upper end of design interval (min)
A=100; B=50;

%%%%% Find Max F0 when c=c_min and F1=F1_max
c=c_min; F1=F1_max;
sim('globe')
t=H(:,1);
t_fill=t(end);
F0_max=A*((t_fill/TL)-1)^2;

s=sprintf('Max F0 = %.2f occurs when c=0, F1=10 cfm with fill time of %.2f min \n',  F0_max, t_fill);
disp(s)
F0=input('Enter value of F0 between 0 and Max F0    '); 


if F0==0
    Tfill_low=TL; 
    Tfill_high=TH; 
elseif F0 > 0 & F0 <= 50  % find Tfill_low and Tfill_high from Eq 3.43 
                        % i.e. f(Tfill_low)=F0 and f(Tfill_high)=F0
    Tfill_low=TL*(1-sqrt(F0/A)); 
    Tfill_high=TH+(T_max-TH)*sqrt(F0/B);
elseif F0 > 50 & F0 <= 100 % find Tfill_low from Eq 3.43 
    Tfill_low=TL*(1-sqrt(F0/A));         
end

delc=c_max-c_min;
i=0;
for c=c_min:delc:c_max
    
  i=i+1; 
  ci(i)=c;
  F1=c*sqrt(R); % minimum req'd flow in to fill globe
  delF1=0.0025;  
  eps=0.5; % fill time tolerance
  F1_low(i)=0;
  F1_high(i)=0;
  iter=0;
  iter_max=round(F1_max/delF1);
  
     if F0 >= 0 & F0 <= 50
    
        while F1_high(i)==0 & iter < iter_max  
      
           F1=F1+delF1;     
           sim('globe')     
           t=H(:,1);
           tfill=t(end);      
           Ht=H(:,2);
           Ht_final=Ht(end);     

           if abs(tfill-Tfill_high)<eps  
             F1_low(i)=F1; 
             % c,Tfill_high, tfill, F1, Ht_final
           end
   
           if abs(tfill-Tfill_low)<eps  
             F1_high(i)=F1; 
             % c,Tfill_low, tfill, F1, Ht_final
           end
 
         iter=iter+1;

        end % while F1_high(i)==0 & iter < iter_max  
        
        plot(ci,F1_low,'.:b')
        axis([c_min c_max F1_min F1_max])
        hold on
        plot(ci,F1_high,'.:r')
           if F0==0
             text(0.1,1.30,'(\itF_{\rm1}\rm)_{\rmlow}','FontSize',11)
             text(0.4,1.85,'\itt_{\rmfill} \rm= 155 min','FontSize',11)
             text(0.45,4.5,'(\itF_{\rm1}\rm)_{\rmhigh}','FontSize',11)
             text(0.45,3.5,'\itt_{\rmfill} \rm= 145 min','FontSize',11)
             title('Lower and Upper Limit of \itF_{\rm1} \rmCorresponding to \itF\rm(\itF_{\rm1},\itc\rm) = F_{0} = 0','FontSize',11)
           end % if F0==0
        xlabel('\itc  \rm(cu ft per min per ft^{1/2})','FontSize',11)
        ylabel('\itF_{\rm1}  \rm(cu ft per min)','FontSize',11)
           if F0 ~= 0
             text(0,10.5,'Lower and Upper Limit of \itF_{\rm1} \rmCorresponding to \itF\rm(\itF_{\rm1},\itc\rm) = F_{0} = ','FontSize',11)
             s=num2str(F0);
             text(1.85,10.62,s)
           end % if F0 ~= 0
     end % if F0 >=0 & F0 <= 50
     

     if F0 > 50 & F0 <= 100
    
        while F1_high(i)==0 & iter < iter_max 
      
           F1=F1+delF1;     
           sim('globe')     
           t=H(:,1);
           tfill=t(end);      
           Ht=H(:,2);
           Ht_final=Ht(end);                
   
           if abs(tfill-Tfill_low)<eps  
             F1_high(i)=F1; 
             % c,Tfill_low, tfill, F1, Ht_final             
           end
 
         iter=iter+1;
 
        end % while F1_high(i)==0 & iter <2000  
        
        plot(ci,F1_high,'.:r')
        hold on
        axis([c_min c_max F1_min F1_max])        
        xlabel('\itc  \rm(cu ft per min per ft^{1/2})','FontSize',11)
        ylabel('\itF_{\rm1}  \rm(cu ft per min)','FontSize',11)
        text(0.4,10.5,'\itF_{\rm1} \rmCorresponding to \itF\rm(\itF_{\rm1},\itc\rm) = F_{0} = ','FontSize',11)
        s=num2str(F0);
        text(1.48,10.62,s)
     end % if F0 > 50 & F) <= 100
     
  % iter

end % for c

F1_R=sqrt(R)*ci;
cc(1)=0; cc(2)=c_max; cc(3)=c_max; cc(4)=0;
FF(1)=0; FF(2)=F1_R(end); FF(3)=0; FF(4)=0;
fill(cc,FF,'g')
text(0.9,1.25,'Infeasible Region: \itH\rm(\infty) < \itR \rm= 5 ft','FontSize',11)

     
 
 