% Chap7_grad_search_globe_fill.m
% Draws objective function surface over F1-c plane
% Uses gradient search to find optimum point in F1-c plane

clc, clear all, close all

global T_design T_low T_high T_max A B del F1 c
R=5; % globe radius (ft)
T_design=150; % center of fill time design interval (min)
del=10; % width of design interval centered at T_design (min) 
T_low=T_design-del/2; % lower end of design interval (min)
T_high=T_design+del/2; % upper end of design interval (min)
A=100; B=50;
T_max=300;
r=input('Enter 1 to draw obj fcn surface or 2 to find optimum - ');

if r==1 
%%%%% get points for drwaing obj fcn surface %%%%%
  numF1=75; numc=75;  
  F1min=0; F1max=10;
  cmin=0; cmax=2;
  
  for i=1:numF1
    F1=F1min+((F1max-F1min)/(numF1-1))*(i-1);  
    F11(i)=F1;     
      for j=1:numc;
        c=cmin+((cmax-cmin)/(numc-1))*(j-1);     
        cc(j)=c;          
        z(i,j)=obj_fcn_globe(F1,c);      
      end % j
   end % i

  mesh(cc,F11,z)
  xlabel('\itc')
  ylabel('\itF_{\rm1}')
  zlabel('\itF\rm(\itF_{\rm1}, \itc\rm)')
  figure
  v=[0.01 5:15:50];
  contour(cc,F11,z,v)
  xlabel('\itc  \rm(cu ft per min per ft^{1/2})')
  ylabel('\itF_{\rm1}  \rm(cu ft per min)')
  title('Contours of \itF\rm(\itF_{\rm1},\itc\rm) = 0.1, 5, 20, 35, 50')
  text(0.3,7.5,'\itF\rm(\itF_{\rm1},\itc\rm) = 50')
  text(0.7,6.0,'35')
  text(0.9,5.2,'20')
  text(1.1,4.6,'5')
  text(0.8,1,'\itF\rm(\itF_{\rm1},\itc\rm) = 0.1, 5, 20, 35, 50')
else
%%%%% begin gradient search %%%%% 
  F1_max=10; c_max=2;
  F1_start=F1_max*rand; % starting point in
  c_start=c_max*rand; % search for optimum 
  F1=F1_start;
  c=c_start;
  if F1 < sqrt(R)*c
    F1=min(1.5*sqrt(R)*c,F1_max) 
  end     
  step=0.5; % initial step size   
  F_start=obj_fcn_globe(F1,c);  % old objective function   
  F_old=F_start;
  [gradF_F1_start gradF_c_start]=gradF_globe(F1,c);
  gradF_F1=gradF_F1_start;
  gradF_c=gradF_c_start;
  gradF_start=[gradF_F1_start; gradF_c_start];
  gradF=[gradF_F1; gradF_c];  % gradient vector    
  mag_gradF_start=sqrt(DOT(gradF_start,gradF_start));    
  mag_gradF=mag_gradF_start;
  F1=min(F1-(step/mag_gradF)*gradF_F1, F1_max);   % take a step in negative 
  c=min(c-(step/mag_gradF)*gradF_c, c_max);      % gradient direction
  F_new=obj_fcn_globe(F1,c); % compute new objective function
  tol_grad=0.1; tol_F=0.001; % stop criteria
  numsteps=0;
  fract=0.75;
  max_iter=50;
  minstep=0.1;
  iter=0; % iteration counter
  
    while mag_gradF >tol_grad & F_new>tol_F & iter<max_iter
      iter=iter+1;
      if F_new<F_old % take a full step 
         %disp('full step')
         %step
         F1=min(F1-(step/mag_gradF)*gradF_F1,F1_max);   
         c=min(c-(step/mag_gradF)*gradF_c, c_max);                  
      else % take a fractional step 
         %disp('fractional step')
         step=max(fract*step, minstep);          
         F1=min(F1-(step/mag_gradF)*gradF_F1, F1_max);   
         c=min(c-(step/mag_gradF)*gradF_c, c_max);         
      end 
    
      if F1 < sqrt(R)*c
        F1=min(1.5*sqrt(R)*c, F1_max);
      end       
    F_old=F_new;  
    F_new=obj_fcn_globe(F1,c) % compute new objective function
    [gradF_F1 gradF_c]=gradF_globe(F1,c);
    gradF=[gradF_F1; gradF_c]; % gradient vector    
    mag_gradF=sqrt(DOT(gradF,gradF)); 
    
    end % while
   
   if iter==max_iter
     disp('***** Search Unsuccessful *****')
     iter,F1,c,gradF,mag_gradF,F_new
   else
     disp('***** Search Successful *****')
     disp('*****************************')
     disp('Start of Search Conditions')
     F1_start,c_start,F_start,gradF_start,mag_gradF_start
     disp('*****************************')
     disp('End of Search Conditions')
     iter,F1,c,F_new,gradF,mag_gradF
   end
     
   
end % if r==1







  

    
    
    
    






