% m-file Ch7_hospital.m
% cals Simulink model hospital.mdl
% plots Figure 7.46

clc, clear all, close all
warning off

emergency_arrivals_mean=5;
emergency_arrivals_variance=2;
scheduled_arrivals_mean=21;
scheduled_arrivals_variance=4;
deaths_mean=2;
deaths_variance=0.25;
discharges_mean=23;
discharges_variance=9;

num_days=365; % number of days in an individual time series
num_days=50;
L=200; % number of beds
num_trials=10; % number of time series (replications) for Monte Carlo simulation
num_scheduled_arrivals_means=11;

capacity=(num_days+1)*L;
initial_occupancy=L;
c1=1; % objective function weight for grand ave of excess patients per day
c2=1; % objective function weight for grand ave of excess capacity per day


for j=1:num_scheduled_arrivals_means
  scheduled_arrivals_mean=14+j; 
  scheduled_arrivals_means(j)=scheduled_arrivals_mean;

for i=1:num_trials
  emergency_arrivals_seed=100*rand;
  scheduled_arrivals_seed=100*rand;
  deaths_seed=100*rand;
  discharges_seed=100*rand;    
  sim('hospital')
  patient_occupancy=x(:,2); % initial patient occupancy plus end of day i occupancies, i=1,2,...,nfinal     
  total_patient_occupancy(i)=sum(patient_occupancy);   
  percent_patient_occupancy(i)=100*total_patient_occupancy(i)/capacity;
  
  delta_gt_zero=delta_gt_0(:,2); % excess patients
  total_excess_patients(i)=sum(delta_gt_zero); % total number of patients turned away from day 1 to day nfinal  
  ave_excess_patients_per_day(i)=mean(delta_gt_zero);
   
  delta_lt_zero=delta_lt_0(:,2); % excess capacity
  total_excess_capacity(i)=sum(delta_lt_zero);
  ave_excess_capacity_per_day(i)=abs(mean(delta_lt_zero));  
end % i

ave_percent_patient_occupancy(j)=mean(percent_patient_occupancy);
grand_ave_excess_patients_per_day(j)=mean(ave_excess_patients_per_day);
grand_ave_excess_capacity_per_day(j)=mean(ave_excess_capacity_per_day);
F(j)=c1*grand_ave_excess_patients_per_day(j) + c2*grand_ave_excess_capacity_per_day(j);

end % j

% scheduled_arrivals_means
% ave_percent_patient_occupancy
% grand_ave_excess_patients_per_day
% grand_ave_excess_capacity_per_day

figure(1) % plot Figure 7.46
subplot(2,2,1)
plot(scheduled_arrivals_means,F,'b.--','MarkerSize',11,'LineWidth',1.2)
grid on
axis([15 25 -10 210])
set(gca,'XTick',[15:25])
xlabel('\mu_S','FontSize',13)
ylabel('Objective Function','FontSize',11)

subplot(2,2,2)
plot(scheduled_arrivals_means,ave_percent_patient_occupancy,'b.--','MarkerSize',11,'LineWidth',1.2)
grid on
axis([15 25 0 105])
set(gca,'XTick',[15:25])
xlabel('\mu_S','FontSize',13)
ylabel('Ave Percent Occupancy','FontSize',11)

subplot(2,2,3)
plot(scheduled_arrivals_means,grand_ave_excess_patients_per_day,'b.--','MarkerSize',11,'LineWidth',1.2)
grid on
axis([15 25 -0.5 5.5])
set(gca,'XTick',[15:25])
xlabel('\mu_S','FontSize',13)
ylabel('Ave Excess Patients Per day','FontSize',11)

subplot(2,2,4)
plot(scheduled_arrivals_means,grand_ave_excess_capacity_per_day,'b.--','MarkerSize',11,'LineWidth',1.2)
grid on
axis([15 25 -10 210])
set(gca,'XTick',[15:25])
xlabel('\mu_S','FontSize',13)
ylabel('Ave Excess Capacity Per day','FontSize',11)


figure(2) % plot Figure 7.40
days=u_gt_0(:,1);
patients=u_gt_0(:,2);
plot(days,u_gt_0,'b','LineWidth',1.3)
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:5:50])

