% m-file Ch7_min_sep_search.m
% plots Figure Figure 7.21 and Figure 7.22

clc, close all, clear all

L=5000; % ft
m=2000/32.2; % slugs
mu=0.15; % lb per ft/sec
tau=m/mu; % time constant (sec)
vT=15; % mph
vT=vT*(5280/3600); % ft/sec
vP_initial=35; % projectile initial speed (mph)
vP_initial=vP_initial*(5280/3600); % projectile initial speed (ft/sec)

t=linspace(0,2*tau,750);
yT=L+vT*t;
yP=tau*vP_initial*(1-exp(-t/tau));
D=yT-yP;

figure(1) % plot Figure 7.21
plot(t,D,'b','LineWidth',1.3)
axis([0 800 0 5000])
grid on
set(gca,'FontSize',11)
set(gca,'XTick',[0:100:800])
set(gca,'YTick',[0:500:5000])
xlabel('t  (s)','FontSize',12)
ylabel('D  (ft)','FontSize',12)
title('Separation Between Target and Projectile','FontSize',11)
text(220,4550,'v_T  = 15 mph, v_P(0) = 35 mph','FontSize',13)
text(65,4120,'L = 5000 ft, m = 2000/32.2 slugs, \mu = 0.15 lb-s/ft','FontSize',13)


%%%%% start search for min from t0=0
clear t D
step=10;
t_old=0; 
t(1)=t_old 
deriv_old=vT-vP_initial*exp(-t_old/tau);
t_new=t_old-deriv_old*step;
t(2)=t_new 
deriv_new=vT-vP_initial*exp(-t_new/tau) 
D_new=L+vT*t_new-tau*vP_initial*(1-exp(-t_new/tau))
disp('start iterations')
iter=0;
while abs(deriv_new)>0.1 & iter<50   
  
  if abs(deriv_new)<abs(deriv_old)
      deriv_old=deriv_new;
      t_new=t_new-deriv_new*step; 
      t(iter+3)=t_new;
      iter=iter+1;
  else
      step=0.5*step;
      t_new=t_new-deriv_new*step;
      t(iter+3)=t_new;
      iter=iter+1;
  end % if
  
  iter,t_new,t
  D_new=L+vT*t_new-tau*vP_initial*(1-exp(-t_new/tau))  
  deriv_new=vT-vP_initial*exp(-t_new/tau) 
  
end % while

t_opt=t_new;
D_opt=L+vT*t_new-tau*vP_initial*(1-exp(-t_new/tau));

figure(2) % plot Figure 7.22
subplot(2,2,1)
hold on
ti=linspace(0,800,750);
Di=L+vT*ti-tau*vP_initial*(1-exp(-ti/tau));
plot(ti,Di,'b','LineWidth',1.3)
axis([0 400 0 6000])
set(gca,'FontSize',11)
set(gca,'XTick',[0:100:400])
set(gca,'YTick',[0:1500:6000])
grid on
set(gca,'Box','on')
ylabel('D  (ft)','FontSize',12)
text(175,6800,'Sequence of Points in Search for Minimum','FontSize',12)
text(225,3500,'t_0 = 0','FontSize',13)
text(225,2200,'\Delta = 10','FontSize',13)
text(35,5100,'Starting Pt','FontSize',13)
D=L+vT*t-tau*vP_initial*(1-exp(-t/tau));
plot(t,D,'.r','MarkerSize',9)

subplot(2,2,3)
Ddoti=vT-vP_initial*exp(-ti/tau);
plot(ti,Ddoti,'b','LineWidth',1.3)
grid on
hold on
Ddot=vT-vP_initial*exp(-t/tau);
plot(t,Ddot,'.r','MarkerSize',9)
axis([0 400 -35 5])
set(gca,'FontSize',11)
set(gca,'XTick',[0:100:400])
set(gca,'YTick',[-35:10:5])
ylabel('dD/dt (ft/s)','FontSize',12)
text(5,10,'Sequence of Derivative Evaluations in Search for Minimum','FontSize',12)
xlabel('t  (s)','FontSize',12)
text(225,-16.5,'t_0 = 0','FontSize',13)
text(225,-25,'\Delta = 10','FontSize',13)  


%%%% start search for min from t0=800
clear t D
step=10;
t_old=800;
t(1)=t_old 
deriv_old=vT-vP_initial*exp(-t_old/tau);
t_new=t_old-deriv_old*step;
t(2)=t_new 
deriv_new=vT-vP_initial*exp(-t_new/tau) 
D_new=L+vT*t_new-tau*vP_initial*(1-exp(-t_new/tau))
disp('start iterations')
iter=0;
while abs(deriv_new)>0.1 & iter<50   
  
  if abs(deriv_new)<abs(deriv_old)
      deriv_old=deriv_new;
      t_new=t_new-deriv_new*step; 
      t(iter+3)=t_new;
      iter=iter+1;
  else
      step=0.5*step;
      t_new=t_new-deriv_new*step;
      t(iter+3)=t_new;
      iter=iter+1;
  end % if
  
  iter,t_new,t
  D_new=L+vT*t_new-tau*vP_initial*(1-exp(-t_new/tau))  
  deriv_new=vT-vP_initial*exp(-t_new/tau) 
  
end % while

t_opt=t_new;
D_opt=L+vT*t_new-tau*vP_initial*(1-exp(-t_new/tau));

subplot(2,2,2)
ti=linspace(0,800,750);
Di=L+vT*ti-tau*vP_initial*(1-exp(-ti/tau));
plot(ti,Di,'b','LineWidth',1.3)
axis([300 900 0 5000])
set(gca,'FontSize',11)
set(gca,'XTick',[300:150:900])
set(gca,'YTick',[0:1000:5000])
grid on
ylabel('D  (ft)','FontSize',12)
text(350,3200,'t_0 = 800','FontSize',13)
text(350,2250,'\Delta = 10','FontSize',13)
text(470,4500,'Starting Pt','FontSize',13)
hold on
D=L+vT*t-tau*vP_initial*(1-exp(-t/tau));
plot(t,D,'.r','MarkerSize',9)

subplot(2,2,4)
Ddoti=vT-vP_initial*exp(-ti/tau);
plot(ti,Ddoti,'b','LineWidth',1.3)
grid on
axis([300 900 -5 20])
set(gca,'FontSize',11)
set(gca,'XTick',[300:150:900])
set(gca,'YTick',[-5:5:20])
hold on
Ddot=vT-vP_initial*exp(-t/tau);
plot(t,Ddot,'.r','MarkerSize',9)
ylabel('dD/dt  (ft/s)','FontSize',12)
xlabel('t  (s)','FontSize',12)
text(335,16,'t_0 = 800','FontSize',13)
text(335,11.15,'\Delta = 10','FontSize',13)  
  
  
  
  
  
  
  
  
  
  
  
  
  
    














