% m-file Ch7_opt_search.m
% calls Simulink model target_projectile.mdl
% finds optimum firing angle to intercept target
% Note: do not change parameter values below
% plots Figure 7.17

clc, close all, clear all

L=5000; % ft
m=2000/32.2; % slugs
mu=0.1; % lb per ft/sec
vT=15; % mph
vT=vT*(5280/3600); % ft/sec
vP_initial=45; % projectile initial speed (mph)
vP_initial=vP_initial*(5280/3600); % projectile initial speed (ft/sec)
theta=45 ;% projectile firing angle (deg)
theta=theta*(pi/180); % projectile firing angle (rad)
T=0.05; % step size (sec)
%%%%% begin search for optimum theta
theta_old=0; % old theta value (rad)
theta=theta_old; 
theta_deg(1)=theta*180/pi;
iter(1)=1;
sim('target_projectile')
f_old=D(end); 
f(1)=f_old;

step=2.5*pi/180; % theta increment (rad)
theta_new=theta_old+step; % new theta value (rad)
theta=theta_new; 
theta_deg(2)=theta*180/pi;
iter(2)=2;
sim('target_projectile')
f_new=D(end); 
f(2)=f_new;
flag=0;
count=3;
while min(f_old,f_new)>10 & count<50 & flag==0    
      
     if f_new<f_old  
         theta_old=theta_new;
         theta_new=theta_new+step;         
     else 
         theta_lower=theta_old-step; 
         theta_lower_deg=theta_lower*180/pi
         theta_upper=theta_new; 
         theta_upper_deg=theta_upper*180/pi
         flag=1; % theta interval found       
     end % if  
     
  if flag==0   
  f_old=f_new;   
  theta=theta_new;  
  theta_deg(count)=theta*180/pi;
  sim('target_projectile')   
  f_new=D(end);
  f(count)=f_new;
  iter(count)=count;
  count=count+1;
  end % if flag
  
end % while

subplot(2,2,1)
plot(iter,theta_deg,'.b','MarkerSize',8)
grid on
set(gca,'XTick',[1 5:5:30])
axis([1 count 0 90])
ylabel('\theta  (deg)','FontSize',12)
xlabel('Iteration','FontSize',12)
% text(5,60,'\theta \rm vs Iteration','FontSize',11)
title('Phase 1 Search: \Delta\theta = 2.5 deg','FontSize',11)
hold on
plot(iter(end-2),theta_deg(end-2),'*r')
plot(iter(end),theta_deg(end),'*r')
text(5,72.5,'\theta_U = 72.5 deg','FontSize',12)
plot([23 30],[72.5 72.5],'k')
text(13,20,'\theta_L = 67.5 deg','FontSize',12)
plot([28 28],[30 67.5],'k')

subplot(2,2,3)
plot(iter,f,'.b','MarkerSize',8)
grid on
set(gca,'XTick',[1 5:5:30])
axis([1 count -250 6000])
ylabel('D_{final}','FontSize',12)
xlabel('Iteration','FontSize',12)
% text(5,1500,'\itD_{final}  \rmvs Iteration','FontSize',11)

if flag==1 % check if phase 1 finds theta interval

del_theta=(theta_upper-theta_lower)/25;
theta=theta_lower-del_theta;

  clear iter theta_deg
  i=0;
  while f_new>10 & theta <= theta_upper 
      i=i+1;
      iter(i)=i;
      theta=theta+del_theta;
      theta_deg(i)=theta*180/pi;
      sim('target_projectile')   
      f_new(i)=D(end);     
  end % while

  if f_new(i)<10
   theta_opt=theta*180/pi % opt theta (deg)
   f_opt=f_new(i) % min D_final
  else
   disp('No Solution')
  end % if f_new(i)

else
    theta_opt=theta_new*180/pi
    f_opt=f_new
end % if flag
 
subplot(2,2,2)
plot(iter(1:end-1),theta_deg(1:end-1),'b.','MarkerSize',8)
grid on
set(gca,'XTick',[1:12])
theta_lower_deg=theta_lower*180/pi;
theta_upper_deg=theta_upper*180/pi;
del_theta_deg=(theta_upper_deg-theta_lower_deg)/25; % Increase denominator to 100 if opt not found
axis([1 i+1 theta_lower_deg theta_opt+1])
ylabel('\theta  (deg)','FontSize',12)
xlabel('Iteration','FontSize',12)
% text(2.5,69.5,'\theta \rm vs Iteration','FontSize',11)
title('Phase 2 Search: \Delta\theta = 0.2 deg','FontSize',11)
hold on
plot(iter(end),theta_deg(end),'*r')   
text(2,69.7,'\theta_{opt} = 69.7 deg','FontSize',12)
plot([9.5 12],[69.7 69.7],'k')
% plot([iter(end-1) iter(end)],[theta_deg(end-1) theta_deg(end)])

subplot(2,2,4)
plot(iter,f_new,'.b','MarkerSize',8)
grid on
set(gca,'XTick',[1:12])
axis([1 i+1 -20 200])
ylabel('D_{final}','FontSize',12)
xlabel('Iteration','FontSize',12)
% text(2.5,50,'\itD_{final}  \rmvs Iteration','FontSize',11)


    
    
 