% m-file Ch7_reaction_kinetics.m
% calls Simulink model chemical.mdl
% plots Figure 7.30
% requires Optimization tool box

clc, close all, clear all
k=0.125; % actual rate constant
n=2.3; % actual reaction order
x_init=0.5; % initial concentration (moles/liter)
[T,X]=sim('chemical'); % simulate reaction with actual parameters k and n
x_obs=X(1:10:end);  % initial concentration and simulated concentrations at the end of each minute

A=[]; B=[]; Aeq=[]; Beq=[];
LB(1)=0; UB(1)=Inf;
LB(2)=0; UB(2)=Inf;
NONLCON=[];
OPTIONS=[];
k_n_init=[1 1];
[k_n,FVAL,EXITFLAG,OUTPUT]=FMINCON('obj_fcn_kinetics',k_n_init,A,B,Aeq,Beq,LB,UB,NONLCON,OPTIONS,x_obs)
k=k_n(1); % opt k
n=k_n(2); % opt n

plot(T(1:10:end),x_obs,'.')
xlabel('t  (min)','FontSize',13)
ylabel('x(t) and x\wedge(t),  moles per liter','FontSize',13)
title('Observed and Simulated (k = k_{opt}, n = n_{opt}) Concentrations','FontSize',11)
[T,X]=sim('chemical'); % simulate reaction with optimal parameters k and n
hold on
plot(T,X)
text(15,0.45,'End-of-minute observed concentrations','FontSize',11)
plot([12.5],[0.45],'.b')
text(15,0.4,'Simulated concentration using \itk_{\rmopt} \rmand \itn_{\rmopt}','FontSize',11)
plot([11.5 13.5],[0.404 0.404],'b')
text(29,0.3,'\itk_{\rmopt} \rm= 0.1256, \itn_{\rmopt} \rm= 2.3037','FontSize',11)
text(-7.8,0.261,'<','FontSize',11)