% m-file Ch7_ship_control.m
% PI control of a ship's heading
% calls Simulink model ship.mdl
% plots Figure 7.26

clc, clear all, close all

Kg=10*pi/180; % gyro gain (v/deg)
L=25; % sat limit
Ks=0.04*180/pi; % ship gain (deg/sec per v)
tau=10.0; % motor time constant (sec)
theta_com=30; %  command heading (deg)

Ki=0;
c1=1; c2=1; c3=1; c4=0; c5=0;
numKp=30; numKd=30;
Kpmin=2.5; Kpmax=25;
Kdmin=0; Kdmax=25;
for i=1:numKp
   Kp=Kpmin+((Kpmax-Kpmin)/(numKp-1))*(i-1);  
   Kpp(i)=Kp;    
      for j=1:numKd;
        Kd=Kdmin+((Kdmax-Kdmin)/(numKd-1))*(j-1);     
        Kdd(j)=Kd;  
        sim('ship') 
        t=heading(:,1);
        theta=heading(:,2);        
        max_theta=max(theta);
        threshold1=0.1*theta_com;
        threshold2=0.9*theta_com;
        
        flag=0; rise_time=0;
        for k=2:length(t)
            if theta(k)>threshold1 & theta(k-1)<threshold1 & flag==0
                t10=t(k);
            elseif  theta(k)>threshold2 & theta(k-1)<threshold2 & flag==0                
                t90=t(k); 
                rise_time=t90-t10;
                flag=1;
            end % if
        end % for k
        if flag==0
            Kp,Kd,max_theta,disp('No Rise Time Found')
            rise_time=100;
        end
                    
        if max_theta+0.1>=theta_com            
          max_heading_overshoot=max_theta-theta_com;
        else 
          max_heading_overshoot=0;
          Kp,Kd,max_theta,disp('Commanded Heading Not Attained')
        end       
        
        max_heading_rate=max(heading_rate(:,2));
        z(i,j)=c1*max_heading_overshoot+c2*max_heading_rate+c3*rise_time+c4*IAE(end,2)+c5*ISE(end,2);
    end % j
end % i
colormap([0 0 0])
mesh(Kdd,Kpp,z)
grid on
axis([0 25 0 25 10 40])
set(gca,'FontSize',11)
set(gca,'XTick',[0:5:25])
set(gca,'YTick',[0:5:25])
set(gca,'ZTick',[10:5:40])
xlabel('K_d','FontSize',12)
ylabel('K_p','FontSize',12)
zlabel('F(K_p, K_d)','FontSize',12)
title('Objective Function Surface','FontSize',12)





