% m-file Ch8_Ex8_13.m
% plots Figure 8.102

clc, clear all, close all

zeta=0.25; wn=1000;
b1=1; b0=wn^2;
K_cont=1;
num_cont=K_cont*[b1 b0];

a2=1; a1=2*zeta*wn; a0=wn^2;
den_cont=[a2 a1 a0];
sysc=tf(num_cont,den_cont) 
T=0.001; % sampling time (sec)
w_nyq=pi/T; % nyquist frequency (rad/sec)
w=linspace(0,w_nyq,1000);
s=j*w;
G_cont=K_cont*(b1*s+b0)./(a2*s.^2 + a1*s + a0);
Mag_cont=abs(G_cont);
Phase_cont=180*angle(G_cont)/pi;

f=1/T; % sampling freq (Hz)%
sysd=c2d(sysc,T,'tustin')  % BLT system, no prewarping
[num_disc,den_disc]=bilinear(num_cont,den_cont,f)  % BLT num and den coefficients, no prewarping
z=exp(j*w*T);
b2_disc=num_disc(1);
b1_disc=num_disc(2);
b0_disc=num_disc(3);
a2_disc=den_disc(1);
a1_disc=den_disc(2);
a0_disc=den_disc(3);
G_disc=(b2_disc*z.^2 + b1_disc*z + b0_disc)./(a2_disc*z.^2 + a1_disc*z + a0_disc);
Mag_disc=abs(G_disc);
Phase_disc=180*angle(G_disc)/pi;

w_crit=wn; % critical frequency (rad/sec)
w_pre_warped=(2/T)*tan(0.5*w_crit*T)
f_crit=w_crit/(2*pi); % warped frequency (Hz)
sysd_prewarp=c2d(sysc,T,'prewarp',w_crit) % BLT system with prewarping using 'c2d' function
[num_disc_warp,den_disc_warp]=bilinear(num_cont,den_cont,f,f_crit)  % BLT num and den coefficients with prewarping using 'bilinear'
b2_disc_warp=num_disc_warp(1);
b1_disc_warp=num_disc_warp(2);
b0_disc_warp=num_disc_warp(3);
a2_disc_warp=den_disc_warp(1);
a1_disc_warp=den_disc_warp(2);
a0_disc_warp=den_disc_warp(3);
G_disc_warp=(b2_disc_warp*z.^2 + b1_disc_warp*z + b0_disc_warp)./(a2_disc_warp*z.^2 + a1_disc_warp*z + a0_disc_warp);
Mag_disc_warp=abs(G_disc_warp);
Phase_disc_warp=180*angle(G_disc_warp)/pi;


figure(1) % plot Figure 8.102
subplot(2,1,1)
plot(w,Mag_cont,'b','LineWidth',1.3)
grid on
axis([0 w_nyq 0 2.2])
set(gca,'FontSize',11,'XTick',[0:500:3000],'YTick',[0:0.5:2])
hold on
plot(w,Mag_disc,'r','LineWidth',1.3)
plot(w,Mag_disc_warp,'k','LineWidth',1.3)
xlabel('\omega  (rad/s)','FontSize',12)
ylabel('Magnitude','FontSize',12)
text(500,2.35,'Use of Bilinear Transform with and without Prewarping','FontSize',12)
text(2300,0.5,'|H(j\omega)|','FontSize',12)
text(1500,1.0,'|H(e^{j\omegaT})|','FontSize',12)
text(500,0.5,'|H(e^{j\omegaT})|','FontSize',12)
text(1542,1.17,'\bf\wedge','FontSize',11)
plot([w_crit w_crit],[0 3],'k','LineWidth',1.1)
plot([930 1430],[0.45 0.45],'k','LineWidth',1.1)
plot([1259 1465],[0.95 0.95],'k','LineWidth',1.1)
plot([2175 2275],[0.45 0.45],'k','LineWidth',1.1)
plot([2175 2175],[0.27 0.45],'k','LineWidth',1.1)
text(1165,1.85,'Prewarped frequency, \omega_0 0= 1000 rad/s','FontSize',12)


subplot(2,1,2)
plot(w,Phase_cont,'b','LineWidth',1.3)
grid on
axis([0 w_nyq -180 0])
set(gca,'FontSize',11,'XTick',[0:500:3000],'YTick',[-180:45:0])
hold on
plot(w,Phase_disc,'r','LineWidth',1.3)
plot(w,Phase_disc_warp,'k','LineWidth',1.3)
xlabel('\omega  (rad/sk)','FontSize',12)
ylabel('Phase (deg)','FontSize',12)
text(2450,-145,'Arg H(j\omega)','FontSize',12)
text(1500,-125,'Arg H(e^{j\omegaT})','FontSize',12)
text(400,-150,'Arg |H(e^{j\omegaT})|','FontSize',12)
text(1707,-111,'\bf\wedge','FontSize',11)
plot([w_crit w_crit],[-200 0],'k','LineWidth',1.1)
plot([975 1400],[-155 -155],'k','LineWidth',1.1)
plot([1200 1450],[-130 -130],'k','LineWidth',1.1)
plot([2315 2415],[-145 -145],'k','LineWidth',1.1)
plot([2315 2315],[-145 -165],'k','LineWidth',1.1)