% m-file Ch8_Ex8_8.m
% calls Simulinkj model TwoTanks.mdl, TwoTanks_linmod.mdl and TwoTanks_NL_and_L
% plots Figure 8.58 and Figure 8.59

close all, clear all, clc

% baseline parameter values
gam=62.4; % specific wt of water (lb per cu ft) 
p0=14.7*144; % atm pressure (lb/sq ft)
R1=15; % ft
A1=pi*R1^2;
L1=50; % ft
R2=5; % ft
A2=pi*R2^2;
L2=7.5; % ft
c1=4; % cu ft/min per psf^1/2
c2=2; % 
EPS=1e-16;  % tolerance for flow calculations

F0=60; % Tank 1 inflow (cu ft per min)

%%%%% steady-state analysis
F0_bar=60; %  Tank 1 operating point inflow (cu ft per min)
alpha=(F0_bar/c2)^2;
a=gam; b=-(p0+gam*L2+alpha); c=alpha*L2;  % coeffs in quadratic for H2_ss
H2_bar=min(roots([a b c])); 
p2_bar=L2*p0/(L2-H2_bar);
beta=(F0_bar/c1)^2;
H1_bar=L2+(beta+p2_bar-p0)/gam; 
F12_bar=c1*sqrt((gam*(H1_bar-L2)-(H2_bar*p0)/(L2-H2_bar)));
F2_bar=c2*sqrt((H2_bar*p0)/(L2-H2_bar)+gam*H2_bar);
% H1_bar,H2_bar,F12_bar,F2_bar,p2_bar

% initial conditions
H1_init=H1_bar;
H2_init=H2_bar;

%%%%% linearization
k1=gam*(H1_bar-L2);
k2=(H2_bar/(L2-H2_bar))*p0;
k3=sqrt(k1-k2);
k4=gam+(p0*L2)/(L2-H2_bar)^2;
A11=(-0.5*gam*c1/A1)/k3; 
A12=(0.5*p0*L2*c1/A1)/k3;
A12=A12/((L2-H2_bar)^2);
A21=(0.5*gam*c1/A2)/k3;

A22=(-0.5*p0*L2*c1/A2)/k3;
A22=A22/((L2-H2_bar)^2);
A22=A22-(0.5*c2/A2)*k4/sqrt((k2+gam*H2_bar));

AA=[A11 A12; A21 A22]; 
lam=eig(AA);
lam1=lam(1); tau1=-1/lam1;
lam2=lam(2); tau2=-1/lam2;

stiffness=lam2/lam1; 

%%%%% Begin Linmod
T=0.1; % SIMULINK RK-4 step size in model TwoTanks_NL_and_L
Tf=0.1;
[sizes,X0,states]=TwoTanks([ ],[ ],[ ],0);
H_opert=[H1_bar; H2_bar];
u0=F0;
[A,B,C,D]=linmod('TwoTanks_linmod',H_opert,u0);

% dF=-5; % F0 peturbation
% sim('TwoTanks_NL_and_L')
% t=H1_sim(:,1);

% figure(1) % plotFigure 8.58
% plot(t,H1_sim(:,2),'b')
% axis([0 1500 20.7 23.7])
% hold on
% plot(t,H1_lin(:,2),'r:')
% xlabel('\itt  \rm(min)','FontSize',11)
% ylabel('\itH_{\rm1}  \rm(ft)','FontSize',11)
% title('Nonlinear and Linearized System Tank 1 Level Response','FontSize',11)
% 
% text(825,20.9,'linearized','FontSize',11)
% plot([1075 1244],[20.9 20.9],'k')
% text(1020,21.2,'nonlinear','FontSize',11)
% plot([844.5 990],[21.19 21.19],'k')
% 
% text(750,23,'\itF_{\rm0}\rm(\itt\rm) = \itF_{\rm0} , \itt \leq  \rm50 min','FontSize',11)
% text(927,23.123,'-','FontSize',11)
% text(750, 22.7,'       = \itF_{\rm0} \rm+ \Delta\itF_{\rm0} , \itt > \rm50 min','FontSize',11)
% text(910,22.82,'-','FontSize',11)
% text(700,22.25,'(\itF_{\rm0} \rm= 60 ft^{3}/min,  \Delta\itF_{\rm0} \rm= -5 ft^{3}/min)','FontSize',11)
% text(730,22.37,'-','FontSize',11)
% text(150,23.5,'\itH_{\rm1}\rm(0) = \itH_{\rm1} \rm= 23.52 ft','FontSize',11)
% text(347,23.63,'-','FontSize',11)
% 
% figure(2) % plot Figure 8.59
% plot(t,H2_sim(:,2),'b')
% axis([0 1500 1.75 2.02])
% hold on
% plot(t,H2_lin(:,2),'r:')
% xlabel('\itt  \rm(min)','FontSize',11)
% ylabel('\itH_{\rm2}  \rm(ft)','FontSize',11)
% title('Nonlinear and Linearized System Tank 2 Level Response','FontSize',11)
% 
% text(550,1.78,'nonlinear','FontSize',11)
% plot([783 928],[1.779 1.779],'k')
% text(750,1.82,'linearized','FontSize',11)
% plot([585 720],[1.82 1.82],'k')
% 
% text(750,1.951,'\itF_{\rm0}\rm(\itt\rm) = \itF_{\rm0} , \itt \leq  \rm50 min','FontSize',11)
% text(926.3,1.962,'-','FontSize',11)
% text(750, 1.92,'       = \itF_{\rm0} \rm+ \Delta\itF_{\rm0} , \itt > \rm50 min','FontSize',11)
% text(910,1.931,'-','FontSize',11)
% text(700,1.87,'(\itF_{\rm0} \rm= 60 ft^{3}/min,  \Delta\itF_{\rm0} \rm= -5 ft^{3}/min)','FontSize',11)
% text(734,1.881,'-','FontSize',11)
% text(150,2.005,'\itH_{\rm2}\rm(0) = \itH_{\rm2} \rm= 2.01 ft','FontSize',11)
% text(347,2.016,'-','FontSize',11)
% 
% %%%%% Part g
% 
% deltaH_ss=-inv(A)*B*dF
% H1_ss=H1_bar+deltaH_ss(1)
% H2_ss=H2_bar+deltaH_ss(2)
