% m-file Ch8_Fig8_45.m
% plots Figure 8.45

clc, close all, clear all

%%%%% RK-4 %%%%%

num=100;
for i=1:num+1
   theta=((i-1)/num)*2*pi;  
   x=exp(j*theta);
   r=roots([1/24 1/6 1/2 1 1-x]); 
   lamT_RK4_1(i)=r(1);   
   lamT_RK4_2(i)=r(2);  
   lamT_RK4_3(i)=r(3);
   lamT_RK4_4(i)=r(4);
end

% lamT_RK4_4; 
lamT_RK4_4=lamT_RK4_4(2:round(num/2)+1);
% lamT_RK4_3; 
lamT_RK4_3=lamT_RK4_3(1:round(num/2)+1);
% lamT_RK4_2; 
lamT_RK4_2=lamT_RK4_2(round(num/2)+2:num+1);
% lamT_RK4_1;  
lamT_RK4_1=lamT_RK4_1(round(num/2)+2:num);
% plot(lamT_RK4_1,'*b-')
% plot(lamT_RK4_2,'*r-')
% plot(lamT_RK4_3,'*g-')
% plot(lamT_RK4_4,'*m-')
lamT_RK4_top=[0 lamT_RK4_4 lamT_RK4_1 lamT_RK4_3 lamT_RK4_2];
lamT_RK4_bot=lamT_RK4_top';

%%%%% Pitch control system dynamics %%%%%

wn=5; % natural frequency (rad/sec)
KA=10;
tauA=0.8;
zeta=0.2;

%%%%% control surface actuator parameters %%%%%
Kact=500;
Ce=0.08;
tau=0.01;
Kc=Kact*Ce/(tau^2);
z=1/Ce;
p1=1/tau;
p2=p1;
J=1;

%%%%% pitch input command parameters %%%%%
theta_com_amp_deg=5;
theta_com_amp=theta_com_amp_deg*pi/180;

K=0.1625;
Kq=0.2;

%%%%% State Eq matrices A, B, C, D %%%%%
wnsq=wn^2;
%%%%% Coefficient matrix %%%%%
A(7,7)=0;
A(1,2)=KA*wnsq;
A(1,3)=KA*wnsq*tauA;
A(2,3)=1;
A(3,2)=-wnsq;
A(3,3)=-2*zeta*wn;
A(3,4)=1;
A(4,5)=1;
A(5,6)=1;
A(6,1)=-Kc*K;
A(6,2)=-Kc*K*Kq*KA*wnsq;
A(6,3)=-Kc*K*Kq*KA*wnsq*tauA;
A(6,4)=-Kc;
A(6,6)=-p2;
A(6,7)=Kc*(z-p1);
A(7,1)=-K;
A(7,2)=-K*Kq*KA*wnsq;
A(7,3)=-K*Kq*KA*wnsq*tauA;
A(7,4)=-1;
A(7,7)=-p1;
%%%%% Input matrix %%%%%
B(1:7)=0;
B=B';
B(6)=Kc*K;
B(7)=K;
%%%%% Output matrix %%%%%
C(7,7)=0;
C(1,1)=1; % y1=x1=pitch (rad)
C(2,2)=1; % y2=x2
C(3,3)=1; % y3=x3
C(4,4)=1; % y4=x4=delta_e
C(5,5)=1; % y5=x5=delta_e_dot
C(6,6)=1; % y6=x6=delta_e_dbldot
C(7,7)=1; % y7=x7
%%%%% Direct transmission matrix %%%%%
D(1:7)=0;  
D=D';
 
ev=eig(A)

figure(1) % plot Figure 8.45

for T=[0.01 0.0187]
    evT=T*ev;
    if T==0.01        
       subplot(1,2,1) 
       plot(evT,'r.','MarkerSize',10) 
       hold on
       grid on
       axis([-3 0.75 -4 3.25])
       set(gca,'FontSize',11,'XTick',[-3:1.0:0.75],'YTick',[-4:3])
       text(-2.65,-3.5,'\lambda_iT_i, i=1,..,7  (T=0.01 s)','FontSize',11)
       plot(-2.8,-3.5,'r.','MarkerSize',10)
       plot(lamT_RK4_top,'b','LineWidth',1.3)
       plot(lamT_RK4_bot,'b','LineWidth',1.3)
       text(-2.8,2.5,'\lambdaT plane','FontSize',12)
       text(-2.8,3.55,'RK-4 Stability Boundary','FontSize',12)
       xlabel('Re (\lambdaT)','FontSize',13)
       ylabel('Im (\lambdaT)','FontSize',11)
    elseif T==0.0187
Tmax=-2.785/max(ev)
evTmax=Tmax*ev;

subplot(1,2,2)
plot(evTmax,'r.','MarkerSize',10)
hold on
grid on
axis([-3 0.5 -4 3.25])
set(gca,'FontSize',11,'XTick',[-3:1.0:0.75],'YTick',[-4:3])
text(-2.75,-3.5,'\lambda_iT_i, i=1,..,7  (T=0.0187 s)','FontSize',11)
plot(-2.9,-3.5,'r.','MarkerSize',10)
plot(lamT_RK4_top,'b','LineWidth',1.3)
plot(lamT_RK4_bot,'b','LineWidth',1.3)
text(-2.8,2.5,'\lambdaT plane','FontSize',12)
text(-2.8,3.55,'RK-4 Stability Boundary','FontSize',12)
xlabel('Re (\lambdaT)','FontSize',13)
ylabel('Im (\lambdaT)','FontSize',11)
    end % if T
    
end % for T








