% m-file Ch8_Fig8_60.m
% plots Figure 8.60

close all, clear all, clc

% baseline parameter values
gam=62.4; % specific wt of water (lb per cu ft) 
p0=14.7*144; % atm pressure (lb/sq ft)
R1=15; % ft
A1=pi*R1^2;
L1=60; % ft
R2=5; % ft
A2=pi*R2^2;
L2=7.5; % ft
c1=4; % cu ft/min per psf^1/2
c2=2; % 
EPS=1e-16;  % tolerance for flow calculations
i=0;
for F0=1:1:95 % independent inflow to tank 1 (cu ft/min)
i=i+1; 
F0_bar(i)=F0;     
alpha=(F0/c2)^2;
a=gam; b=-(p0+gam*L2+alpha); c=alpha*L2;  % coeffs in quadratic for H2_ss
H2=min(roots([a b c]));
H2_bar(i)=H2;
p2=L2*p0/(L2-H2);
p2_bar(i)=p2;
beta=(F0/c1)^2;
H1=L2+(beta+p2-p0)/gam;
H1_bar(i)=H1;
k1=gam*(H1-L2);
k2=(H2/(L2-H2))*p0;
k3=sqrt(k1-k2);
k4=gam+(p0*L2)/(L2-H2)^2;
A11=(-0.5*gam*c1/A1)/k3; 
A12=(0.5*p0*L2*c1/A1)/k3;
A12=A12/((L2-H2)^2);
A21=(0.5*gam*c1/A2)/k3;
A22=(-0.5*p0*L2*c1/A2)/k3;
A22=A22/((L2-H2)^2);
A22=A22-(0.5*c2/A2)*k4/sqrt((k2+gam*H2));
AA=[A11 A12; A21 A22]; 
lam=eig(AA);
lam1=lam(1); tau1=-1/lam1;
lam2=lam(2); tau2=-1/lam2;
stiffness=lam2/lam1; 
stiffness_bar(i)=stiffness;

if F0==60
    stiffness_60=stiffness;
    H1_60=H1;
    H2_60=H2;
    p2_60=p2/144;
end

p2_bar(i)=p2_bar(i)/144;
end

figure(1) % plot Figure 8.60
subplot(2,2,1)
plot(F0_bar,stiffness_bar,'b','LineWidth',1.3)
grid on
axis([0 100 0 1000])
set(gca,'FontSize',11,'XTick',[0:20:100],'YTick',[0:200:1000])
hold on
plot([0 60],[stiffness_60 stiffness_60],'--k','LineWidth',1.1)
plot([60 60], [0 stiffness_60],'--k','LineWidth',1.1)
plot(60,stiffness_60,'.r','MarkerSize',13)
ylabel('Stiffness','FontSize',12)
text(-5,1130,'Linearized System Stiffness','FontSize',12)
plot(10,770,'.r','MarkerSize',13)
text(15,800,'Operating Pt','FontSize',12)

subplot(2,2,2)
plot(F0_bar,H1_bar,'b','LineWidth',1.3)
grid on
axis([0 100 0 60])
set(gca,'FontSize',11,'XTick',[0:20:100],'YTick',[0:15:60])
hold on
plot([0 60],[H1_60 H1_60],'--k','LineWidth',1.1)
plot([60 60], [0 H1_60],'--k','LineWidth',1.1)
plot(60,H1_60,'.r','MarkerSize',13)
ylabel('H_1  (ft)','FontSize',12)
text(-31.0,23.0,'\bf|')
text(-2,67,'Steady-state Tank 1 Level','FontSize',12)
plot(10,39,'.r','MarkerSize',13)
text(15,40,'Operating Pt','FontSize',12)

subplot(2,2,3)
plot(F0_bar,H2_bar,'b','LineWidth',1.3)
grid on
axis([0 100 0 4])
set(gca,'FontSize',11,'XTick',[0:20:100],'YTick',[0:4])
hold on
plot([0 60],[H2_60 H2_60],'--k','LineWidth',1.1)
plot([60 60], [0 H2_60],'--k','LineWidth',1.1)
plot(60,H2_60,'.r','MarkerSize',13)
xlabel('F_0 (ft^3/min)','FontSize',12)
text(29,-0.77,'_')
ylabel('H_2  (ft)','FontSize',12)
text(-26.5,1.55,'\bf|')
text(-2,4.5,'Steady-state Tank 2 Level','FontSize',12)
plot(10,3.20,'.r','MarkerSize',13)
text(15,3.25,'Operating Pt','FontSize',12)

subplot(2,2,4)
plot(F0_bar,p2_bar,'b','LineWidth',1.3)
grid on
axis([0 100 0 30])
set(gca,'FontSize',11,'XTick',[0:20:100],'YTick',[0:5:30])
hold on
plot([0 60],[p2_60 p2_60],'--k','LineWidth',1.1)
plot([60 60], [0 p2_60],'--k','LineWidth',1.1)
plot(60,p2_60,'.r','MarkerSize',13)
xlabel('F_0 (ft^3/min)','FontSize',12)
text(29,-5.8,'_')
ylabel('p_2  (psi)','FontSize',12)
text(-29.0,10.1,'\bf|')
text(-20,35,'Steady-state Tank 2 Air Pressure','FontSize',12)
plot(10,26.5,'.r','MarkerSize',13)
text(15,27.0,'Operating Pt','FontSize',12)







