% m-file Ch8_TwoTanks_AB2.m
% plots Figure 8.61 and Figure 8.62

close all, clear all, clc

global A1 A2 L1 L2 c1 c2 gam p0 

% baseline parameter values
gam=62.4; % specific wt of water (lb per cu ft) 
p0=14.7*144; % atm pressure (lb/sq ft)
R1=15; % ft
A1=pi*R1^2;
L1=50; % ft
R2=5; % ft
A2=pi*R2^2;
L2=7.5; % ft
c1=4; % cu ft/min per psf^1/2
c2=2; % 
EPS=1e-16;  % tolerance for flow calculations

%%%%% steady-state analysis
F0_bar=60; %  Tank 1 operating point inflow (cu ft per min)
alpha=(F0_bar/c2)^2;
a=gam; b=-(p0+gam*L2+alpha); c=alpha*L2;  % coeffs in quadratic for H2_ss
H2_bar=min(roots([a b c])); 
p2_bar=L2*p0/(L2-H2_bar);
beta=(F0_bar/c1)^2;
H1_bar=L2+(beta+p2_bar-p0)/gam; 
F12_bar=c1*sqrt((gam*(H1_bar-L2)-(H2_bar*p0)/(L2-H2_bar)));
F2_bar=c2*sqrt((H2_bar*p0)/(L2-H2_bar)+gam*H2_bar);

%%%%% Begin AB-2 integration of system with T=0.1, F0=55
figure(1) % plot Figure 8.61
T=0.1;
tfinal=3000; % final simulation time (sec)
H1_init=H1_bar; % initialize H1
H1(1)=H1_init; % H1 is array for plotting
t(1)=0;
H2_init=H2_bar; % initialize H2
H2(1)=H2_init; % H2 is array for plotting

F0=55;
%%% Step 1 - Take Euler step to find H1(T) and H2(T)
k11=deriv_H1(H1_init,H2_init,F0); 
k12=deriv_H2(H1_init,H2_init,F0);
H1(2)=H1_init+T*k11;  % compute H1(T) using RK-1
H2(2)=H2_init+T*k12;  % compute H2(T) using RK-1
t(2)=T;
  
%%% Step 2 - Advance H1 and H2 using AB-2
ifinal=round(tfinal/T); % compute total number of frames

for i=2:ifinal   % start from beginning of 2nd frame  
   H1_past=H1(i-1); H2_past=H2(i-1);
   H1_current=H1(i); H2_current=H2(i);
   H1_new=H1_current+(0.5*T)*(3*deriv_H1(H1_current,H2_current,F0)-deriv_H1(H1_past,H2_past,F0));    
   H1(i+1)=H1_new;
   H2_new=H2_current+(0.5*T)*(3*deriv_H2(H1_current,H2_current,F0)-deriv_H2(H1_past,H2_past,F0));  
   H2(i+1)=H2_new;
   t(i+1)=i*T;  
end % i

subplot(2,2,1)
plot(t,H1,'b','LineWidth',1.3)
grid on
axis([0 3000 20 24])
set(gca,'FontSize',11,'XTick',[0:1000:3000]','YTick',[20:24])
ylabel('H_1  (ft)','FontSize',12)
text(-900,24.6,'AB-2 Simulation of Tank 1 Level, F_0(t) = 55 ft^3/min, t \geq 0, H_1(0) = 23.52 ft','FontSize',12)
text(1000,22.25,'T = 0.1 min','FontSize',13)

subplot(2,2,3)
plot(t,H2,'b','LineWidth',1.3)
grid on
axis([0 3000 0 2.5])
set(gca,'FontSize',11,'XTick',[0:1000:3000]','YTick',[0:0.5:2.5])
ylabel('H_2  (ft)','FontSize',12)
text(-900,2.85,'AB-2 Simulation of Tank 2 Level, F_0(t) = 55 ft^3/min, t \geq 0, H_2(0) = 2.01 ft','FontSize',12)
xlabel('t  (min)','FontSize',12)
text(1000,1.15,'T = 0.1 min','FontSize',12)


%%%%% Begin AB-2 integration of system with T=0.87, F0=55
clear t H1 H2
T=0.87;
H1_init=H1_bar; % initialize H1
H1(1)=H1_init; % H1 is array for plotting
t(1)=0;
H2_init=H2_bar; % initialize H2
H2(1)=H2_init; % H2 is array for plotting

F0=55;
%%% Step 1 - Take Euler step to find H1(T) and H2(T)
k11=deriv_H1(H1_init,H2_init,F0); 
k12=deriv_H2(H1_init,H2_init,F0);
H1(2)=H1_init+T*k11;  % compute H1(T) using RK-1
H2(2)=H2_init+T*k12;  % compute H2(T) using RK-1
t(2)=T;
  
%%% Step 2 - Advance H1 and H2 using AB-2
ifinal=round(tfinal/T); % compute total number of frames

for i=2:ifinal   % start from beginning of 2nd frame  
   H1_past=H1(i-1); H2_past=H2(i-1);
   H1_current=H1(i); H2_current=H2(i);
   H1_new=H1_current+(0.5*T)*(3*deriv_H1(H1_current,H2_current,F0)-deriv_H1(H1_past,H2_past,F0));    
   H1(i+1)=H1_new;
   H2_new=H2_current+(0.5*T)*(3*deriv_H2(H1_current,H2_current,F0)-deriv_H2(H1_past,H2_past,F0));  
   H2(i+1)=H2_new;
   t(i+1)=i*T;  
end % i

subplot(2,2,2)
plot(t,H1,'b','LineWidth',1.3)
grid on
axis([0 3100 20.5 25])
set(gca,'FontSize',11,'XTick',[0:1000:3000]','YTick',[20:24])
ylabel('H_1  (ft)','FontSize',12)
text(400,24.28,'T = 0.87 min','FontSize',13)

subplot(2,2,4)
plot(t,H2,'b','LineWidth',1.3)
grid on
axis([0 3000 0 2.5])
set(gca,'FontSize',11,'XTick',[0:1000:3000]','YTick',[0:0.5:2.5])
ylabel('H_2  (ft)','FontSize',12)
xlabel('t  (min)','FontSize',12)
text(150,0.65,'T = 0.87 min','FontSize',12)
% 


%%%%% Begin AB-2 integration of system with T=0.1, F0=60 and tank initially empty
clear t H1 H2
T=0.1;
tfinal=3000; % final simulation time (sec)
H1_init=0; % initialize H1
H1(1)=H1_init; % H1 is array for plotting
t(1)=0;
H2_init=0; % initialize H2
H2(1)=H2_init; % H2 is array for plotting

F0=60;
%%% Step 1 - Take Euler step to find H1(T) and H2(T)
k11=deriv_H1(H1_init,H2_init,F0); 
k12=deriv_H2(H1_init,H2_init,F0);
H1(2)=H1_init+T*k11;  % compute H1(T) using RK-1
H2(2)=H2_init+T*k12;  % compute H2(T) using RK-1
t(2)=T;
  
%%% Step 2 - Advance H1 and H2 using AB-2
ifinal=round(tfinal/T); % compute total number of frames

for i=2:ifinal   % start from beginning of 2nd frame  
   H1_past=H1(i-1); H2_past=H2(i-1);
   H1_current=H1(i); H2_current=H2(i);
   H1_new=H1_current+(0.5*T)*(3*deriv_H1(H1_current,H2_current,F0)-deriv_H1(H1_past,H2_past,F0));    
   H1(i+1)=H1_new;
   H2_new=H2_current+(0.5*T)*(3*deriv_H2(H1_current,H2_current,F0)-deriv_H2(H1_past,H2_past,F0));  
   H2(i+1)=H2_new;
   t(i+1)=i*T;  
end % i

figure(2) % plot Figure 8.62
subplot(2,2,1)
plot(t,H1,'b','LineWidth',1.3)
grid on
axis([0 3000 0 30])
set(gca,'FontSize',11,'XTick',[0:1000:3000]','YTick',[0:5:30])
ylabel('H_1  (ft)','FontSize',12)
text(-750,34,'AB-2 Simulation of Tank 1 Level, F_0(t) = 60 ft^3/min, t \geq 0, H_1(0) = 0 ft','FontSize',12)
text(1000,11.58,'T = 0.1 min','FontSize',13)

subplot(2,2,3)
plot(t,H2,'b','LineWidth',1.3)
grid on
axis([0 3000 0 3])
set(gca,'FontSize',11,'XTick',[0:1000:3000]','YTick',[0:0.5:3])
ylabel('H_2  (ft)','FontSize',12)
text(-750,3.4,'AB-2 Simulation of Tank 2 Level, F_0(t) = 60 ft^3/min, t \geq 0, H_2(0) = 0 ft','FontSize',12)
xlabel('t  (min)','FontSize',12)
text(1000,1.18,'T = 0.1 min','FontSize',12)


%%%%% Begin AB-2 integration of system with T=0.87, F0=60 and tanks initially empty
clear t H1 H2
T=0.87;
H1_init=0; % initialize H1
H1(1)=H1_init; % H1 is array for plotting
t(1)=0;
H2_init=0; % initialize H2
H2(1)=H2_init; % H2 is array for plotting

F0=60;
%%% Step 1 - Take Euler step to find H1(T) and H2(T)
k11=deriv_H1(H1_init,H2_init,F0); 
k12=deriv_H2(H1_init,H2_init,F0);
H1(2)=H1_init+T*k11;  % compute H1(T) using RK-1
H2(2)=H2_init+T*k12;  % compute H2(T) using RK-1
t(2)=T;
  
%%% Step 2 - Advance H1 and H2 using AB-2
ifinal=round(tfinal/T); % compute total number of frames

for i=2:ifinal   % start from beginning of 2nd frame  
   H1_past=H1(i-1); H2_past=H2(i-1);
   H1_current=H1(i); H2_current=H2(i);
   H1_new=H1_current+(0.5*T)*(3*deriv_H1(H1_current,H2_current,F0)-deriv_H1(H1_past,H2_past,F0));    
   H1(i+1)=H1_new;
   H2_new=H2_current+(0.5*T)*(3*deriv_H2(H1_current,H2_current,F0)-deriv_H2(H1_past,H2_past,F0));  
   H2(i+1)=H2_new;
   t(i+1)=i*T;  
end % i

subplot(2,2,2)
plot(t,H1,'b','LineWidth',1.3)
grid on
axis([0 3000 0 30])
set(gca,'FontSize',11,'XTick',[0:1000:3000]','YTick',[0:5:30])
ylabel('H_1  (ft)','FontSize',12)
text(1000,11.58,'T = 0.87 min','FontSize',13)

subplot(2,2,4)
plot(t,H2,'b','LineWidth',1.3)
grid on
axis([0 3000 0 3])
set(gca,'FontSize',11,'XTick',[0:1000:3000]','YTick',[0:0.5:3])
ylabel('H_2  (ft)','FontSize',12)
xlabel('t  (min)','FontSize',12)
text(1000,0.65,'T = 0.87 min','FontSize',12)

 













