% m-file Ch8_Sec4_Two_Tanks.m

close all, clear all, clc

% baseline parameter values
gam=62.4; % specific wt of water (lb per cu ft) 
p0=14.7*144; % atm pressure (lb/sq ft)
R1=15; % ft
A1=pi*R1^2;
L1=25; % ft
R2=5; % ft
A2=pi*R2^2;
L2=7.5; % ft
c1=4; % cu ft/min per psf^1/2
c21=1; % cu ft/min per psf^1/2
c2=2; % 
EPS=1e-16;  % tolerance for flow calculations

% input
F0=60; % independent inflow to tank 1 (cu ft/min)

%%%%% steady-state analysis
F0_bar=F0; % Tank 1 input constant inflow
alpha=(F0_bar/c2)^2;
a=gam; b=-(p0+gam*L2+alpha); c=alpha*L2;  % coeffs in quadratic for H2_ss
H2_ss=min(roots([a b c]))
p2_ss=L2*p0/(L2-H2_ss)
beta=(F0_bar/c1)^2;
H1_ss=L2+(beta+p2_ss-p0)/gam

% initial conditions
% H1_init=0.9*H1_ss;
% H2_init=0.9*H2_ss;
H1_init=0;
H2_init=0;

%%%%% linearization
k1=gam*(H1_ss-L2);
k2=(H2_ss/(L2-H2_ss))*p0;
k3=sqrt(k1-k2);
k4=gam+(p0*L2)/(L2-H2_ss)^2;
A11=(-0.5*gam*c1/A1)/k3; 
A12=(0.5*p0*L2*c1/A1)/k3;
A12=A12/((L2-H2_ss)^2);
A21=(0.5*gam*c1/A2)/k3;

A22=(-0.5*p0*L2*c1/A2)/k3;
A22=A22/((L2-H2_ss)^2);
A22=A22-(0.5*c2/A2)*k4/sqrt((k2+gam*H2_ss));


A=[A11 A12; A21 A22];
lam=eig(A);
lam1=lam(1), tau1=-1/lam1
lam2=lam(2), tau2=-1/lam2

stiffness=lam2/lam1 

